@@ -440,7 +440,7 @@ main (int argc, char *argv[])
 		errno = saved_errno;
 		pfatal_with_name (outname);
 	      }
-	    if (nread < (int) sizeof buf)
+	    if (nread < sizeof buf)
 	      break;
 	  }
       }
@@ -588,14 +588,20 @@ lock_dot(char *filename)
     p--;
   *p = 0;
   strcpy (p, "EXXXXXX");
+#ifndef HAVE_MKSTEMP
   mktemp (tempname);
   unlink (tempname);
+#endif
 
   for (;;)
     {
       /* Create the lock file, but not under the lock file name.  */
       /* Give up if cannot do that.  */
+#ifdef HAVE_MKSTEMP
+      desc = mkstemp (tempname);
+#else
       desc = open (tempname, O_WRONLY | O_CREAT | O_EXCL, 0666);
+#endif
       if (desc < 0)
 	{
 	  char *message = (char *) xmalloc (strlen (tempname) + 50);
@@ -741,14 +747,14 @@ popmail (char *user, char *outfile, char *password)
   server = pop_open (0, user, password, POP_NO_GETPASS);
   if (! server)
     {
-      error ("%s", pop_error, NULL);
+      error (pop_error, NULL, NULL);
       return (1);
     }
 
   VERBOSE(("stat'ing messages\n"));
   if (pop_stat (server, &nmsgs, &nbytes))
     {
-      error ("%s", pop_error, NULL);
+      error (pop_error, NULL, NULL);
       return (1);
     }
 
@@ -796,7 +802,7 @@ popmail (char *user, char *outfile, char *password)
           mbx_delimit_begin (mbf);
 	  if (pop_retr (server, i, mbx_write, mbf) != POP_RETRIEVED)
 	    {
-	      error ("%s", Errmsg, NULL);
+	      error (Errmsg, NULL, NULL);
 	      close (mbfi);
 	      return (1);
 	    }
@@ -844,7 +850,7 @@ popmail (char *user, char *outfile, char *password)
 	      VERBOSE(("deleting message %d     \n", i));
 	      if (pop_delete (server, i))
 		{
-		  error ("%s", pop_error, NULL);
+		  error (pop_error, NULL, NULL);
 		  pop_close (server);
 		  return (1);
 		}
@@ -855,7 +861,7 @@ popmail (char *user, char *outfile, char *password)
   VERBOSE(("closing server             \n"));
   if (pop_quit (server))
     {
-      error ("%s", pop_error, NULL);
+      error (pop_error, NULL, NULL);
       return (1);
     }
     
