@@ -1,27 +1,23 @@
 /* pop.c: client routines for talking to a POP3-protocol post-office server
-   Copyright (C) 1991, 1993, 1996, 1997, 1999, 2002, 2003, 2004,
-                 2005, 2006 Free Software Foundation, Inc.
-   Copyright (C) 2001 Ben Wing.
+   Copyright (c) 1991, 1993, 1996 Free Software Foundation, Inc.
    Written by Jonathan Kamens, jik@security.ov.com.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU Emacs; see the file COPYING.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.  */
-
-/* Synched up with: FSF 22.0.50. */
+along with XEmacs; see the file COPYING.  If not, write to
+the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 #define NO_SHORTNAMES	/* Tell config not to load remap.h */
@@ -99,7 +95,7 @@ extern struct servent *hes_getservbyname (/* char *, char * */);
 #ifdef KERBEROS
 #ifndef KRB5
 extern int krb_sendauth (/* long, int, KTEXT, char *, char *, char *,
-			    u_long, MSG_DAT *, CREDENTIALS *, Key_schedule,
+			    unsigned long, MSG_DAT *, CREDENTIALS *, Key_schedule,
 			    struct sockaddr_in *, struct sockaddr_in *,
 			    char * */);
 extern char *krb_realmofhost (/* char * */);
@@ -113,7 +109,7 @@ extern int h_errno;
 #endif
 
 static int socket_connection (char *, int);
-static int pop_getline (popserver, char **);
+static char *pop_getline (popserver);
 static int sendline (popserver, char *);
 static int fullwrite (int, char *, int);
 static int getok (popserver);
@@ -121,11 +117,9 @@ static int getok (popserver);
 static int gettermination (popserver);
 #endif
 static void pop_trash (popserver);
-static char *find_crlf (char *, int);
+static char *find_crlf (char *);
 
-#define ERROR_MAX 160		/* a pretty arbitrary size, but needs
-				   to be bigger than the original
-				   value of 80 */
+#define ERROR_MAX 80		/* a pretty arbitrary size */
 #define POP_PORT 110
 #define KPOP_PORT 1109
 #if defined(WIN32_NATIVE) || defined(CYGWIN)
@@ -135,7 +129,7 @@ static char *find_crlf (char *, int);
 #endif
 #ifdef KERBEROS
 #ifdef KRB5
-#define KPOP_SERVICE "k5pop"
+#define KPOP_SERVICE "k5pop";
 #else
 #define KPOP_SERVICE "kpop"
 #endif
@@ -361,7 +355,7 @@ pop_stat (popserver server, int *count, int *size)
       return (-1);
     }
      
-  if (sendline (server, "STAT") || (pop_getline (server, &fromserver) < 0))
+  if (sendline (server, "STAT") || (! (fromserver = pop_getline (server))))
     return (-1);
 
   if (strncmp (fromserver, "+OK ", 4))
@@ -453,7 +447,7 @@ pop_list (popserver server, int message, int **IDs, int **sizes)
 	  free ((char *) *sizes);
 	  return (-1);
 	}
-      if (pop_getline (server, &fromserver) < 0)
+      if (! (fromserver = pop_getline (server)))
 	{
 	  free ((char *) *IDs);
 	  free ((char *) *sizes);
@@ -498,7 +492,7 @@ pop_list (popserver server, int message, int **IDs, int **sizes)
 	}
       for (i = 0; i < how_many; i++)
 	{
-	  if (pop_multi_next (server, &fromserver) <= 0)
+	  if (pop_multi_next (server, &fromserver))
 	    {
 	      free ((char *) *IDs);
 	      free ((char *) *sizes);
@@ -517,7 +511,7 @@ pop_list (popserver server, int message, int **IDs, int **sizes)
 	    }
 	  (*sizes)[i] = atoi (fromserver);
 	}
-      if (pop_multi_next (server, &fromserver) < 0)
+      if (pop_multi_next (server, &fromserver))
 	{
 	  free ((char *) *IDs);
 	  free ((char *) *sizes);
@@ -547,17 +541,14 @@ pop_list (popserver server, int message, int **IDs, int **sizes)
  *	markfrom
  * 		If true, then mark the string "From " at the beginning
  * 		of lines with '>'.
- *	msg_buf	Output parameter to which a buffer containing the
- * 		message is assigned.
  * 
- * Return value: The number of bytes in msg_buf, which may contain
- * 	embedded nulls, not including its final null, or -1 on error
- * 	with pop_error set.
+ * Return value: A string pointing to the message, if successful, or
+ * 	null with pop_error set if not.
  *
  * Side effects: May kill connection on error.
  */
-int
-pop_retrieve (popserver server, int message, int markfrom, char **msg_buf)
+char *
+pop_retrieve (popserver server, int message, int markfrom)
 {
   int *IDs, *sizes, bufsize, fromcount = 0, cp = 0;
   char *ptr, *fromserver;
@@ -570,11 +561,11 @@ pop_retrieve (popserver server, int message, int markfrom, char **msg_buf)
     }
 
   if (pop_list (server, message, &IDs, &sizes))
-    return (-1);
+    return (0);
 
   if (pop_retrieve_first (server, message, &fromserver))
     {
-      return (-1);
+      return (0);
     }
 
   /*
@@ -592,16 +583,17 @@ pop_retrieve (popserver server, int message, int markfrom, char **msg_buf)
     {
       strcpy (pop_error, "Out of memory in pop_retrieve");
       pop_retrieve_flush (server);
-      return (-1);
+      return (0);
     }
 
-  while ((ret = pop_retrieve_next (server, &fromserver)) >= 0)
+  while (! (ret = pop_retrieve_next (server, &fromserver)))
     {
+      int linesize;
+
       if (! fromserver)
 	{
 	  ptr[cp] = '\0';
-	  *msg_buf = ptr;
-	  return (cp);
+	  return (ptr);
 	}
       if (markfrom && fromserver[0] == 'F' && fromserver[1] == 'r' &&
 	  fromserver[2] == 'o' && fromserver[3] == 'm' &&
@@ -615,19 +607,25 @@ pop_retrieve (popserver server, int message, int markfrom, char **msg_buf)
 		{
 		  strcpy (pop_error, "Out of memory in pop_retrieve");
 		  pop_retrieve_flush (server);
-		  return (-1);
+		  return (0);
 		}
 	      fromcount = 0;
 	    }
 	  ptr[cp++] = '>';
 	}
-      memcpy (&ptr[cp], fromserver, ret);
-      cp += ret;
+      linesize = strlen (fromserver);
+      memcpy (&ptr[cp], fromserver, linesize);
+      cp += linesize;
       ptr[cp++] = '\n';
     }
 
-  free (ptr);
-  return (-1);
+  if (ret)
+    {
+      free (ptr);
+      /* return (0); */
+    }
+  /* This function used to fall off the end, but that doesn't make any sense */
+  return (0);
 }     
 
 int
@@ -637,14 +635,6 @@ pop_retrieve_first (popserver server, int message, char **response)
   return (pop_multi_first (server, pop_error, response));
 }
 
-/*
-  Returns a negative number on error, 0 to indicate that the data has
-  all been read (i.e., the server has returned a "." termination
-  line), or a positive number indicating the number of bytes in the
-  returned buffer (which is null-terminated and may contain embedded
-  nulls, but the returned bytecount doesn't include the final null).
-  */
-
 int
 pop_retrieve_next (popserver server, char **line)
 {
@@ -664,14 +654,6 @@ pop_top_first (popserver server, int message, int lines, char **response)
   return (pop_multi_first (server, pop_error, response));
 }
 
-/*
-  Returns a negative number on error, 0 to indicate that the data has
-  all been read (i.e., the server has returned a "." termination
-  line), or a positive number indicating the number of bytes in the
-  returned buffer (which is null-terminated and may contain embedded
-  nulls, but the returned bytecount doesn't include the final null).
-  */
-
 int
 pop_top_next (popserver server, char **line)
 {
@@ -694,7 +676,7 @@ pop_multi_first (popserver server, char *command, char **response)
       return (-1);
     }
 
-  if (sendline (server, command) || (pop_getline (server, response) < 0))
+  if (sendline (server, command) || (! (*response = pop_getline (server))))
     {
       return (-1);
     }
@@ -718,20 +700,10 @@ pop_multi_first (popserver server, char *command, char **response)
     }
 }
 
-/*
-  Read the next line of data from SERVER and place a pointer to it
-  into LINE.  Return -1 on error, 0 if there are no more lines to read
-  (i.e., the server has returned a line containing only "."), or a
-  positive number indicating the number of bytes in the LINE buffer
-  (not including the final null).  The data in that buffer may contain
-  embedded nulls, but does not contain the final CRLF. When returning
-  0, LINE is set to null. */
-
 int
 pop_multi_next (popserver server, char **line)
 {
   char *fromserver;
-  int ret;
 
   if (! server->in_multi)
     {
@@ -739,7 +711,8 @@ pop_multi_next (popserver server, char **line)
       return (-1);
     }
 
-  if ((ret = pop_getline (server, &fromserver)) < 0)
+  fromserver = pop_getline (server);
+  if (! fromserver)
     {
       return (-1);
     }
@@ -755,13 +728,13 @@ pop_multi_next (popserver server, char **line)
       else
 	{
 	  *line = fromserver + 1;
-	  return (ret - 1);
+	  return (0);
 	}
     }
   else
     {
       *line = fromserver;
-      return (ret);
+      return (0);
     }
 }
 
@@ -769,22 +742,21 @@ int
 pop_multi_flush (popserver server)
 {
   char *line;
-  int ret;
 
   if (! server->in_multi)
     {
       return (0);
     }
 
-  while ((ret = pop_multi_next (server, &line)))
+  while (! pop_multi_next (server, &line))
     {
-      if (ret < 0)
+      if (! line)
 	{
-	  return (-1);
+	  return (0);
 	}
     }
 
-  return (0);
+  return (-1);
 }
 
 /* Function: pop_delete
@@ -871,7 +843,7 @@ pop_last (popserver server)
   if (sendline (server, "LAST"))
     return (-1);
 
-  if (pop_getline (server, &fromserver) < 0)
+  if (! (fromserver = pop_getline (server)))
     return (-1);
 
   if (! strncmp (fromserver, "-ERR", 4))
@@ -989,8 +961,6 @@ socket_connection (char *host, int flags)
 #ifdef KERBEROS
 #ifdef KRB5
   krb5_error_code rem;
-  krb5_context kcontext = 0;
-  krb5_auth_context auth_context = 0;
   krb5_ccache ccdef;
   krb5_principal client, server;
   krb5_error *err_ret;
@@ -1001,7 +971,6 @@ socket_connection (char *host, int flags)
   CREDENTIALS cred;
   Key_schedule schedule;
   int rem;
-  char *realhost;
 #endif /* KRB5 */
 #endif /* KERBEROS */
 
@@ -1015,6 +984,19 @@ socket_connection (char *host, int flags)
   }
 #endif
 
+  do
+    {
+      hostent = gethostbyname (host);
+      try_count++;
+      if ((! hostent) 
+	  && ((h_errno != TRY_AGAIN) || (try_count == 5))
+	  )
+	{
+	  strcpy (pop_error, "Could not determine POP server's address");
+	  return (-1);
+	}
+    } while (! hostent);
+
   memset (&addr, 0, sizeof (addr));
   addr.sin_family = AF_INET;
 
@@ -1053,33 +1035,18 @@ socket_connection (char *host, int flags)
 	}
     }
 
-#define POP_SOCKET_ERROR "Could not create socket for POP connection: "
+#define SOCKET_ERROR "Could not create socket for POP connection: "
 
   sock = socket (PF_INET, SOCK_STREAM, 0);
   if (sock < 0)
     {
-      strcpy (pop_error, POP_SOCKET_ERROR);
+      strcpy (pop_error, SOCKET_ERROR);
       strncat (pop_error, strerror (errno),
-	       ERROR_MAX - sizeof (POP_SOCKET_ERROR));
+	       ERROR_MAX - sizeof (SOCKET_ERROR));
       return (-1);
 	  
     }
 
-  do
-    {
-      hostent = gethostbyname (host);
-      try_count++;
-      if ((! hostent) 
-#ifndef BROKEN_CYGWIN	  
-	  && ((h_errno != TRY_AGAIN) || (try_count == 5))
-#endif
-	  )
-	{
-	  strcpy (pop_error, "Could not determine POP server's address");
-	  return (-1);
-	}
-    } while (! hostent);
-
   while (*hostent->h_addr_list)
     {
       memcpy (&addr.sin_addr, *hostent->h_addr_list, hostent->h_length);
@@ -1105,13 +1072,11 @@ socket_connection (char *host, int flags)
   if (! (flags & POP_NO_KERBEROS))
     {
 #ifdef KRB5
-      if ((rem = krb5_init_context (&kcontext)))
+      krb5_init_ets ();
+
+      if (rem = krb5_cc_default (&ccdef))
 	{
 	krb5error:
-	  if (auth_context)
-	    krb5_auth_con_free (kcontext, auth_context);
-	  if (kcontext)
-	    krb5_free_context (kcontext);
 	  strcpy (pop_error, KRB_ERROR);
 	  strncat (pop_error, error_message (rem),
 		   ERROR_MAX - sizeof(KRB_ERROR));
@@ -1119,14 +1084,10 @@ socket_connection (char *host, int flags)
 	  return (-1);
 	}
 
-      if ((rem = krb5_auth_con_init (kcontext, &auth_context)))
-	goto krb5error;
-
-      if (rem = krb5_cc_default (kcontext, &ccdef))
-	goto krb5error;
-
-      if (rem = krb5_cc_get_principal (kcontext, ccdef, &client))
-	goto krb5error;
+      if (rem = krb5_cc_get_principal (ccdef, &client))
+	{
+	  goto krb5error;
+	}
 
       for (cp = hostent->h_name; *cp; cp++)
 	{
@@ -1136,20 +1097,22 @@ socket_connection (char *host, int flags)
 	    }
 	}
 
-      if (rem = krb5_sname_to_principal (kcontext, hostent->h_name,
-					 POP_SERVICE, FALSE, &server))
-	goto krb5error;
+      if (rem = krb5_sname_to_principal (hostent->h_name, POP_SERVICE,
+					 FALSE, &server))
+	{
+	  goto krb5error;
+	}
 
-      rem = krb5_sendauth (kcontext, &auth_context,
-			   (krb5_pointer) &sock, "KPOPV1.0", client, server,
+      rem = krb5_sendauth ((krb5_pointer) &sock, "KPOPV1.0", client, server,
 			  AP_OPTS_MUTUAL_REQUIRED,
 			  0,	/* no checksum */
 			  0,	/* no creds, use ccache instead */
 			  ccdef,
-			  &err_ret,
+			  0,	/* don't need seq # */
 			  0,	/* don't need subsession key */
+			  &err_ret,
 			  0);	/* don't need reply */
-      krb5_free_principal (kcontext, server);
+      krb5_free_principal (server);
       if (rem)
 	{
 	  if (err_ret && err_ret->text.length)
@@ -1172,23 +1135,20 @@ socket_connection (char *host, int flags)
 		       ERROR_MAX - sizeof (KRB_ERROR));
 	    }
 	  if (err_ret)
-	    krb5_free_error (kcontext, err_ret);
-	  krb5_auth_con_free (kcontext, auth_context);
-	  krb5_free_context (kcontext);
+	    krb5_free_error (err_ret);
 
 	  CLOSESOCKET (sock);
 	  return (-1);
 	}
 #else  /* ! KRB5 */	  
       ticket = (KTEXT) malloc (sizeof (KTEXT_ST));
-      rem = krb_sendauth (0L, sock, ticket, "pop", realhost,
-			  (char *) krb_realmofhost (realhost),
+      rem = krb_sendauth (0L, sock, ticket, "pop", hostent->h_name,
+			  (char *) krb_realmofhost (hostent->h_name),
 			  (unsigned long) 0, &msg_data, &cred, schedule,
 			  (struct sockaddr_in *) 0,
 			  (struct sockaddr_in *) 0,
 			  "KPOPV0.1");
       free ((char *) ticket);
-      free (realhost);
       if (rem != KSUCCESS)
 	{
 	  strcpy (pop_error, KRB_ERROR);
@@ -1215,20 +1175,15 @@ socket_connection (char *host, int flags)
  * Arguments:
  * 	server	The server from which to get the line of text.
  *
- * Returns: The number of characters in the line, which is returned in
- * 	LINE, not including the final null.  A return value of 0
- * 	indicates a blank line.  A negative return value indicates an
- * 	error (in which case the contents of LINE are undefined.  In
- * 	case of error, an error message is copied into pop_error.
+ * Returns: A non-null pointer if successful, or a null pointer on any
+ * 	error, with an error message copied into pop_error.
  *
  * Notes: The line returned is overwritten with each call to pop_getline.
  *
  * Side effects: Closes the connection on error.
- *
- * THE RETURNED LINE MAY CONTAIN EMBEDDED NULLS!
  */
-static int
-pop_getline (popserver server, char **line)
+static char *
+pop_getline (popserver server)
 {
 #define GETLINE_ERROR "Error reading from server: "
 
@@ -1237,8 +1192,7 @@ pop_getline (popserver server, char **line)
 
   if (server->data)
     {
-      char *cp = find_crlf (server->buffer + server->buffer_index,
-			    server->data);
+      char *cp = find_crlf (server->buffer + server->buffer_index);
       if (cp)
 	{
 	  int found;
@@ -1252,11 +1206,8 @@ pop_getline (popserver server, char **line)
 	  server->buffer_index += data_used;
 
 	  if (pop_debug)
-	    /* Embedded nulls will truncate this output prematurely,
-	       but that's OK because it's just for debugging anyway. */
 	    fprintf (stderr, "<<< %s\n", server->buffer + found);
-	  *line = server->buffer + found;
-	  return (data_used - 2);
+	  return (server->buffer + found);
 	}
       else
 	{
@@ -1292,7 +1243,7 @@ pop_getline (popserver server, char **line)
 	    {
 	      strcpy (pop_error, "Out of memory in pop_getline");
 	      pop_trash (server);
-	      return (-1);
+	      return (0);
 	    }
 	}
       ret = RECV (server->file, server->buffer + server->data,
@@ -1303,13 +1254,13 @@ pop_getline (popserver server, char **line)
 	  strncat (pop_error, strerror (errno),
 		   ERROR_MAX - sizeof (GETLINE_ERROR));
 	  pop_trash (server);
-	  return (-1);
+	  return (0);
 	}
       else if (ret == 0)
 	{
 	  strcpy (pop_error, "Unexpected EOF from server in pop_getline");
 	  pop_trash (server);
-	  return (-1);
+	  return (0);
 	}
       else
 	{
@@ -1317,8 +1268,7 @@ pop_getline (popserver server, char **line)
 	  server->data += ret;
 	  server->buffer[server->data] = '\0';
 	       
-	  cp = find_crlf (server->buffer + search_offset,
-			  server->data - search_offset);
+	  cp = find_crlf (server->buffer + search_offset);
 	  if (cp)
 	    {
 	      int data_used = (cp + 2) - server->buffer;
@@ -1328,12 +1278,9 @@ pop_getline (popserver server, char **line)
 
 	      if (pop_debug)
 		fprintf (stderr, "<<< %s\n", server->buffer);
-	      *line = server->buffer;
-	      return (data_used - 2);
+	      return (server->buffer);
 	    }
-	  /* As above, the "- 1" here is to account for the fact that
-	     we may have read a CR without its accompanying LF. */
-	  search_offset += ret - 1;
+	  search_offset += ret;
 	}
     }
 
@@ -1363,24 +1310,12 @@ sendline (popserver server, char *line)
 {
 #define SENDLINE_ERROR "Error writing to POP server: "
   int ret;
-  char *buf;
 
-  /* Combine the string and the CR-LF into one buffer.  Otherwise, two
-     reasonable network stack optimizations, Nagle's algorithm and
-     delayed acks, combine to delay us a fraction of a second on every
-     message we send.  (Movemail writes line without \r\n, client
-     kernel sends packet, server kernel delays the ack to see if it
-     can combine it with data, movemail writes \r\n, client kernel
-     waits because it has unacked data already in its outgoing queue,
-     client kernel eventually times out and sends.)
-
-     This can be something like 0.2s per command, which can add up
-     over a few dozen messages, and is a big chunk of the time we
-     spend fetching mail from a server close by.  */
-  buf = alloca (strlen (line) + 3);
-  strcpy (buf, line);
-  strcat (buf, "\r\n");
   ret = fullwrite (server->file, line, strlen (line));
+  if (ret >= 0)
+    {				/* 0 indicates that a blank line was written */
+      ret = fullwrite (server->file, "\r\n", 2);
+    }
 
   if (ret < 0)
     {
@@ -1409,10 +1344,10 @@ static int
 fullwrite (int fd, char *buf, int nbytes)
 {
   char *cp;
-  int ret = 0;
+  int ret;
 
   cp = buf;
-  while (nbytes && ((ret = SEND (fd, cp, nbytes, 0)) > 0))
+  while ((ret = SEND (fd, cp, nbytes, 0)) > 0)
     {
       cp += ret;
       nbytes -= ret;
@@ -1440,7 +1375,7 @@ getok (popserver server)
 {
   char *fromline;
 
-  if (pop_getline (server, &fromline) < 0)
+  if (! (fromline = pop_getline (server)))
     {
       return (-1);
     }
@@ -1478,7 +1413,8 @@ gettermination (popserver server)
 {
   char *fromserver;
 
-  if (pop_getline (server, &fromserver) < 0)
+  fromserver = pop_getline (server);
+  if (! fromserver)
     return (-1);
 
   if (strcmp (fromserver, "."))
@@ -1549,16 +1485,17 @@ pop_trash (popserver server)
 #endif
 }
 
-/* Return a pointer to the first CRLF in IN_STRING, which can contain
-   embedded nulls and has LEN characters in it not including the final
-   null, or 0 if it does not contain one.  */
+/* Return a pointer to the first CRLF in IN_STRING,
+   or 0 if it does not contain one.  */
 
 static char *
-find_crlf (char *in_string, int len)
+find_crlf (char *in_string)
 {
-  while (len--)
+  while (1)
     {
-      if (*in_string == '\r')
+      if (! *in_string)
+	return (0);
+      else if (*in_string == '\r')
 	{
 	  if (*++in_string == '\n')
 	    return (in_string - 1);
@@ -1566,7 +1503,7 @@ find_crlf (char *in_string, int len)
       else
 	in_string++;
     }
-  return (0);
+  /* NOTREACHED */
 }
 
 #endif /* MAIL_USE_POP */
