@@ -3,20 +3,20 @@
 
  Author: Boaz Ben-Zvi <boaz@lcs.mit.edu>
 
- This file is part of GNU Emacs.
+ This file is part of XEmacs.
 
- GNU Emacs is free software; you can redistribute it and/or modify
+ XEmacs is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
- GNU Emacs is distributed in the hope that it will be useful,
+ XEmacs is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GNU Emacs; see the file COPYING.  If not, write to
+ along with XEmacs; see the file COPYING.  If not, write to
  the Free the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
@@ -41,7 +41,7 @@ static struct timeval TV1, TV2;
 static int watch_not_started = 1; /* flag */
 static char time_string[30];
 
-#ifdef WINDOWSNT
+#ifdef WIN32_NATIVE
 #include <sys/timeb.h>
 /* Emulate gettimeofday (Ulrich Leodolter, 1/11/95).  */
 void 
