@@ -28,7 +28,7 @@
 
 ;;; Commentary:
 
-;; This code helps GNU Emacs maintainers keep the loaddefs.el file up to
+;; This code helps XEmacs maintainers keep the loaddefs.el file up to
 ;; date.  It interprets magic cookies of the form ";;;###autoload" in
 ;; lisp source files in various useful ways.  To learn more, read the
 ;; source; if you're going to use this, you'd better be able to.
@@ -39,100 +39,30 @@
 
 ;;; Code:
 
-;; Need to load easy-mmode because we expand macro calls to easy-mmode
-;; macros in make-autoloads below.
-(require 'easy-mmode)
-
-; Add operator definitions to autoload-operators.el in the xemacs-base
-; package.
-(eval-when-compile (load "cl-macs"))
-(ignore-errors (require 'autoload-operators))
-
-; As autoload-operators is new, provide stopgap measure for a while.
-(if (not (boundp 'autoload-make-autoload-operators))
-    (progn
-      (defvar autoload-make-autoload-operators
-	'(defun define-skeleton defmacro define-derived-mode define-generic-mode
-	  easy-mmode-define-minor-mode easy-mmode-define-global-mode
-	  define-minor-mode defun* defmacro*)
-	"`defun'-like operators that use `autoload' to load the library.")
-      
-      (defvar autoload-make-autoload-complex-operators
-	'(easy-mmode-define-minor-mode easy-mmode-define-global-mode
-	  define-minor-mode)
-	"`defun'-like operators to macroexpand before using `autoload'.")
-      
-      (put 'autoload 'doc-string-elt 3)
-      (put 'defun    'doc-string-elt 3)
-      (put 'defun*   'doc-string-elt 3)
-      (put 'defvar   'doc-string-elt 3)
-      (put 'defcustom 'doc-string-elt 3)
-      (put 'defconst 'doc-string-elt 3)
-      (put 'defmacro 'doc-string-elt 3)
-      (put 'defmacro* 'doc-string-elt 3)
-      (put 'defsubst 'doc-string-elt 3)
-      (put 'define-skeleton 'doc-string-elt 2)
-      (put 'define-derived-mode 'doc-string-elt 4)
-      (put 'easy-mmode-define-minor-mode 'doc-string-elt 2)
-      (put 'define-minor-mode 'doc-string-elt 2)
-      (put 'define-generic-mode 'doc-string-elt 7)
-      ;; defin-global-mode has no explicit docstring.
-      (put 'easy-mmode-define-global-mode 'doc-string-elt 1000)))
-
 (defun make-autoload (form file)
-  "Turn FORM into an autoload or defvar for source file FILE.
-Returns nil if FORM is not a special autoload form (i.e. a function definition
-or macro definition or a defcustom)."
-  (let ((car (car-safe form)) expand)
-    (cond
-     ;; For complex cases, try again on the macro-expansion.
-     ((and (memq car autoload-make-autoload-complex-operators)
-	   (setq expand (let ((load-file-name file)) (macroexpand form)))
-	   (eq (car expand) 'progn)
-	   (memq :autoload-end expand))
-      (let ((end (memq :autoload-end expand)))
-	;; Cut-off anything after the :autoload-end marker.
-	(setcdr end nil)
-	(cons 'progn
-	      (mapcar (lambda (form) (make-autoload form file))
-		      (cdr expand)))))
+  "Turn FORM, a defun or defmacro, into an autoload for source file FILE.
+Returns nil if FORM is not a defun, define-skeleton or defmacro."
+  (let ((car (car-safe form)))
+    (if (memq car '(defun define-skeleton defmacro))
+	(let ((macrop (eq car 'defmacro))
+	      name doc)
+	  (setq form (cdr form)
+		name (car form)
+		;; Ignore the arguments.
+		form (cdr (if (eq car 'define-skeleton)
+			      form
+			    (cdr form)))
+		doc (car form))
+	  (if (stringp doc)
+	      (setq form (cdr form))
+	    (setq doc nil))
+	  (list 'autoload (list 'quote name) file doc
+		(or (eq car 'define-skeleton)
+		    (eq (car-safe (car form)) 'interactive))
+		(if macrop (list 'quote 'macro) nil)))
+      nil)))
 
-     ;; For special function-like operators, use the `autoload' function.
-     ((memq car autoload-make-autoload-operators)
-      (let* ((macrop (memq car '(defmacro defmacro*)))
-	     (name (nth 1 form))
-	     (body (nthcdr (get car 'doc-string-elt) form))
-	     (doc (if (stringp (car body)) (pop body))))
-	;; `define-generic-mode' quotes the name, so take care of that
-	(list 'autoload (if (listp name) name (list 'quote name)) file doc
-	      (or (and (memq car '(define-skeleton define-derived-mode
-				    define-generic-mode
-				    easy-mmode-define-global-mode
-				    easy-mmode-define-minor-mode
-				    define-minor-mode)) t)
-		  (eq (car-safe (car body)) 'interactive))
-	      (if macrop (list 'quote 'macro) nil))))
-
-     ;; Convert defcustom to a simpler (and less space-consuming) defvar,
-     ;; but add some extra stuff if it uses :require.
-     ((eq car 'defcustom)
-      (let ((varname (car-safe (cdr-safe form)))
-	    (init (car-safe (cdr-safe (cdr-safe form))))
-	    (doc (car-safe (cdr-safe (cdr-safe (cdr-safe form)))))
-	    (rest (cdr-safe (cdr-safe (cdr-safe (cdr-safe form))))))
-	(if (not (plist-get rest :require))
-	    `(defvar ,varname ,init ,doc)
-	  `(progn
-	     (defvar ,varname ,init ,doc)
-	     (custom-add-to-group ,(plist-get rest :group)
-				  ',varname 'custom-variable)
-	     (custom-add-load ',varname
-			      ,(plist-get rest :require))))))
-     ;; Coding systems. #### Would be nice to handle the docstring here too.
-     ((memq car '(make-coding-system make-8-bit-coding-system))
-      `(autoload-coding-system ,(nth 1 form) '(load ,file)))
-     ;; nil here indicates that this is not a special autoload form.
-     (t nil))))
+(put 'define-skeleton 'doc-string-elt 3)
 
 (defvar generate-autoload-cookie ";;;###autoload"
   "Magic comment indicating the following form should be autoloaded.
@@ -159,6 +89,30 @@ the section of autoloads for a file.")
 
 (defvar autoload-package-name nil)
 
+;;; Forms which have doc-strings which should be printed specially.
+;;; A doc-string-elt property of ELT says that (nth ELT FORM) is
+;;; the doc-string in FORM.
+;;;
+;;; There used to be the following note here:
+;;; ;;; Note: defconst and defvar should NOT be marked in this way.
+;;; ;;; We don't want to produce defconsts and defvars that
+;;; ;;; make-docfile can grok, because then it would grok them twice,
+;;; ;;; once in foo.el (where they are given with ;;;###autoload) and
+;;; ;;; once in loaddefs.el.
+;;;
+;;; Counter-note: Yes, they should be marked in this way.
+;;; make-docfile only processes those files that are loaded into the
+;;; dumped Emacs, and those files should never have anything
+;;; autoloaded here.  The above-feared problem only occurs with files
+;;; which have autoloaded entries *and* are processed by make-docfile;
+;;; there should be no such files.
+
+(put 'autoload 'doc-string-elt 3)
+(put 'defun    'doc-string-elt 3)
+(put 'defvar   'doc-string-elt 3)
+(put 'defconst 'doc-string-elt 3)
+(put 'defmacro 'doc-string-elt 3)
+
 (defun autoload-trim-file-name (file)
   "Returns a relative pathname of FILE including the last directory."
   (setq file (expand-file-name file))
@@ -514,7 +468,10 @@ This function refuses to update autoloads files."
 This runs `update-file-autoloads' on each .el file in DIR.
 Obsolete autoload entries for files that no longer exist are deleted.
 Note that, if this function is called from `batch-update-directory',
-`generated-autoload-file' was rebound in that function."
+`generated-autoload-file' was rebound in that function.
+
+You don't really want to be calling this function.  Try using
+`update-autoload-files' instead."
   (interactive "DUpdate autoloads for directory: ")
   (setq dir (expand-file-name dir))
   (let ((simple-dir (file-name-as-directory
@@ -544,37 +501,6 @@ Note that, if this function is called from `batch-update-directory',
       (unless noninteractive
 	(save-buffer)))))
 
-;;;###autoload
-(defun batch-update-autoloads ()
-  "Update the autoloads for the files or directories on the command line.
-Runs `update-file-autoloads' on files and `update-directory-autoloads'
-on directories.  Must be used only with -batch, and kills Emacs on completion.
-Each file will be processed even if an error occurred previously.
-For example, invoke `xemacs -batch -f batch-update-autoloads *.el'.
-The directory to which the auto-autoloads.el file must be the first parameter
-on the command line."
-  (unless noninteractive
-    (error "batch-update-autoloads is to be used only with -batch"))
-  (let ((defdir (directory-file-name default-directory))
-	(enable-local-eval nil))	; Don't query in batch mode.
-    ;; (message "Updating autoloads in %s..." generated-autoload-file)
-    (dolist (arg command-line-args-left)
-      (setq arg (expand-file-name arg defdir))
-      (cond
-       ((file-directory-p arg)
-	(message "Updating autoloads for directory %s..." arg)
-	(update-autoloads-from-directory arg))
-       ((file-exists-p arg)
-	(update-file-autoloads arg))
-       (t (error "No such file or directory: %s" arg))))
-    (fixup-autoload-buffer (concat (if autoload-package-name
-				       autoload-package-name
-				     (file-name-nondirectory defdir))
-				   "-autoloads"))
-    (save-some-buffers t)
-    ;; (message "Done")
-    (kill-emacs 0)))
-
 (defun fixup-autoload-buffer (sym)
   (save-excursion
     (set-buffer (find-file-noselect generated-autoload-file))
@@ -590,11 +516,73 @@ on the command line."
 
 (defvar autoload-package-name nil)
 
-;; #### this function is almost identical to, but subtly different from,
-;; batch-update-autoloads.  Both of these functions, unfortunately, are
-;; used in various build scripts in xemacs-packages.  They should be
-;; merged. (However, it looks like no scripts pass more than one arg,
-;; making merging easy.) --ben
+;;;###autoload
+(defun update-autoload-files (files-or-dirs &optional all-into-one-file force)
+  "Update all the autoload files associated with FILES-OR-DIRS.
+FILES-OR-DIRS should be a list of files or directories to be
+processed.  If ALL-INTO-ONE-FILE is not given, the appropriate
+autoload file for each file or directory (located in that directory,
+or in the directory of the specified file) will be updated with the
+directory's or file's autoloads, some additional fixup text will be
+added, and the files will be saved.  If ALL-INTO-ONE-FILE is given,
+`generated-autoload-file' should be set to the name of the autoload
+file into which the autoloads will be generated, and the autoloads
+for all files and directories will go into that same file.
+
+If FORCE is non-nil, always save out the autoload files even if unchanged."
+  (let ((defdir default-directory)
+	(enable-local-eval nil))	; Don't query in batch mode.
+    ;; (message "Updating autoloads in %s..." generated-autoload-file)
+    (dolist (arg files-or-dirs)
+      (setq arg (expand-file-name arg defdir))
+      (let ((generated-autoload-file
+	     (if all-into-one-file generated-autoload-file
+	       (expand-file-name autoload-file-name
+				 (if (file-directory-p arg) arg
+				   (file-name-directory arg))))))
+	(cond
+	 ((file-directory-p arg)
+	  (message "Updating autoloads for directory %s..." arg)
+	  (update-autoloads-from-directory arg))
+	 ((file-exists-p arg)
+	  (update-file-autoloads arg))
+	 (t (error "No such file or directory: %s" arg)))
+	(when (not all-into-one-file)
+	  (fixup-autoload-buffer (concat (if autoload-package-name
+					     autoload-package-name
+					   (file-name-nondirectory defdir))
+					 "-autoloads"))
+	  (if force (set-buffer-modified-p
+		     t (find-file-noselect generated-autoload-file))))))
+    (when all-into-one-file
+      (fixup-autoload-buffer (concat (if autoload-package-name
+					 autoload-package-name
+				       (file-name-nondirectory defdir))
+				     "-autoloads"))
+      (if force (set-buffer-modified-p
+		 t (find-file-noselect generated-autoload-file))))
+    (save-some-buffers t)
+    ;; (message "Done")
+    ))
+
+;; #### these entry points below are a big mess, especially the
+;; first two.  there don't seem to be very many packages that use the
+;; first one (the "all-into-one-file" variety), and do they actually
+;; rely on this functionality? --ben
+
+;;;###autoload
+(defun batch-update-autoloads ()
+  "Update the autoloads for the files or directories on the command line.
+Runs `update-file-autoloads' on files and `update-directory-autoloads'
+on directories.  Must be used only with -batch, and kills Emacs on completion.
+Each file will be processed even if an error occurred previously.
+For example, invoke `xemacs -batch -f batch-update-autoloads *.el'.
+The directory to which the auto-autoloads.el file must be the first parameter
+on the command line."
+  (unless noninteractive
+    (error "batch-update-autoloads is to be used only with -batch"))
+  (update-autoload-files command-line-args-left t)
+  (kill-emacs 0))
 
 ;;;###autoload
 (defun batch-update-directory ()
@@ -603,29 +591,9 @@ Runs `update-file-autoloads' on each file in the given directory, and must
 be used only with -batch."
   (unless noninteractive
     (error "batch-update-directory is to be used only with -batch"))
-  (let ((defdir default-directory)
-	(enable-local-eval nil))	; Don't query in batch mode.
-    (dolist (arg command-line-args-left)
-      (setq arg (expand-file-name arg defdir))
-      (let ((generated-autoload-file (expand-file-name autoload-file-name
-							arg)))
-	(cond
-	 ((file-directory-p arg)
-	  (message "Updating autoloads in directory %s..." arg)
-	  (update-autoloads-from-directory arg))
-	 (t (error "No such file or directory: %s" arg)))
-	(fixup-autoload-buffer (concat (if autoload-package-name
-					   autoload-package-name
-					 (file-name-nondirectory arg))
-				"-autoloads"))
-	(save-some-buffers t))
-      ;; (message "Done")
-      ;; (kill-emacs 0)
-      )
-    (setq command-line-args-left nil)))
-
-;; #### i created the following.  this one and the last should be merged into
-;; batch-update-autoloads and batch-update-one-directory. --ben
+  (update-autoload-files command-line-args-left)
+  ;; (kill-emacs 0)
+  (setq command-line-args-left nil))
 
 ;;;###autoload
 (defun batch-update-one-directory ()
@@ -634,25 +602,21 @@ Runs `update-file-autoloads' on each file in the given directory, and must
 be used only with -batch."
   (unless noninteractive
     (error "batch-update-directory is to be used only with -batch"))
-  (let ((defdir default-directory)
-	(enable-local-eval nil))	; Don't query in batch mode.
-    (let ((arg (car command-line-args-left)))
-      (setq command-line-args-left (cdr command-line-args-left))
-      (setq arg (expand-file-name arg defdir))
-      (let ((generated-autoload-file (expand-file-name autoload-file-name
-							arg)))
-	(cond
-	 ((file-directory-p arg)
-	  (message "Updating autoloads in directory %s..." arg)
-	  (update-autoloads-from-directory arg))
-	 (t (error "No such file or directory: %s" arg)))
-	(fixup-autoload-buffer (concat (if autoload-package-name
-					   autoload-package-name
-					 (file-name-nondirectory arg))
-				"-autoloads"))
-	(save-some-buffers t))
-      ;; (message "Done")
-      )))
+  (let ((arg (car command-line-args-left)))
+    (setq command-line-args-left (cdr command-line-args-left))
+    (update-autoload-files (list arg))))
+
+;;;###autoload
+(defun batch-force-update-one-directory ()
+  "Update the autoloads for a single directory on the command line.
+Runs `update-file-autoloads' on each file in the given directory, and must
+be used only with -batch.  Always rewrite the autoloads file, even if
+unchanged."
+  (unless noninteractive
+    (error "batch-update-directory is to be used only with -batch"))
+  (let ((arg (car command-line-args-left)))
+    (setq command-line-args-left (cdr command-line-args-left))
+    (update-autoload-files (list arg) nil t)))
 
 (provide 'autoload)
 
