@@ -348,10 +348,7 @@ redefining the function `format-buffers-menu-line'."
 		     :items items)
 	     frame)
 	    ;; set-glyph-image will not make the gutter dirty
-	    (set-specifier-dirty-flag 
-	     (eval (intern (concat 
-			    (symbol-name gutter-buffers-tab-orientation) 
-			    "-gutter"))))))))))
+	    (set-gutter-dirty-p gutter-buffers-tab-orientation)))))))
 
 ;; A myriad of different update hooks all doing slightly different things
 (add-one-shot-hook 
@@ -426,7 +423,8 @@ side-by-side."
 		     ;; 'quit is special and acts "asynchronously".
 		     :descriptor "Stop" :callback 'quit]
 		    ,progress-text-instantiator)])
-    (set-glyph-image progress-layout-glyph progress-layout-instantiator locale))
+    (set-glyph-image progress-layout-glyph progress-layout-instantiator
+		     locale))
    (t 
     (setq progress-glyph-height 24)
     (setq progress-layout-instantiator
@@ -442,7 +440,20 @@ side-by-side."
 			      :descriptor " Stop "
 			      ;; 'quit is special and acts "asynchronously".
 			      :callback 'quit])])])
-    (set-glyph-image progress-layout-glyph progress-layout-instantiator locale))))
+    (set-glyph-image progress-layout-glyph progress-layout-instantiator
+		     locale))))
+
+(defvar progress-abort-glyph (make-glyph))
+
+(defun set-progress-abort-instantiator (&optional locale)
+  (set-glyph-image progress-abort-glyph
+		   `[layout :orientation vertical :justify left
+			    :items (,progress-text-instantiator
+				    [layout
+				     :margin-width 4
+				     :pixel-height progress-glyph-height
+				     :orientation horizontal])]
+		   locale))
 
 (defvar progress-stack nil
   "An alist of label/string pairs representing active progress gauges.
@@ -450,15 +461,6 @@ The first element in the list is currently displayed in the gutter area.
 Do not modify this directly--use the `progress-feedback' or
 `display-progress-feedback'/`clear-progress-feedback' functions.")
 
-(defvar progress-abort-glyph
-  (make-glyph
-   `[layout :orientation vertical :justify left
-	    :items (,progress-text-instantiator
-		    [layout
-		     :margin-width 4
-		     :pixel-height progress-glyph-height
-		     :orientation horizontal])]))
-
 (defun progress-feedback-displayed-p (&optional return-string frame)
   "Return a non-nil value if a progress gauge is presently displayed in the
 gutter area.  If optional argument RETURN-STRING is non-nil,
@@ -486,8 +488,7 @@ you should just use (progress nil)."
       (clear-message label frame nil no-restore)
     (or frame (setq frame (selected-frame)))
     (remove-progress-feedback label frame)
-    (let ((inhibit-read-only t)
-	  (zmacs-region-stays zmacs-region-stays)) ; preserve from change
+    (let ((inhibit-read-only t))
       (erase-buffer (get-buffer-create " *Gutter Area*")))
     (if no-restore
 	nil			; just preparing to put another msg up
@@ -556,8 +557,7 @@ you should just use (progress nil)."
     (or frame (setq frame (selected-frame)))
     ;; Add a new entry to the message-stack, or modify an existing one
     (let* ((top (car progress-stack))
-	   (inhibit-read-only t)
-	   (zmacs-region-stays zmacs-region-stays))
+	   (inhibit-read-only t))
       (if (eq label (car top))
 	  (setcdr top message)
 	(push (cons label message) progress-stack))
@@ -570,8 +570,8 @@ you should just use (progress nil)."
 	  ;; fixup the gutter specifiers
 	  (set-gutter-element bottom-gutter 'progress gutter-string frame)
 	  (set-specifier bottom-gutter-border-width 2 frame)
-	  (set-instantiator-property progress-text-instantiator :datat message)
-	  (set-progress-feedback-instantiator (frame-selected-window frame))
+	  (set-instantiator-property progress-text-instantiator :data message)
+	  (set-progress-abort-instantiator (frame-selected-window frame))
 	  (set-specifier bottom-gutter-height 'autodetect frame)
 	  (set-gutter-element-visible-p bottom-gutter-visible-p 
 					'progress t frame)
@@ -587,7 +587,6 @@ you should just use (progress nil)."
 (defun raw-append-progress-feedback (message &optional value frame)
   (unless (equal message "")
     (let* ((inhibit-read-only t)
-	  (zmacs-region-stays zmacs-region-stays)
 	  (val (or value 0))
 	  (gutter-string (copy-sequence "\n"))
 	  (ext (make-extent 0 1 gutter-string)))
