@@ -343,7 +343,7 @@ The return value has the form (NAME . ADDRESS)."
 
 (defun lm-version (&optional file)
   "Return the version listed in file FILE, or current buffer if FILE is nil.
-This can befound in an RCS or SCCS header to crack it out of."
+This can be found in an RCS or SCCS header to crack it out of."
   (save-excursion 
     (if file
 	(find-file file))
@@ -561,7 +561,7 @@ Prompts for bug subject.  Leaves you in a mail buffer."
 	  (if addr
 	      (concat (car addr) " <" (cdr addr) ">")
 	    (or (and (boundp 'report-emacs-bug-beta-address)
-		     report-emacs-bug-beta-address)
+		     (declare-boundp report-emacs-bug-beta-address))
 		"<xemacs-beta@xemacs.org>"))
 	  topic)
     (goto-char (point-max))
