@@ -449,17 +449,7 @@ Type ^H^H^H (Control-h Control-h Control-h) to get more help options.\n")
 			   debug-paths)
       (startup-setup-paths-warning))
 
-    (if (and (not inhibit-autoloads)
-	     lisp-directory)
-	(load (expand-file-name (file-name-sans-extension autoload-file-name)
-				lisp-directory) nil t))
-
-    (if (not inhibit-autoloads)
-	(progn
-	  (if (not inhibit-early-packages)
-	      (packages-load-package-auto-autoloads early-package-load-path))
-	  (packages-load-package-auto-autoloads late-package-load-path)
-	  (packages-load-package-auto-autoloads last-package-load-path)))
+    (startup-load-autoloads)
 
     (unwind-protect
 	(command-line)
@@ -491,24 +481,10 @@ Type ^H^H^H (Control-h Control-h Control-h) to get more help options.\n")
 
     (if load-user-init-file-p
 	(maybe-migrate-user-init-file))
-    ;;####FSFmacs junk
-    ;;      (or menubar-bindings-done
-    ;;	  (precompute-menubar-bindings))
+    ;; FSF calls precompute-menubar-bindings.  We don't mix menubars
+    ;; and keymaps.
     ))
 
-;;####FSFmacs junk
-;;; Precompute the keyboard equivalents in the menu bar items.
-;;(defun precompute-menubar-bindings ()
-;;  (if (eq window-system 'x)
-;;      (let ((submap (lookup-key global-map [menu-bar])))
-;;	(while submap
-;;	  (and (consp (car submap))
-;;	       (symbolp (car (car submap)))
-;;	       (stringp (car-safe (cdr (car submap))))
-;;	       (keymapp (cdr (cdr (car submap))))
-;;	       (x-popup-menu nil (cdr (cdr (car submap)))))
-;;	  (setq submap (cdr submap))))))
-
 (defun command-line-early (args)
   ;; This processes those switches which need to be processed before
   ;; starting up the window system.
@@ -624,6 +600,9 @@ If this is nil, no message will be displayed.")
       ;; handled here instead of down in C.
       (setq command-line-args-left (command-line-early command-line-args-left))
 
+      (when (eq system-type 'windows-nt)
+	(init-mswindows-at-startup))
+
       ;; Setup the toolbar icon directory
       (when (featurep 'toolbar)
 	(init-toolbar-location))
@@ -1427,4 +1406,17 @@ It's idempotent, so call this as often as you like!"
 	(erase-buffer)
 	t)))))
 
+(defun startup-load-autoloads ()
+  (if (and (not inhibit-autoloads)
+	   lisp-directory)
+      (load (expand-file-name (file-name-sans-extension autoload-file-name)
+			      lisp-directory) nil t))
+
+  (if (not inhibit-autoloads)
+      (progn
+	(if (not inhibit-early-packages)
+	    (packages-load-package-auto-autoloads early-package-load-path))
+	(packages-load-package-auto-autoloads late-package-load-path)
+	(packages-load-package-auto-autoloads last-package-load-path))))
+
 ;;; startup.el ends here
