@@ -1,4 +1,4 @@
-/* Synchronous subprocess invocation for XEmacs.
+/* Old synchronous subprocess invocation for XEmacs.
    Copyright (C) 1985, 86, 87, 88, 93, 94, 95 Free Software Foundation, Inc.
 
 This file is part of XEmacs.
@@ -21,6 +21,16 @@ Boston, MA 02111-1307, USA.  */
 /* Synched up with: Mule 2.0, FSF 19.30. */
 /* Partly sync'ed with 19.36.4 */
 
+
+/* #### This ENTIRE file is only used in batch mode.
+
+   We only need two things to get rid of both this and ntproc.c:
+
+   -- my `stderr-proc' ws, which adds support for a separate stderr
+      in asynch. subprocesses. (it's a feature in `old-call-process-internal'.)
+   -- a noninteractive event loop that supports processes.
+*/
+
 #include <config.h>
 #include "lisp.h"
 
@@ -138,20 +148,6 @@ call_process_cleanup (Lisp_Object fdpid)
   return Qnil;
 }
 
-static Lisp_Object fork_error;
-#if 0 /* UNUSED */
-static void
-report_fork_error (char *string, Lisp_Object data)
-{
-  Lisp_Object errstring = lisp_strerror (errno);
-
-  fork_error = Fcons (build_string (string), Fcons (errstring, data));
-
-  /* terminate this branch of the fork, without closing stdin/out/etc. */
-  _exit (1);
-}
-#endif /* unused */
-
 DEFUN ("old-call-process-internal", Fold_call_process_internal, 1, MANY, 0, /*
 Call PROGRAM synchronously in separate process, with coding-system specified.
 Arguments are
@@ -202,7 +198,7 @@ If you quit, the process is killed with SIGINT, or SIGKILL if you
 #if defined (NO_SUBPROCESSES)
   /* Without asynchronous processes we cannot have BUFFER == 0.  */
   if (nargs >= 3 && !INTP (args[2]))
-    error ("Operating system cannot handle asynchronous subprocesses");
+    signal_error (Qunimplemented, "Operating system cannot handle asynchronous subprocesses", Qunbound);
 #endif /* NO_SUBPROCESSES */
 
   /* Do all filename munging before building new_argv because GC in
@@ -233,8 +229,8 @@ If you quit, the process is killed with SIGINT, or SIGKILL if you
     /* This is in FSF, but it breaks everything in the presence of
        ange-ftp-visited files, so away with it.  */
     if (NILP (Ffile_accessible_directory_p (current_dir)))
-      report_file_error ("Setting current directory",
-                         Fcons (current_buffer->directory, Qnil));
+      signal_error (Qprocess_error, "Setting current directory",
+		    current_buffer->directory);
 #endif /* 0 */
     NUNGCPRO;
   }
@@ -308,12 +304,12 @@ If you quit, the process is killed with SIGINT, or SIGKILL if you
   new_argv[max(nargs - 3,1)] = 0;
 
   if (NILP (path))
-    report_file_error ("Searching for program", Fcons (args[0], Qnil));
+    signal_error (Qprocess_error, "Searching for program", args[0]);
   new_argv[0] = (char *) XSTRING_DATA (path);
 
   filefd = open ((char *) XSTRING_DATA (infile), O_RDONLY | OPEN_BINARY, 0);
   if (filefd < 0)
-    report_file_error ("Opening process input file", Fcons (infile, Qnil));
+    report_process_error ("Opening process input file", infile);
 
   if (INTP (buffer))
     {
@@ -368,10 +364,9 @@ If you quit, the process is killed with SIGINT, or SIGKILL if you
 	if (fd1 >= 0)
 	  close (fd1);
 	errno = save_errno;
-	report_file_error ("Cannot open", Fcons(error_file, Qnil));
+	report_process_error ("Cannot open", error_file);
       }
 
-    fork_error = Qnil;
 #ifdef WIN32_NATIVE
     pid = child_setup (filefd, fd1, fd_error, new_argv,
                        (char *) XSTRING_DATA (current_dir));
@@ -424,9 +419,6 @@ If you quit, the process is killed with SIGINT, or SIGKILL if you
       close (fd1);
   }
 
-  if (!NILP (fork_error))
-    signal_error (Qfile_error, fork_error);
-
 #ifndef WIN32_NATIVE
   if (pid < 0)
     {
@@ -434,7 +426,7 @@ If you quit, the process is killed with SIGINT, or SIGKILL if you
       if (fd[0] >= 0)
 	close (fd[0]);
       errno = save_errno;
-      report_file_error ("Doing fork", Qnil);
+      report_process_error ("Doing fork", Qunbound);
     }
 #endif
 
@@ -787,7 +779,7 @@ child_setup (int in, int out, int err, char **new_argv,
 		  (const char* const*)env);
   if (cpid == -1)
     /* An error occurred while trying to spawn the process.  */
-    report_file_error ("Spawning child process", Qnil);
+    report_process_error ("Spawning child process", Qunbound);
   reset_standard_handles (in, out, err, handles);
   return cpid;
 #else /* not WIN32_NATIVE */
@@ -897,13 +889,40 @@ init_callproc (void)
   {
     /* Initialize shell-file-name from environment variables or best guess. */
 #ifdef WIN32_NATIVE
-    const char *shell = egetenv ("COMSPEC");
-    if (!shell) shell = "\\WINNT\\system32\\cmd.exe";
+    const char *shell = egetenv ("SHELL");
+    if (!shell) shell = egetenv ("COMSPEC");
+    /* Should never happen! */
+    if (!shell) shell = (GetVersion () & 0x80000000 ? "command" : "cmd");
 #else /* not WIN32_NATIVE */
     const char *shell = egetenv ("SHELL");
     if (!shell) shell = "/bin/sh";
 #endif
 
+#if 0 /* defined (WIN32_NATIVE) */
+    /* BAD BAD BAD.  We do not wanting to be passing an XEmacs-created
+       SHELL var down to some inferior Cygwin process, which might get
+       screwed up.
+	 
+       There are a few broken apps (eterm/term.el, eterm/tshell.el,
+       os-utils/terminal.el, texinfo/tex-mode.el) where this will
+       cause problems.  Those broken apps don't look at
+       shell-file-name, instead just at explicit-shell-file-name,
+       ESHELL and SHELL.  They are apparently attempting to borrow
+       what `M-x shell' uses, but that latter also looks at
+       shell-file-name.  What we want is for all of these apps to look
+       at shell-file-name, so that the user can change the value of
+       shell-file-name and everything will work out hunky-dorey.
+       */
+    
+    if (!egetenv ("SHELL"))
+      {
+	CBufbyte *faux_var = alloca_array (CBufbyte, 7 + strlen (shell));
+	sprintf (faux_var, "SHELL=%s", shell);
+	Vprocess_environment = Fcons (build_string (faux_var),
+				      Vprocess_environment);
+      }
+#endif /* 0 */
+
     Vshell_file_name = build_string (shell);
   }
 }
