@@ -1,5 +1,5 @@
 /* Console functions for mswindows.
-   Copyright (C) 1996, 2000 Ben Wing.
+   Copyright (C) 1996, 2000, 2001 Ben Wing.
 
 This file is part of XEmacs.
 
@@ -148,7 +148,7 @@ mswindows_ensure_console_allocated (void)
 
 static Lisp_Object
 mswindows_canonicalize_console_connection (Lisp_Object connection,
-					   Error_behavior errb)
+					   Error_Behavior errb)
 {
   /* Do not allow more than one mswindows device, by explicitly
      requiring that CONNECTION is nil, the only allowed connection in
@@ -156,7 +156,7 @@ mswindows_canonicalize_console_connection (Lisp_Object connection,
   if (!NILP (connection))
     {
       if (ERRB_EQ (errb, ERROR_ME))
-	signal_simple_error
+	invalid_argument
 	  ("Invalid (non-nil) connection for mswindows device/console",
 	   connection);
       else
@@ -168,7 +168,7 @@ mswindows_canonicalize_console_connection (Lisp_Object connection,
 
 static Lisp_Object
 mswindows_canonicalize_device_connection (Lisp_Object connection,
-					  Error_behavior errb)
+					  Error_Behavior errb)
 {
   return mswindows_canonicalize_console_connection (connection, errb);
 }
@@ -182,17 +182,15 @@ mswindows_hide_console (void)
 void
 mswindows_show_console (void)
 {
+  /* What I really want is for the console window to appear on top of other
+     windows, but NOT get the focus.  This seems hard-to-impossible under
+     Windows.  The following sequence seems to do the best possible, along
+     with keeping the console window on top when xemacs --help is used. */
   HWND hwnd = mswindows_get_console_hwnd ();
-  ShowWindow (hwnd, SW_SHOWNA);
-
-  /* I tried to raise the window to the top without activating
-     it, but this fails.  Apparently Windows just doesn't like
-     having the active window not be on top.  So instead, we
-     at least put it just below our own window, where part of it
-     will likely be seen. */
-  SetWindowPos (hwnd, GetForegroundWindow (), 0, 0, 0, 0,
-		SWP_NOSIZE | SWP_NOMOVE | SWP_NOSENDCHANGING |
-		SWP_NOACTIVATE);
+  HWND hwndf = GetFocus ();
+  ShowWindow (hwnd, SW_SHOW);
+  BringWindowToTop (hwnd);
+  SetFocus (hwndf);
 }
 
 static int mswindows_console_buffered = 0;
@@ -237,6 +235,37 @@ mswindows_windows9x_p (void)
   return GetVersion () & 0x80000000;
 }
 
+DEFUN ("mswindows-debugging-output", Fmswindows_debugging_output, 1, 1, 0, /*
+Write CHAR-OR-STRING to the Windows debugger, using OutputDebugString().
+This function can be used as the STREAM argument of Fprint() or the like.
+*/
+       (char_or_string))
+{
+  Extbyte *extstr;
+
+  if (STRINGP (char_or_string))
+    {
+      TO_EXTERNAL_FORMAT (LISP_STRING, char_or_string,
+			  C_STRING_ALLOCA, extstr,
+			  Qmswindows_tstr);
+      OutputDebugString (extstr);
+    }
+  else
+    {
+      Bufbyte str[MAX_EMCHAR_LEN + 1];
+      Bytecount len;
+
+      CHECK_CHAR_COERCE_INT (char_or_string);
+      len = set_charptr_emchar (str, XCHAR (char_or_string));
+      str[len] = '\0';
+      TO_EXTERNAL_FORMAT (C_STRING, str,
+			  C_STRING_ALLOCA, extstr,
+			  Qmswindows_tstr);
+      OutputDebugString (extstr);
+    }
+
+  return char_or_string;
+}
 
 #ifdef DEBUG_XEMACS
 
@@ -446,10 +475,7 @@ no effect.  */
   Extbyte *titleout = 0;
   UINT sty = 0;
 
-  if (noninteractive)
-    return Qcancel;
-
-  if (!CONSP (flags))
+  if (!LISTP (flags))
     {
       CHECK_SYMBOL (flags);
       flags = list1 (flags);
@@ -504,14 +530,14 @@ no effect.  */
 #undef FROB
 
       else
-	signal_simple_error ("Unrecognized flag", st);
+	invalid_constant ("Unrecognized flag", st);
     }
 
   {
     int retval = MessageBox (NULL, msgout, titleout, sty);
 
     if (retval == 0)
-      error ("Out of memory when calling `mswindows-message-box'");
+      out_of_memory ("When calling `mswindows-message-box'", Qunbound);
 
 #define FROB(sym, val) if (retval == val) return sym
     FROB (Qabort, IDABORT);
@@ -523,28 +549,81 @@ no effect.  */
     FROB (Qyes, IDYES);
 #undef FROB
     
-    signal_simple_error ("Unknown return value from MessageBox()",
-			 make_int (retval));
+    invalid_argument ("Unknown return value from MessageBox()",
+		      make_int (retval));
   }
 
   return Qnil;
 }
 
-void
-mswindows_output_last_error (char *frob)
+Lisp_Object
+mswindows_lisp_error (int errnum)
 {
-  LPVOID lpMsgBuf;
-  int errval = GetLastError();
+  LPTSTR lpMsgBuf;
+  Lisp_Object result;
+  Bufbyte *inres;
+  Bytecount len;
   
   FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER
 		 | FORMAT_MESSAGE_FROM_SYSTEM,
-		 NULL, errval,
+		 NULL, errnum,
+		 /* !!#### not Mule-correct */
 		 MAKELANGID (LANG_NEUTRAL, SUBLANG_DEFAULT),
+		 /* yeah, i'm casting a char ** to a char *.  ya gotta
+		    problem widdat? */
 		 (LPTSTR) &lpMsgBuf,
 		 0,
 		 NULL);
+
+  TO_INTERNAL_FORMAT (C_STRING, lpMsgBuf, ALLOCA, (inres, len),
+		      Qmswindows_tstr);
+  /* Messages tend to end with a period and newline */
+  if (len >= 3 && !bufbyte_strcmp (inres + len - 3, ".\r\n"))
+    len -= 3;
+  result = make_string (inres, len);
+  
+  LocalFree (lpMsgBuf);
+  return result;
+}
+
+void
+mswindows_output_last_error (char *frob)
+{
+  int errval = GetLastError ();
+  Lisp_Object errmess = mswindows_lisp_error (errval);
+  
   stderr_out ("last error during %s is %d: %s\n",
-	      frob, errval, (char*)lpMsgBuf);
+	      frob, errval, XSTRING_DATA (errmess));
+}
+
+static Lisp_Object
+msprinter_canonicalize_console_connection (Lisp_Object connection,
+					   Error_Behavior errb)
+{
+  /* If nil connection is specified, transform it into the name
+     of the default printer */
+  if (NILP (connection))
+    {
+      connection = msprinter_default_printer ();
+      if (NILP (connection))
+	{
+	  if (ERRB_EQ (errb, ERROR_ME))
+	    invalid_state ("There is no default printer in the system",
+			   Qunbound);
+	  else
+	    return Qunbound;
+	}
+    }
+
+  CHECK_STRING (connection);
+  return connection;
+}
+
+static Lisp_Object
+msprinter_canonicalize_device_connection (Lisp_Object connection,
+					  Error_Behavior errb)
+{
+  return msprinter_canonicalize_console_connection (connection, errb);
 }
 
 
@@ -555,40 +634,42 @@ mswindows_output_last_error (char *frob)
 void
 syms_of_console_mswindows (void)
 {
-  defsymbol (&Qabortretryignore, "abortretryignore");
-  defsymbol (&Qapplmodal, "applmodal");
-  defsymbol (&Qdefault_desktop_only, "default-desktop-only");
-  defsymbol (&Qdefbutton1, "defbutton1");
-  defsymbol (&Qdefbutton2, "defbutton2");
-  defsymbol (&Qdefbutton3, "defbutton3");
-  defsymbol (&Qdefbutton4, "defbutton4");
-  /* defsymbol (&Qhelp, "help"); */
-  defsymbol (&Qiconasterisk, "iconasterisk");
-  defsymbol (&Qiconexclamation, "iconexclamation");
-  defsymbol (&Qiconhand, "iconhand");
-  defsymbol (&Qiconinformation, "iconinformation");
-  defsymbol (&Qiconquestion, "iconquestion");
-  defsymbol (&Qiconstop, "iconstop");
-  /* defsymbol (&Qok, "ok"); */
-  defsymbol (&Qokcancel, "okcancel");
-  defsymbol (&Qretrycancel, "retrycancel");
-  /* defsymbol (&Qright, "right"); */
-  defsymbol (&Qrtlreading, "rtlreading");
-  defsymbol (&Qservice_notification, "service-notification");
-  defsymbol (&Qsetforeground, "setforeground");
-  defsymbol (&Qsystemmodal, "systemmodal");
-  defsymbol (&Qtaskmodal, "taskmodal");
-  defsymbol (&Qtopmost, "topmost");
-  defsymbol (&Qyesno, "yesno");
-  defsymbol (&Qyesnocancel, "yesnocancel");
+  DEFSUBR (Fmswindows_debugging_output);
 
-  /* defsymbol (&Qabort, "abort"); */
-  /* defsymbol (&Qcancel, "cancel"); */
-  /* defsymbol (&Qignore, "ignore"); */
-  /* defsymbol (&Qno, "no"); */
-  /* defsymbol (&Qok, "ok"); */
-  /* defsymbol (&Qretry, "retry"); */
-  /* defsymbol (&Qyes, "yes"); */
+  DEFSYMBOL (Qabortretryignore);
+  DEFSYMBOL (Qapplmodal);
+  DEFSYMBOL (Qdefault_desktop_only);
+  DEFSYMBOL (Qdefbutton1);
+  DEFSYMBOL (Qdefbutton2);
+  DEFSYMBOL (Qdefbutton3);
+  DEFSYMBOL (Qdefbutton4);
+  /* DEFSYMBOL (Qhelp); */
+  DEFSYMBOL (Qiconasterisk);
+  DEFSYMBOL (Qiconexclamation);
+  DEFSYMBOL (Qiconhand);
+  DEFSYMBOL (Qiconinformation);
+  DEFSYMBOL (Qiconquestion);
+  DEFSYMBOL (Qiconstop);
+  /* DEFSYMBOL (Qok); */
+  DEFSYMBOL (Qokcancel);
+  DEFSYMBOL (Qretrycancel);
+  /* DEFSYMBOL (Qright); */
+  DEFSYMBOL (Qrtlreading);
+  DEFSYMBOL (Qservice_notification);
+  DEFSYMBOL (Qsetforeground);
+  DEFSYMBOL (Qsystemmodal);
+  DEFSYMBOL (Qtaskmodal);
+  DEFSYMBOL (Qtopmost);
+  DEFSYMBOL (Qyesno);
+  DEFSYMBOL (Qyesnocancel);
+
+  /* DEFSYMBOL (Qabort); */
+  /* DEFSYMBOL (Qcancel); */
+  /* DEFSYMBOL (Qignore); */
+  /* DEFSYMBOL (Qno); */
+  /* DEFSYMBOL (Qok); */
+  /* DEFSYMBOL (Qretry); */
+  /* DEFSYMBOL (Qyes); */
 
   DEFSUBR (Fmswindows_message_box);
 }
@@ -609,6 +690,8 @@ console_type_create_mswindows (void)
 /*  CONSOLE_HAS_METHOD (mswindows, semi_canonicalize_device_connection); */
 
   INITIALIZE_CONSOLE_TYPE (msprinter, "msprinter", "console-msprinter-p");
+  CONSOLE_HAS_METHOD (msprinter, canonicalize_console_connection);
+  CONSOLE_HAS_METHOD (msprinter, canonicalize_device_connection);
 }
 
 void
