@@ -104,7 +104,6 @@ mark_console (Lisp_Object obj)
 
 #define MARKED_SLOT(x) mark_object (con->x)
 #include "conslots.h"
-#undef MARKED_SLOT
 
   /* Can be zero for Vconsole_defaults, Vconsole_local_symbols */
   if (con->conmeths)
@@ -123,8 +122,8 @@ print_console (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
   char buf[256];
 
   if (print_readably)
-    error ("printing unreadable object #<console %s 0x%x>",
-	   XSTRING_DATA (con->name), con->header.uid);
+    printing_unreadable_object ("#<console %s 0x%x>",
+				XSTRING_DATA (con->name), con->header.uid);
 
   sprintf (buf, "#<%s-console", !CONSOLE_LIVE_P (con) ? "dead" :
 	   CONSOLE_TYPE_NAME (con));
@@ -176,7 +175,7 @@ decode_console (Lisp_Object console)
 
 
 struct console_methods *
-decode_console_type (Lisp_Object type, Error_behavior errb)
+decode_console_type (Lisp_Object type, Error_Behavior errb)
 {
   int i;
 
@@ -184,7 +183,7 @@ decode_console_type (Lisp_Object type, Error_behavior errb)
     if (EQ (type, Dynarr_at (the_console_type_entry_dynarr, i).symbol))
       return Dynarr_at (the_console_type_entry_dynarr, i).meths;
 
-  maybe_signal_simple_error ("Invalid console type", type, Qconsole, errb);
+  maybe_invalid_constant ("Invalid console type", type, Qconsole, errb);
 
   return 0;
 }
@@ -281,10 +280,10 @@ time this function is called.
 	  Fselect_window (FRAME_SELECTED_WINDOW (f), Qnil);
 	}
       else
-	error ("Can't select console with no frames.");
+ invalid_operation ("Can't select console with no frames", Qunbound);
     }
   else
-    error ("Can't select a console with no devices");
+    invalid_operation ("Can't select a console with no devices", Qunbound);
   return Qnil;
 }
 
@@ -358,7 +357,7 @@ make_console (struct console *con)
 
 static Lisp_Object
 semi_canonicalize_console_connection (struct console_methods *meths,
-				      Lisp_Object name, Error_behavior errb)
+				      Lisp_Object name, Error_Behavior errb)
 {
   if (HAS_CONTYPE_METH_P (meths, semi_canonicalize_console_connection))
     return CONTYPE_METH (meths, semi_canonicalize_console_connection,
@@ -370,7 +369,7 @@ semi_canonicalize_console_connection (struct console_methods *meths,
 
 static Lisp_Object
 canonicalize_console_connection (struct console_methods *meths,
-				 Lisp_Object name, Error_behavior errb)
+				 Lisp_Object name, Error_Behavior errb)
 {
   if (HAS_CONTYPE_METH_P (meths, canonicalize_console_connection))
     return CONTYPE_METH (meths, canonicalize_console_connection,
@@ -461,9 +460,9 @@ name; in such a case, the first console found is returned.)
   if (NILP (console))
     {
       if (NILP (type))
-	signal_simple_error ("No such console", connection);
+	invalid_argument ("No such console", connection);
       else
-	signal_simple_error_2 ("No such console", type, connection);
+	invalid_argument_2 ("No such console", type, connection);
     }
   return console;
 }
@@ -580,6 +579,15 @@ find_nonminibuffer_frame_not_on_console (Lisp_Object console)
 			  LISP_TO_VOID (console));
 }
 
+static void
+nuke_all_console_slots (struct console *con, Lisp_Object zap)
+{
+  zero_lcrecord (con);
+
+#define MARKED_SLOT(x)	con->x = zap
+#include "conslots.h"
+}
+
 /* Delete console CON.
 
    If FORCE is non-zero, allow deletion of the only frame.
@@ -625,7 +633,7 @@ delete_console_internal (struct console *con, int force,
       if (down_we_go)
 	{
 	  if (!force)
-	    error ("Attempt to delete the only frame");
+	    invalid_operation ("Attempt to delete the only frame", Qunbound);
 	  else if (from_io_error)
 	    {
 	      /* Mayday mayday!  We're going down! */
@@ -719,7 +727,15 @@ delete_console_internal (struct console *con, int force,
   MAYBE_CONMETH (con, delete_console, (con));
 
   Vconsole_list = delq_no_quit (console, Vconsole_list);
+
   RESET_CHANGED_SET_FLAGS;
+
+  /* Nobody should be accessing anything in this object any more, and
+     making all Lisp_Objects Qnil allows for better GC'ing in case a
+     pointer to the dead console continues to hang around.  Zero all
+     other structs in case someone tries to access something through
+     them. */
+  nuke_all_console_slots (con, Qnil);
   con->conmeths = dead_console_methods;
 
   UNGCPRO;
@@ -1107,14 +1123,14 @@ syms_of_console (void)
   DEFSUBR (Fset_input_mode);
   DEFSUBR (Fcurrent_input_mode);
 
-  defsymbol (&Qconsolep, "consolep");
-  defsymbol (&Qconsole_live_p, "console-live-p");
+  DEFSYMBOL (Qconsolep);
+  DEFSYMBOL (Qconsole_live_p);
 
-  defsymbol (&Qcreate_console_hook, "create-console-hook");
-  defsymbol (&Qdelete_console_hook, "delete-console-hook");
+  DEFSYMBOL (Qcreate_console_hook);
+  DEFSYMBOL (Qdelete_console_hook);
 
-  defsymbol (&Qsuspend_hook, "suspend-hook");
-  defsymbol (&Qsuspend_resume_hook, "suspend-resume-hook");
+  DEFSYMBOL (Qsuspend_hook);
+  DEFSYMBOL (Qsuspend_resume_hook);
 }
 
 static const struct lrecord_description cte_description_1[] = {
@@ -1203,37 +1219,38 @@ One argument, the to-be-deleted console.
 #endif
 }
 
-/* The docstrings for DEFVAR_* are recorded externally by make-docfile.  */
-#define DEFVAR_CONSOLE_LOCAL_1(lname, field_name, forward_type, magicfun) do {	\
-  static const struct symbol_value_forward I_hate_C =				\
-  { /* struct symbol_value_forward */						\
-    { /* struct symbol_value_magic */						\
-      { /* struct lcrecord_header */						\
-	{ /* struct lrecord_header */						\
-	  lrecord_type_symbol_value_forward, /* lrecord_type_index */		\
-	  1, /* mark bit */							\
-	  1, /* c_readonly bit */						\
-	  1  /* lisp_readonly bit */						\
-	},									\
-	0, /* next */								\
-	0, /* uid  */								\
-	0  /* free */								\
-      },									\
-      &(console_local_flags.field_name), 					\
-      forward_type								\
-    },										\
-    magicfun									\
-  };										\
-										\
-  {										\
-    int offset = ((char *)symbol_value_forward_forward (&I_hate_C)		\
-		  - (char *)&console_local_flags);				\
-										\
-    defvar_magic (lname, &I_hate_C);						\
-										\
-    *((Lisp_Object *)(offset + (char *)XCONSOLE (Vconsole_local_symbols)))	\
-      = intern (lname);								\
-  }										\
+/* The docstrings for DEFVAR_* are recorded externally by make-docfile.  */ \
+#define DEFVAR_CONSOLE_LOCAL_1(lname, field_name, forward_type, magicfun)   \
+do {									    \
+  static const struct symbol_value_forward I_hate_C =			    \
+  { /* struct symbol_value_forward */					    \
+    { /* struct symbol_value_magic */					    \
+      { /* struct lcrecord_header */					    \
+	{ /* struct lrecord_header */					    \
+	  lrecord_type_symbol_value_forward, /* lrecord_type_index */	    \
+	  1, /* mark bit */						    \
+	  1, /* c_readonly bit */					    \
+	  1  /* lisp_readonly bit */					    \
+	},								    \
+	0, /* next */							    \
+	0, /* uid  */							    \
+	0  /* free */							    \
+      },								    \
+      &(console_local_flags.field_name),				    \
+      forward_type							    \
+    },									    \
+    magicfun								    \
+  };									    \
+									    \
+  {									    \
+    int offset = ((char *)symbol_value_forward_forward (&I_hate_C)	    \
+		  - (char *)&console_local_flags);			    \
+									    \
+    defvar_magic (lname, &I_hate_C);					    \
+									    \
+    *((Lisp_Object *)(offset + (char *)XCONSOLE (Vconsole_local_symbols)))  \
+      = intern (lname);							    \
+  }									    \
 } while (0)
 
 #define DEFVAR_CONSOLE_LOCAL_MAGIC(lname, field_name, magicfun)		\
@@ -1253,16 +1270,6 @@ One argument, the to-be-deleted console.
 #define DEFVAR_CONSOLE_DEFAULTS(lname, field_name)			\
 	DEFVAR_CONSOLE_DEFAULTS_MAGIC (lname, field_name, 0)
 
-static void
-nuke_all_console_slots (struct console *con, Lisp_Object zap)
-{
-  zero_lcrecord (con);
-
-#define MARKED_SLOT(x)	con->x = zap
-#include "conslots.h"
-#undef MARKED_SLOT
-}
-
 static void
 common_init_complex_vars_of_console (void)
 {
@@ -1391,7 +1398,7 @@ The `read-key-sequence' function replaces any subsequence bound by
 keymaps have no binding for the current key sequence but
 `function-key-map' binds a suffix of the sequence to a vector or string,
 `read-key-sequence' replaces the matching suffix with its binding, and
-continues with the new sequence.  See `key-binding'.
+continues with the new sequence.
 
 The events that come from bindings in `function-key-map' are not
 themselves looked up in `function-key-map'.
@@ -1465,7 +1472,6 @@ buffer's local map, and the minor mode keymaps and text property keymaps.
   if ((XINT (console_local_flags.slot) != -2 &&			\
          XINT (console_local_flags.slot) != -3)			\
       != !(NILP (XCONSOLE (Vconsole_local_symbols)->slot)))	\
-  ABORT ()
+  abort ()
 #include "conslots.h"
-#undef MARKED_SLOT
 }
