@@ -63,11 +63,34 @@ enum device_metrics
 extern const struct struct_description cted_description;
 extern const struct struct_description console_methods_description;
 
+
+/*
+ * Constants returned by device_implementation_flags_method
+ */
+
+/* Set when device uses pixel-based geometry */
+#define XDEVIMPF_PIXEL_GEOMETRY		0x00000001L
+
+/* Indicates that the device is a printer */
+#define XDEVIMPF_IS_A_PRINTER		0x00000002L
+
+/* Do not automatically redisplay this device */
+#define XDEVIMPF_NO_AUTO_REDISPLAY	0x00000004L
+
+/* Do not delete the device when last frame's gone */
+#define XDEVIMPF_FRAMELESS_OK		0x00000008L
+
+/* Do not preempt resiaply of frame or device once it starts */
+#define XDEVIMPF_DONT_PREEMPT_REDISPLAY 0x00000010L
+
 struct console_methods
 {
   const char *name;	/* Used by print_console, print_device, print_frame */
   Lisp_Object symbol;
   Lisp_Object predicate_symbol;
+  unsigned int flags;	/* Read-only implementation flags, set once upon
+			   console type creation. INITIALIZE_CONSOLE_TYPE sets
+			   this member to 0. */
 
   /* console methods */
   void (*init_console_method) (struct console *, Lisp_Object props);
@@ -75,15 +98,15 @@ struct console_methods
   int (*initially_selected_for_input_method) (struct console *);
   void (*delete_console_method) (struct console *);
   Lisp_Object (*semi_canonicalize_console_connection_method)
-    (Lisp_Object connection, Error_behavior errb);
+    (Lisp_Object connection, Error_Behavior errb);
   Lisp_Object (*semi_canonicalize_device_connection_method)
-    (Lisp_Object connection, Error_behavior errb);
+    (Lisp_Object connection, Error_Behavior errb);
   Lisp_Object (*canonicalize_console_connection_method)
-    (Lisp_Object connection, Error_behavior errb);
+    (Lisp_Object connection, Error_Behavior errb);
   Lisp_Object (*canonicalize_device_connection_method)
-    (Lisp_Object connection, Error_behavior errb);
+    (Lisp_Object connection, Error_Behavior errb);
   Lisp_Object (*device_to_console_connection_method)
-    (Lisp_Object connection, Error_behavior errb);
+    (Lisp_Object connection, Error_Behavior errb);
 
   /* device methods */
   void (*init_device_method) (struct device *, Lisp_Object props);
@@ -93,7 +116,6 @@ struct console_methods
   void (*asynch_device_change_method) (void);
   Lisp_Object (*device_system_metrics_method) (struct device *,
                                                enum device_metrics);
-  unsigned int (*device_implementation_flags_method) (void);
   Lisp_Object (*own_selection_method)(Lisp_Object selection_name,
                                       Lisp_Object selection_value,
                                       Lisp_Object how_to_add,
@@ -188,7 +210,7 @@ struct console_methods
   int (*initialize_color_instance_method) (Lisp_Color_Instance *,
 					   Lisp_Object name,
 					   Lisp_Object device,
-					   Error_behavior errb);
+					   Error_Behavior errb);
   void (*mark_color_instance_method) (Lisp_Color_Instance *);
   void (*print_color_instance_method) (Lisp_Color_Instance *,
 				       Lisp_Object printcharfun,
@@ -206,14 +228,14 @@ struct console_methods
   int (*initialize_font_instance_method) (Lisp_Font_Instance *,
 					  Lisp_Object name,
 					  Lisp_Object device,
-					  Error_behavior errb);
+					  Error_Behavior errb);
   void (*mark_font_instance_method) (Lisp_Font_Instance *);
   void (*print_font_instance_method) (Lisp_Font_Instance *,
 				      Lisp_Object printcharfun,
 				      int escapeflag);
   void (*finalize_font_instance_method) (Lisp_Font_Instance *);
   Lisp_Object (*font_instance_truename_method) (Lisp_Font_Instance *,
-						Error_behavior errb);
+						Error_Behavior errb);
   Lisp_Object (*font_instance_properties_method) (Lisp_Font_Instance *);
   Lisp_Object (*list_fonts_method) (Lisp_Object pattern,
 				    Lisp_Object device);
@@ -303,26 +325,12 @@ struct console_methods
 #endif
 };
 
-/*
- * Constants returned by device_implementation_flags_method
- */
-
-/* Set when device uses pixel-based geometry */
-#define XDEVIMPF_PIXEL_GEOMETRY	    0x00000001L
-
-/* Indicates that the device is a printer */
-#define XDEVIMPF_IS_A_PRINTER	    0x00000002L
-
-/* Do not automatically redisplay this device */
-#define XDEVIMPF_NO_AUTO_REDISPLAY  0x00000004L
-
-/* Do not delete the device when last frame's gone */
-#define XDEVIMPF_FRAMELESS_OK	    0x00000008L
-
+#define CONMETH_TYPE(meths) ((meths)->symbol)
+#define CONMETH_IMPL_FLAG(meths, f) ((meths)->flags & (f))
 
 #define CONSOLE_TYPE_NAME(c) ((c)->conmeths->name)
 #define CONSOLE_TYPE(c) ((c)->conmeths->symbol)
-#define CONMETH_TYPE(meths) ((meths)->symbol)
+#define CONSOLE_IMPL_FLAG(c, f) CONMETH_IMPL_FLAG ((c)->conmeths, (f))
 
 /******** Accessing / calling a console method *********/
 
@@ -407,6 +415,10 @@ struct console_methods * type##_console_methods
 #define CONSOLE_INHERITS_METHOD(type, fromtype, m) \
   (type##_console_methods->m##_method = fromtype##_##m)
 
+/* Define console type implementation flags */
+#define CONSOLE_IMPLEMENTATION_FLAGS(type, flg) \
+  (type##_console_methods->flags = flg)
+
 struct console
 {
   struct lcrecord_header header;
@@ -431,7 +443,6 @@ struct console
 
 #define MARKED_SLOT(x) Lisp_Object x
 #include "conslots.h"
-#undef MARKED_SLOT
 
   /* Where to store the next keystroke of the macro.
      Index into con->kbd_macro_builder. */
@@ -452,6 +463,7 @@ struct console
 DECLARE_LRECORD (console, struct console);
 #define XCONSOLE(x) XRECORD (x, console, struct console)
 #define XSETCONSOLE(x, p) XSETRECORD (x, p, console)
+#define wrap_console(p) wrap_record (p, console)
 #define CONSOLEP(x) RECORDP (x, console)
 #define CHECK_CONSOLE(x) CHECK_RECORD (x, console)
 #define CONCHECK_CONSOLE(x) CONCHECK_RECORD (x, console)
@@ -612,7 +624,7 @@ Lisp_Object make_console (struct console *c);
 void add_entry_to_console_type_list (Lisp_Object symbol,
 				     struct console_methods *type);
 struct console_methods *decode_console_type (Lisp_Object type,
-					     Error_behavior errb);
+					     Error_Behavior errb);
 void delete_console_internal (struct console *con, int force,
 			      int from_kill_emacs, int from_io_error);
 void io_error_delete_console (Lisp_Object console);
