@@ -1,7 +1,7 @@
 /* Primitive operations on Lisp data types for XEmacs Lisp interpreter.
    Copyright (C) 1985, 1986, 1988, 1992, 1993, 1994, 1995
    Free Software Foundation, Inc.
-   Copyright (C) 2000 Ben Wing.
+   Copyright (C) 2000, 2001 Ben Wing.
 
 This file is part of XEmacs.
 
@@ -41,19 +41,21 @@ Boston, MA 02111-1307, USA.  */
 Lisp_Object Qnil, Qt, Qquote, Qlambda, Qunbound;
 Lisp_Object Qerror_conditions, Qerror_message;
 Lisp_Object Qerror, Qquit, Qsyntax_error, Qinvalid_read_syntax;
-Lisp_Object Qlist_formation_error;
+Lisp_Object Qlist_formation_error, Qstructure_formation_error;
 Lisp_Object Qmalformed_list, Qmalformed_property_list;
 Lisp_Object Qcircular_list, Qcircular_property_list;
-Lisp_Object Qinvalid_argument, Qwrong_type_argument, Qargs_out_of_range;
+Lisp_Object Qinvalid_argument, Qinvalid_constant, Qwrong_type_argument;
+Lisp_Object Qargs_out_of_range;
 Lisp_Object Qwrong_number_of_arguments, Qinvalid_function, Qno_catch;
-Lisp_Object Qinternal_error, Qinvalid_state;
+Lisp_Object Qinternal_error, Qinvalid_state, Qstack_overflow, Qout_of_memory;
 Lisp_Object Qvoid_variable, Qcyclic_variable_indirection;
 Lisp_Object Qvoid_function, Qcyclic_function_indirection;
-Lisp_Object Qinvalid_operation, Qinvalid_change;
+Lisp_Object Qinvalid_operation, Qinvalid_change, Qprinting_unreadable_object;
 Lisp_Object Qsetting_constant;
 Lisp_Object Qediting_error;
 Lisp_Object Qbeginning_of_buffer, Qend_of_buffer, Qbuffer_read_only;
-Lisp_Object Qio_error, Qend_of_file;
+Lisp_Object Qio_error, Qfile_error, Qconversion_error, Qend_of_file;
+Lisp_Object Qtext_conversion_error;
 Lisp_Object Qarith_error, Qrange_error, Qdomain_error;
 Lisp_Object Qsingularity_error, Qoverflow_error, Qunderflow_error;
 Lisp_Object Qintegerp, Qnatnump, Qsymbolp;
@@ -65,6 +67,7 @@ Lisp_Object Qinteger_or_char_p, Qinteger_char_or_marker_p;
 Lisp_Object Qnumberp, Qnumber_char_or_marker_p;
 Lisp_Object Qbit_vectorp, Qbitp, Qcdr;
 
+Lisp_Object Qerror_lacks_explanatory_string;
 Lisp_Object Qfloatp;
 
 #ifdef DEBUG_XEMACS
@@ -113,7 +116,7 @@ wrong_type_argument (Lisp_Object predicate, Lisp_Object value)
 DOESNT_RETURN
 dead_wrong_type_argument (Lisp_Object predicate, Lisp_Object value)
 {
-  signal_error (Qwrong_type_argument, list2 (predicate, value));
+  signal_error_1 (Qwrong_type_argument, list2 (predicate, value));
 }
 
 DEFUN ("wrong-type-argument", Fwrong_type_argument, 2, 2, 0, /*
@@ -131,25 +134,27 @@ PREDICATE.  At that point, the gotten value is returned.
 DOESNT_RETURN
 c_write_error (Lisp_Object obj)
 {
-  signal_simple_error ("Attempt to modify read-only object (c)", obj);
+  signal_error (Qsetting_constant,
+		"Attempt to modify read-only object (c)", obj);
 }
 
 DOESNT_RETURN
 lisp_write_error (Lisp_Object obj)
 {
-  signal_simple_error ("Attempt to modify read-only object (lisp)", obj);
+  signal_error (Qsetting_constant,
+		"Attempt to modify read-only object (lisp)", obj);
 }
 
 DOESNT_RETURN
 args_out_of_range (Lisp_Object a1, Lisp_Object a2)
 {
-  signal_error (Qargs_out_of_range, list2 (a1, a2));
+  signal_error_1 (Qargs_out_of_range, list2 (a1, a2));
 }
 
 DOESNT_RETURN
 args_out_of_range_3 (Lisp_Object a1, Lisp_Object a2, Lisp_Object a3)
 {
-  signal_error (Qargs_out_of_range, list3 (a1, a2, a3));
+  signal_error_1 (Qargs_out_of_range, list3 (a1, a2, a3));
 }
 
 void
@@ -1008,8 +1013,6 @@ NUMBER may be an integer or a floating point number.
 */
        (number))
 {
-  char buffer[VALBITS];
-
   CHECK_INT_OR_FLOAT (number);
 
 #ifdef LISP_FLOAT_TYPE
@@ -1022,8 +1025,12 @@ NUMBER may be an integer or a floating point number.
     }
 #endif /* LISP_FLOAT_TYPE */
 
-  long_to_string (buffer, XINT (number));
-  return build_string (buffer);
+  {
+    char buffer[DECIMAL_PRINT_SIZE (long)];
+
+    long_to_string (buffer, XINT (number));
+    return build_string (buffer);
+  }
 }
 
 static int
@@ -1582,7 +1589,7 @@ static void
 print_weak_list (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
 {
   if (print_readably)
-    error ("printing unreadable object #<weak-list>");
+    printing_unreadable_object ("#<weak-list>");
 
   write_c_string ("#<weak-list ", printcharfun);
   print_internal (encode_weak_list_type (XWEAK_LIST (obj)->type),
@@ -1910,7 +1917,7 @@ decode_weak_list_type (Lisp_Object symbol)
   if (EQ (symbol, Qvalue_assoc)) return WEAK_LIST_VALUE_ASSOC;
   if (EQ (symbol, Qfull_assoc))  return WEAK_LIST_FULL_ASSOC;
 
-  signal_simple_error ("Invalid weak list type", symbol);
+  invalid_constant ("Invalid weak list type", symbol);
   return WEAK_LIST_SIMPLE; /* not reached */
 }
 
@@ -2011,7 +2018,7 @@ arith_error (int signo)
 {
   EMACS_REESTABLISH_SIGNAL (signo, arith_error);
   EMACS_UNBLOCK_SIGNAL (signo);
-  signal_error (Qarith_error, Qnil);
+  signal_error (Qarith_error, 0, Qunbound);
 }
 
 void
@@ -2025,9 +2032,9 @@ init_data_very_early (void)
   if (!initialized)
     return;
 #endif /* CANNOT_DUMP */
-  signal (SIGFPE, arith_error);
+  EMACS_SIGNAL (SIGFPE, arith_error);
 #ifdef uts
-  signal (SIGEMT, arith_error);
+  EMACS_SIGNAL (SIGEMT, arith_error);
 #endif /* uts */
 }
 
@@ -2046,28 +2053,25 @@ init_errors_once_early (void)
   DEFERROR (Qerror, "error", Qnil);
   DEFERROR_STANDARD (Qquit, Qnil);
 
-  DEFERROR (Qunimplemented, "Feature not yet implemented", Qerror);
-  DEFERROR_STANDARD (Qsyntax_error, Qerror);
-  DEFERROR_STANDARD (Qinvalid_read_syntax, Qsyntax_error);
-  DEFERROR_STANDARD (Qlist_formation_error, Qsyntax_error);
+  DEFERROR_STANDARD (Qinvalid_argument, Qerror);
 
-  /* Generated by list traversal macros */
+  DEFERROR_STANDARD (Qsyntax_error, Qinvalid_argument);
+  DEFERROR_STANDARD (Qinvalid_read_syntax, Qsyntax_error);
+  DEFERROR_STANDARD (Qstructure_formation_error, Qsyntax_error);
+  DEFERROR_STANDARD (Qlist_formation_error, Qstructure_formation_error);
   DEFERROR_STANDARD (Qmalformed_list, Qlist_formation_error);
   DEFERROR_STANDARD (Qmalformed_property_list, Qmalformed_list);
   DEFERROR_STANDARD (Qcircular_list, Qlist_formation_error);
   DEFERROR_STANDARD (Qcircular_property_list, Qcircular_list);
 
-  DEFERROR_STANDARD (Qinvalid_argument, Qerror);
   DEFERROR_STANDARD (Qwrong_type_argument, Qinvalid_argument);
   DEFERROR_STANDARD (Qargs_out_of_range, Qinvalid_argument);
   DEFERROR_STANDARD (Qwrong_number_of_arguments, Qinvalid_argument);
   DEFERROR_STANDARD (Qinvalid_function, Qinvalid_argument);
+  DEFERROR_STANDARD (Qinvalid_constant, Qinvalid_argument);
   DEFERROR (Qno_catch, "No catch for tag", Qinvalid_argument);
 
-  DEFERROR_STANDARD (Qinternal_error, Qerror);
-
-  DEFERROR (Qinvalid_state, "Properties or values have been set incorrectly",
-	    Qerror);
+  DEFERROR_STANDARD (Qinvalid_state, Qerror);
   DEFERROR (Qvoid_function, "Symbol's function definition is void",
 	    Qinvalid_state);
   DEFERROR (Qcyclic_function_indirection,
@@ -2078,22 +2082,27 @@ init_errors_once_early (void)
   DEFERROR (Qcyclic_variable_indirection,
 	    "Symbol's chain of variable indirections contains a loop",
 	    Qinvalid_state);
+  DEFERROR_STANDARD (Qstack_overflow, Qinvalid_state);
+  DEFERROR_STANDARD (Qinternal_error, Qinvalid_state);
+  DEFERROR_STANDARD (Qout_of_memory, Qinvalid_state);
 
-  DEFERROR (Qinvalid_operation,
-	    "Operation not allowed or error during operation", Qerror);
-  DEFERROR (Qinvalid_change, "Attempt to set properties or values incorrectly",
-	    Qinvalid_operation);
+  DEFERROR_STANDARD (Qinvalid_operation, Qerror);
+  DEFERROR_STANDARD (Qinvalid_change, Qinvalid_operation);
   DEFERROR (Qsetting_constant, "Attempt to set a constant symbol",
 	    Qinvalid_change);
+  DEFERROR_STANDARD (Qprinting_unreadable_object, Qinvalid_operation);
+  DEFERROR (Qunimplemented, "Feature not yet implemented", Qinvalid_operation);
 
-  DEFERROR (Qediting_error, "Invalid operation during editing",
-	    Qinvalid_operation);
+  DEFERROR_STANDARD (Qediting_error, Qinvalid_operation);
   DEFERROR_STANDARD (Qbeginning_of_buffer, Qediting_error);
   DEFERROR_STANDARD (Qend_of_buffer, Qediting_error);
   DEFERROR (Qbuffer_read_only, "Buffer is read-only", Qediting_error);
 
   DEFERROR (Qio_error, "IO Error", Qinvalid_operation);
-  DEFERROR (Qend_of_file, "End of file or stream", Qio_error);
+  DEFERROR_STANDARD (Qfile_error, Qio_error);
+  DEFERROR (Qend_of_file, "End of file or stream", Qfile_error);
+  DEFERROR_STANDARD (Qconversion_error, Qio_error);
+  DEFERROR_STANDARD (Qtext_conversion_error, Qconversion_error);
 
   DEFERROR (Qarith_error, "Arithmetic error", Qinvalid_operation);
   DEFERROR (Qrange_error, "Arithmetic range error", Qarith_error);
@@ -2133,6 +2142,7 @@ syms_of_data (void)
   DEFSYMBOL (Qnumberp);
   DEFSYMBOL (Qnumber_char_or_marker_p);
   DEFSYMBOL (Qcdr);
+  DEFSYMBOL (Qerror_lacks_explanatory_string);
   DEFSYMBOL_MULTIWORD_PREDICATE (Qweak_listp);
 
 #ifdef LISP_FLOAT_TYPE
