@@ -50,7 +50,6 @@ Boston, MA 02111-1307, USA.  */
 /* win32 DDE management library globals */
 #ifdef HAVE_DRAGNDROP
 DWORD mswindows_dde_mlid;
-int mswindows_dde_enable;
 HSZ mswindows_dde_service;
 HSZ mswindows_dde_topic_system;
 HSZ mswindows_dde_item_open;
@@ -180,18 +179,17 @@ mswindows_init_device (struct device *d, Lisp_Object props)
 #endif
 }
 
-#ifdef HAVE_DRAGNDROP
 static void
-mswindows_init_dde ()
+mswindows_finish_init_device (struct device *d, Lisp_Object props)
 {
   /* Initialize DDE management library and our related globals. We execute a
    * dde Open("file") by simulating a drop, so this depends on dnd support. */
+#ifdef HAVE_DRAGNDROP
 # if !(defined(CYGWIN) || defined(MINGW))
   CoInitialize (NULL);
 # endif
 
   mswindows_dde_mlid = 0;
-  mswindows_dde_enable = 0;
   DdeInitialize (&mswindows_dde_mlid, (PFNCALLBACK)mswindows_dde_callback,
 		 APPCMD_FILTERINITS|CBF_FAIL_SELFCONNECTIONS|CBF_FAIL_ADVISES|
 		 CBF_FAIL_POKES|CBF_FAIL_REQUESTS|CBF_SKIP_ALLNOTIFICATIONS,
@@ -204,27 +202,6 @@ mswindows_init_dde ()
   mswindows_dde_item_open = DdeCreateStringHandle (mswindows_dde_mlid,
 						   TEXT(MSWINDOWS_DDE_ITEM_OPEN), 0);
   DdeNameService (mswindows_dde_mlid, mswindows_dde_service, 0L, DNS_REGISTER);
-}
-#endif
-
-void 
-init_mswindows_very_early()
-{
-#ifdef HAVE_DRAGNDROP
-  /* Initializing dde when the device is created is too late - the
-     client will give up waiting.  Instead we initialize here and tell
-     the client we're too busy until the rest of initialization has
-     happened. */
-  mswindows_init_dde();
-#endif
-}
-
-static void
-mswindows_finish_init_device (struct device *d, Lisp_Object props)
-{
-#ifdef HAVE_DRAGNDROP
-  /* Tell pending clients we are ready. */
-  mswindows_dde_enable = 1;
 #endif
 }
 
@@ -479,9 +456,10 @@ msprinter_init_device (struct device *d, Lisp_Object props)
     signal_open_printer_error (d);
 
   pdm = (DEVMODE*) xmalloc (dm_size);
-  DocumentProperties (NULL, DEVICE_MSPRINTER_HPRINTER(d),
-		      printer_name, pdm,
-		      NULL, DM_OUT_BUFFER);
+  if (DocumentProperties (NULL, DEVICE_MSPRINTER_HPRINTER(d),
+			  printer_name, pdm,
+			  NULL, DM_OUT_BUFFER) < 0)
+    signal_open_printer_error (d);
 
   assert (DEVMODE_SIZE (pdm) <= dm_size);
 
@@ -594,7 +572,7 @@ sync_printer_with_devmode (struct device* d, DEVMODE* devmode_in,
 	     Nothing wrong on the Windows side, just forge a unique
 	     connection name. Use the memory address of d as a unique
 	     suffix. */
-	  char* new_connext = alloca (strlen (devname + 11));
+	  Extbyte *new_connext = (Extbyte *) alloca (strlen (devname + 11));
 	  sprintf (new_connext, "%s:%X", devname, d->header.uid);
 	  new_connection = build_ext_string (devname, Qmswindows_tstr);
 	}
@@ -638,7 +616,7 @@ handle_devmode_changes (Lisp_Devmode *ldm, HGLOBAL hDevNames, HGLOBAL hDevMode)
   DEVMODE* devmode = (DEVMODE*) GlobalLock (hDevMode);
 
   /* Size and name may have changed */
-  ldm->devmode = xrealloc (ldm->devmode, DEVMODE_SIZE (devmode));
+  ldm->devmode = (DEVMODE *) xrealloc (ldm->devmode, DEVMODE_SIZE (devmode));
   if (new_name)
     {
       if (ldm->printer_name)
@@ -653,7 +631,7 @@ handle_devmode_changes (Lisp_Devmode *ldm, HGLOBAL hDevNames, HGLOBAL hDevMode)
       if (!sync_printer_with_devmode (d, devmode, ldm->devmode, new_name))
 	{
 	  global_free_2_maybe (hDevNames, hDevMode);
-	  error ("Printer device initialization I/O error, device deleted.");
+	  signal_error (Qio_error, "Printer device initialization I/O error, device deleted", Qunbound);
 	}
     }
   else
@@ -781,17 +759,16 @@ mswindows_handle_print_dialog_box (struct frame *f, Lisp_Object keys)
 	    else if (EQ (value, Qpages))
 	      flags |= PD_PAGENUMS;
 	    else if (!EQ (value, Qall))
-	      invalid_argument ("Invalid value for :selected-page-button",
-				value);
+	      invalid_constant ("for :selected-page-button", value);
 	  }
 	else
-	  syntax_error ("Unrecognized print-dialog keyword", key);
+	  invalid_constant ("Unrecognized print-dialog keyword", key);
       }
   }
 
   if ((UNBOUNDP (device) && UNBOUNDP (settings)) ||
       (!UNBOUNDP (device) && !UNBOUNDP (settings)))
-    syntax_error ("Exactly one of :device and :printer-settings must be given",
+    sferror ("Exactly one of :device and :printer-settings must be given",
 		  keys);
 
   return print_dialog_worker (!UNBOUNDP (device) ? device : settings, flags);
@@ -804,25 +781,25 @@ mswindows_get_default_margin (Lisp_Object prop)
   if (EQ (prop, Qright_margin)) return 1440;
   if (EQ (prop, Qtop_margin)) return 720;
   if (EQ (prop, Qbottom_margin)) return 720;
-  ABORT ();
+  abort ();
   return 0;
 }
 
 static int
-plist_get_margin (Lisp_Object plist, Lisp_Object prop, int mm_p)
+plist_get_margin (Lisp_Object plist, Lisp_Object prop)
 {
   Lisp_Object val =
     Fplist_get (plist, prop, make_int (mswindows_get_default_margin (prop)));
   if (!INTP (val))
     invalid_argument ("Margin value must be an integer", val);
 
-  return MulDiv (XINT (val), mm_p ? 254 : 100, 144);
+  return MulDiv (XINT (val), 100, 144);
 }
 
 static Lisp_Object
 plist_set_margin (Lisp_Object plist, Lisp_Object prop, int margin, int mm_p)
 {
-  Lisp_Object val = make_int (MulDiv (margin, 144, mm_p ? 254 : 100));
+  Lisp_Object val = make_int (MulDiv (margin, 144, mm_p ? 2450 : 100));
   return Fcons (prop, Fcons (val, plist));
 }
 
@@ -851,13 +828,13 @@ mswindows_handle_page_setup_dialog_box (struct frame *f, Lisp_Object keys)
 	    plist = value;
 	  }
 	else
-	  syntax_error ("Unrecognized page-setup dialog keyword", key);
+	  invalid_constant ("Unrecognized page-setup dialog keyword", key);
       }
   }
 
   if ((UNBOUNDP (device) && UNBOUNDP (settings)) ||
       (!UNBOUNDP (device) && !UNBOUNDP (settings)))
-    syntax_error ("Exactly one of :device and :printer-settings must be given",
+    sferror ("Exactly one of :device and :printer-settings must be given",
 		  keys);
 
   if (UNBOUNDP (device))
@@ -866,21 +843,15 @@ mswindows_handle_page_setup_dialog_box (struct frame *f, Lisp_Object keys)
   {
     Lisp_Devmode *ldm = decode_devmode (device);
     PAGESETUPDLG pd;
-    TCHAR measure[2];
-    int data;
- 
-    GetLocaleInfo (LOCALE_USER_DEFAULT, LOCALE_IMEASURE,
-		   measure, sizeof(measure));
-    data = (strcmp (measure, "0"));
 
     memset (&pd, 0, sizeof (pd));
     pd.lStructSize = sizeof (pd);
     pd.hwndOwner = mswindows_get_selected_frame_hwnd ();
     pd.Flags = PSD_MARGINS;
-    pd.rtMargin.left   = plist_get_margin (plist, Qleft_margin, !data);
-    pd.rtMargin.top    = plist_get_margin (plist, Qtop_margin, !data);
-    pd.rtMargin.right  = plist_get_margin (plist, Qright_margin, !data);
-    pd.rtMargin.bottom = plist_get_margin (plist, Qbottom_margin, !data);
+    pd.rtMargin.left   = plist_get_margin (plist, Qleft_margin);
+    pd.rtMargin.top    = plist_get_margin (plist, Qtop_margin);
+    pd.rtMargin.right  = plist_get_margin (plist, Qright_margin);
+    pd.rtMargin.bottom = plist_get_margin (plist, Qbottom_margin);
     pd.hDevMode = devmode_to_hglobal (ldm);
 
     if (!PageSetupDlg (&pd))
@@ -965,11 +936,12 @@ Return value is the previously selected settings object.
 	DocumentProperties (NULL, DEVICE_MSPRINTER_HPRINTER(d),
 			    DEVICE_MSPRINTER_NAME(d), NULL, NULL, 0);
       if (dm_size <= 0)
-	invalid_operation ("Unable to specialize settings, printer error",
-			   device);
+	signal_error (Qio_error,
+		      "Unable to specialize settings, printer error",
+		      device);
 
       assert (XDEVMODE_SIZE (ldm) <= dm_size);
-      ldm->devmode = xrealloc (ldm->devmode, dm_size);
+      ldm->devmode = (DEVMODE *) xrealloc (ldm->devmode, dm_size);
     }
 
   /* If we bail out on signal here, no damage is done, except that
@@ -977,7 +949,9 @@ Return value is the previously selected settings object.
      hold a larger one - not a big deal */
   if (!sync_printer_with_devmode (d, ldm->devmode, ldm->devmode,
 				  ldm->printer_name))
-    error ("Printer device initialization I/O error, device deleted.");
+    signal_error (Qio_error,
+		  "Printer device initialization I/O error, device deleted",
+		  Qunbound);
 
   if (ldm->printer_name == NULL)
     ldm->printer_name = xstrdup (DEVICE_MSPRINTER_NAME(d));
@@ -1034,7 +1008,9 @@ Return value is the currently selected settings object.
   if (!sync_printer_with_devmode (d, ldm_new->devmode,
 				  ldm_current->devmode,
 				  ldm_new->printer_name))
-    error ("Printer device initialization I/O error, device deleted.");
+    signal_error (Qio_error,
+		  "Printer device initialization I/O error, device deleted",
+		  Qunbound);
 
   if (ldm_new->printer_name != NULL)
     {
@@ -1057,8 +1033,8 @@ print_devmode (Lisp_Object obj, Lisp_Object printcharfun,
   char buf[100];
   Lisp_Devmode *dm = XDEVMODE (obj);
   if (print_readably)
-    error ("printing unreadable object #<msprinter-settings 0x%x>",
-           dm->header.uid);
+    printing_unreadable_object ("#<msprinter-settings 0x%x>",
+				dm->header.uid);
   write_c_string ("#<msprinter-settings", printcharfun);
   if (dm->printer_name)
     {
@@ -1246,7 +1222,7 @@ values.  Return value is nil if there are no printers installed.
   if (GetLastError () != ERROR_INSUFFICIENT_BUFFER)
     signal_enum_printer_error ();
 
-  data_buf = alloca (bytes_needed);
+  data_buf = (BYTE *) alloca (bytes_needed);
   ok = EnumPrinters (enum_flags, NULL, enum_level, data_buf, bytes_needed,
 		     &bytes_needed, &num_printers);
   if (!ok)
