@@ -73,20 +73,13 @@ Boston, MA 02111-1307, USA.  */
 #include "lisp.h"
 
 #include "buffer.h"
+#include "nt.h"
 #include "regex.h"
 
 #include "sysdir.h"
 #include "sysproc.h"
 #include "sysfile.h"
-
-#include <time.h>
-
-#include <winsock.h>		/* To make nt.h happy */
-#include "nt.h"		/* For prototypes */
-
-#if ROUND_FILE_SIZES > 0
-#include <math.h>		/* for floor() */
-#endif
+#include "sysfloat.h"
 
 
 static int mswindows_ls_sort_case_insensitive;
@@ -96,9 +89,8 @@ Lisp_Object		Qmswindows_insert_directory;
 
 extern Lisp_Object	Vmswindows_downcase_file_names;	/* in device-msw.c */
 
-
-
-enum mswindows_sortby {
+enum mswindows_sortby
+{
   MSWINDOWS_SORT_BY_NAME,
   MSWINDOWS_SORT_BY_NAME_NOCASE,
   MSWINDOWS_SORT_BY_MOD_DATE,
@@ -227,7 +219,7 @@ mswindows_get_files (char *dirfile, int nowild, Lisp_Object pattern,
 	      if (fh == INVALID_HANDLE_VALUE)
 		{
 		  report_file_error ("Opening directory",
-				     list1(build_string(dirfile)));
+				     build_string (dirfile));
 		}
 	    }
 	  else
@@ -240,7 +232,7 @@ mswindows_get_files (char *dirfile, int nowild, Lisp_Object pattern,
 		    }
 		  FindClose(fh);
 		  report_file_error ("Reading directory",
-				     list1(build_string(dirfile)));
+				     build_string (dirfile));
 		}
 	    }
 
@@ -428,9 +420,8 @@ switches do not contain `d', so that a full listing is expected.
        (file, switches, wildcard, full_directory_p))
 {
   Lisp_Object		result, handler, wildpat, fns, basename;
-  char			*filename;
   char			*switchstr;
-  int			len, nfiles, i;
+  int			nfiles, i;
   int			hide_system, hide_dot, reverse, display_size;
   WIN32_FIND_DATA	*files, **sorted_files;
   enum mswindows_sortby	sort_by;
@@ -495,28 +486,11 @@ switches do not contain `d', so that a full listing is expected.
 	    }
 	}
 
-      /*
-       * Sometimes we get ".../foo* /" as FILE (without the space).
-       * While the shell and `ls' don't mind, we certainly do,
-       * because it makes us think there is no wildcard, only a
-       * directory name.
-       */
-      if (!NILP(Fstring_match(build_string("[[?*]"), file, Qnil, Qnil)))
-	{
-	  wildcard = Qt;
-	  filename = XSTRING_DATA(file);
-	  len = strlen(filename);
-	  if (len > 0 && (filename[len - 1] == '\\' ||
-			  filename[len - 1] == '/'))
-	    {
-	      filename[len - 1] = '\0';
-	    }
-	  file = build_string(filename);
-	}
       if (!NILP(wildcard))
 	{
 	  Lisp_Object	newfile;
 
+	  file = Fdirectory_file_name (file);
 	  basename = Ffile_name_nondirectory(file);
 	  fns = intern("wildcard-to-regexp");
 	  wildpat = call1(fns, basename);
@@ -628,7 +602,7 @@ switches do not contain `d', so that a full listing is expected.
 void
 syms_of_dired_mswindows (void)
 {
-  defsymbol (&Qmswindows_insert_directory, "mswindows-insert-directory");
+  DEFSYMBOL (Qmswindows_insert_directory);
 
   DEFSUBR (Fmswindows_insert_directory);
 }
