@@ -35,6 +35,10 @@ Boston, MA 02111-1307, USA.  */
 #include "opaque.h"
 #include "syntax.h"
 
+#ifdef WIN32_NATIVE
+#include "syswindows.h"
+#endif
+
 Lisp_Object Vcompletion_ignored_extensions;
 Lisp_Object Qdirectory_files;
 Lisp_Object Qfile_name_completion;
@@ -122,10 +126,9 @@ If FILES-ONLY is the symbol t, then only the "files" in the directory
      unwind-protection in case of error, but now there is.  */
   d = opendir ((char *) XSTRING_DATA (directory));
   if (!d)
-    report_file_error ("Opening directory", list1 (directory));
+    report_file_error ("Opening directory", directory);
 
-  /* #### In Matt's code, this was Qt.  Why? */
-  regex_match_object = Qnil;
+  regex_match_object = Qt;
   regex_emacs_buffer = current_buffer;
 
   record_unwind_protect (close_directory_unwind, make_opaque_ptr ((void *)d));
@@ -218,6 +221,11 @@ is not applied to the names of directories.
 DEFUN ("file-name-all-completions", Ffile_name_all_completions, 2, 2, 0, /*
 Return a list of all completions of PARTIAL-FILENAME in DIRECTORY.
 These are all file names in DIRECTORY which begin with PARTIAL-FILENAME.
+
+File names which end with any member of `completion-ignored-extensions'
+are not considered as possible completions for PARTIAL-FILENAME unless
+there is no other possible completion. `completion-ignored-extensions'
+is not applied to the names of directories.
 */
        (partial_filename, directory))
 {
@@ -335,7 +343,7 @@ file_name_completion (Lisp_Object file, Lisp_Object directory, int all_flag,
     {
       d = opendir ((char *) XSTRING_DATA (Fdirectory_file_name (directory)));
       if (!d)
-	report_file_error ("Opening directory", list1 (directory));
+	report_file_error ("Opening directory", directory);
       XCAR (locative) = make_opaque_ptr ((void *)d);
 
       /* Loop reading blocks */
@@ -506,11 +514,6 @@ file_name_completion (Lisp_Object file, Lisp_Object directory, int all_flag,
 }
 
 
-
-/* The *pwent() functions do not exist on NT.  #### The NT equivalent
-   is NetUserEnum(), and rewriting to use it is not hard.*/
-#ifndef  WIN32_NATIVE
-
 static Lisp_Object user_name_completion (Lisp_Object user,
                                          int all_flag,
                                          int *uniq);
@@ -585,8 +588,10 @@ free_user_cache (struct user_cache *cache)
 static Lisp_Object
 user_name_completion_unwind (Lisp_Object cache_incomplete_p)
 {
+#ifndef WIN32_NATIVE
   endpwent ();
   speed_up_interrupts ();
+#endif
 
   if (! NILP (XCAR (cache_incomplete_p)))
     free_user_cache (&user_cache);
@@ -626,13 +631,21 @@ user_name_completion (Lisp_Object user, int all_flag, int *uniq)
 
   if (!user_cache.user_names)
     {
+#ifndef WIN32_NATIVE
       struct passwd *pwd;
+#else
+      DWORD entriesread;
+      DWORD totalentries;
+      DWORD resume_handle = 0;
+#endif
+
       Lisp_Object cache_incomplete_p = noseeum_cons (Qt, Qnil);
       int speccount = specpdl_depth ();
 
+      record_unwind_protect (user_name_completion_unwind, cache_incomplete_p);
+#ifndef WIN32_NATIVE
       slow_down_interrupts ();
       setpwent ();
-      record_unwind_protect (user_name_completion_unwind, cache_incomplete_p);
       while ((pwd = getpwent ()))
         {
           QUIT;
@@ -645,6 +658,69 @@ user_name_completion (Lisp_Object user, int all_flag, int *uniq)
 			      Qnative);
 	  user_cache.length++;
         }
+#else
+      if (xNetUserEnum)
+	{
+	  do
+	    {
+	      USER_INFO_0 *bufptr;
+	      NET_API_STATUS status_status_statui_statum_statu;
+	      int i;
+
+	      QUIT;
+	      status_status_statui_statum_statu =
+		xNetUserEnum (NULL, 0, 0, (LPBYTE *) &bufptr, 1024,
+			      &entriesread, &totalentries, &resume_handle);
+	      if (status_status_statui_statum_statu != NERR_Success &&
+		  status_status_statui_statum_statu != ERROR_MORE_DATA)
+		invalid_operation ("Error enumerating users",
+				   make_int (GetLastError ()));
+	      for (i = 0; i < entriesread; i++)
+		{
+		  int nout =
+		    WideCharToMultiByte (CP_ACP, WC_COMPOSITECHECK,
+					 bufptr[i].usri0_name,
+					 -1, 0, 0, "~", 0);
+		  void *outp = alloca (nout);
+		  WideCharToMultiByte (CP_ACP, WC_COMPOSITECHECK,
+				       bufptr[i].usri0_name, -1,
+				       (LPSTR) outp, nout, "~", 0);
+		  DO_REALLOC (user_cache.user_names, user_cache.size,
+			      user_cache.length + 1, struct user_name);
+		  TO_INTERNAL_FORMAT (C_STRING, outp,
+				      MALLOC,
+				      (user_cache.
+				       user_names[user_cache.length].ptr,
+				       user_cache.
+				       user_names[user_cache.length].len),
+				      Qmswindows_tstr);
+		  user_cache.length++;
+		}
+	      xNetApiBufferFree (bufptr);
+	    }
+	  while (entriesread != totalentries);
+	}
+      else /* Win 9x */
+	{
+	  Extbyte name[2 * (UNLEN + 1)];
+	  DWORD length = sizeof (name);
+	  
+	  if (GetUserName (name, &length))
+	    {
+	      DO_REALLOC (user_cache.user_names, user_cache.size,
+			  user_cache.length + 1, struct user_name);
+	      TO_INTERNAL_FORMAT (C_STRING, name,
+				  MALLOC,
+				  (user_cache.
+				   user_names[user_cache.length].ptr,
+				   user_cache.
+				   user_names[user_cache.length].len),
+				  Qmswindows_tstr);
+	      user_cache.length++;
+	    }
+	}
+#endif
+
       XCAR (cache_incomplete_p) = Qnil;
       unbind_to (speccount, Qnil);
 
@@ -709,7 +785,6 @@ user_name_completion (Lisp_Object user, int all_flag, int *uniq)
     return Qt;
   return Fsubstring (bestmatch, Qzero, make_int (bestmatchsize));
 }
-#endif   /* ! defined WIN32_NATIVE */
 
 
 Lisp_Object
@@ -736,9 +811,6 @@ make_directory_hash_table (const char *path)
     return Qnil;
 }
 
-#if 0
-/* ... never used ... should use list2 directly anyway ... */
-/* NOTE: This function can never return a negative value. */
 Lisp_Object
 wasteful_word_to_lisp (unsigned int item)
 {
@@ -748,7 +820,6 @@ wasteful_word_to_lisp (unsigned int item)
   XCDR (cons) = Fcons (XCDR (cons), Qnil);
   return cons;
 }
-#endif
 
 DEFUN ("file-attributes", Ffile_attributes, 1, 1, 0, /*
 Return a list of attributes of file FILENAME.
@@ -835,9 +906,9 @@ If file does not exist, returns nil.
   values[1] = make_int (s.st_nlink);
   values[2] = make_int (s.st_uid);
   values[3] = make_int (s.st_gid);
-  values[4] = make_time (s.st_atime);
-  values[5] = make_time (s.st_mtime);
-  values[6] = make_time (s.st_ctime);
+  values[4] = wasteful_word_to_lisp (s.st_atime);
+  values[5] = wasteful_word_to_lisp (s.st_mtime);
+  values[6] = wasteful_word_to_lisp (s.st_ctime);
   values[7] = make_int ((EMACS_INT) s.st_size);
   /* If the size is out of range, give back -1.  */
   /* #### Fix when Emacs gets bignums! */
@@ -871,19 +942,17 @@ If file does not exist, returns nil.
 void
 syms_of_dired (void)
 {
-  defsymbol (&Qdirectory_files, "directory-files");
-  defsymbol (&Qfile_name_completion, "file-name-completion");
-  defsymbol (&Qfile_name_all_completions, "file-name-all-completions");
-  defsymbol (&Qfile_attributes, "file-attributes");
+  DEFSYMBOL (Qdirectory_files);
+  DEFSYMBOL (Qfile_name_completion);
+  DEFSYMBOL (Qfile_name_all_completions);
+  DEFSYMBOL (Qfile_attributes);
 
   DEFSUBR (Fdirectory_files);
   DEFSUBR (Ffile_name_completion);
   DEFSUBR (Ffile_name_all_completions);
-#ifndef  WIN32_NATIVE
   DEFSUBR (Fuser_name_completion);
   DEFSUBR (Fuser_name_completion_1);
   DEFSUBR (Fuser_name_all_completions);
-#endif
   DEFSUBR (Ffile_attributes);
 }
 
@@ -894,7 +963,8 @@ vars_of_dired (void)
 *Completion ignores filenames ending in any string in this list.
 This variable does not affect lists of possible completions,
 but does affect the commands that actually do completions.
-It is used by the function `file-name-completion'.
+It is used by the functions `file-name-completion' and
+`file-name-all-completions'.
 */ );
   Vcompletion_ignored_extensions = Qnil;
 }
