@@ -130,7 +130,7 @@ parse_off_posnum (const Bufbyte *start, const Bufbyte *end, int *returned_num)
   while (start != end && isdigit (*start))
     {
       if ((size_t) (arg_ptr - arg_convert) >= sizeof (arg_convert) - 1)
-	error ("Format converter number too large");
+ syntax_error ("Format converter number too large", Qunbound);
       *arg_ptr++ = *start++;
     }
   *arg_ptr = '\0';
@@ -142,10 +142,10 @@ parse_off_posnum (const Bufbyte *start, const Bufbyte *end, int *returned_num)
 #define NEXT_ASCII_BYTE(ch)					\
   do {								\
     if (fmt == fmt_end)						\
-      error ("Premature end of format string");			\
+      syntax_error ("Premature end of format string", Qunbound);			\
     ch = *fmt;							\
     if (ch >= 0200)						\
-      error ("Non-ASCII character in format converter spec");	\
+      syntax_error ("Non-ASCII character in format converter spec", Qunbound);	\
     fmt++;							\
   } while (0)
 
@@ -296,7 +296,7 @@ parse_doprnt_spec (const Bufbyte *format, Bytecount format_length)
 	    }
 
 	  if (!strchr (valid_converters, ch))
-	    error ("Invalid converter character %c", ch);
+	    syntax_error ("Invalid converter character", make_char (ch));
 	  spec.converter = ch;
 	}
 
@@ -356,7 +356,7 @@ get_doprnt_args (printf_spec_dynarr *specs, va_list vargs)
 	}
 
       if (j == Dynarr_length (specs))
-	error ("No conversion spec for argument %d", i);
+ syntax_error ("No conversion spec for argument", make_int (i));
 
       ch = spec->converter;
 
@@ -425,7 +425,7 @@ emacs_doprnt_1 (Lisp_Object stream, const Bufbyte *format_nonreloc,
     {
       /* allow too many args for string, but not too few */
       if (nargs < get_args_needed (specs))
-	signal_error (Qwrong_number_of_arguments,
+	signal_error_1 (Qwrong_number_of_arguments,
 		      list3 (Qformat,
 			     make_int (nargs),
 			     !NILP (format_reloc) ? format_reloc :
@@ -493,7 +493,7 @@ emacs_doprnt_1 (Lisp_Object stream, const Bufbyte *format_nonreloc,
 	}
 
       if (largs && (spec->argnum < 1 || spec->argnum > nargs))
-	error ("Invalid repositioning argument %d", spec->argnum);
+ syntax_error ("Invalid repositioning argument", make_int (spec->argnum));
 
       else if (ch == 'S' || ch == 's')
 	{
@@ -558,8 +558,8 @@ emacs_doprnt_1 (Lisp_Object stream, const Bufbyte *format_nonreloc,
 		obj = make_int (XCHAR (obj));
 	      if (!INT_OR_FLOATP (obj))
 		{
-		  error ("format specifier %%%c doesn't match argument type",
-			 ch);
+		  syntax_error ("format specifier %%%c doesn't match argument type",
+			 make_char (ch));
 		}
 	      else if (strchr (double_converters, ch))
 		arg.d = XFLOATINT (obj);
@@ -585,7 +585,7 @@ emacs_doprnt_1 (Lisp_Object stream, const Bufbyte *format_nonreloc,
 	      a = (Emchar) arg.l;
 
 	      if (!valid_char_p (a))
-		error ("invalid character value %d to %%c spec", a);
+	 syntax_error ("invalid character value %d to %%c spec", make_char (a));
 
 	      charlen = set_charptr_emchar (charbuf, a);
 	      doprnt_1 (stream, charbuf, charlen, spec->minwidth,
@@ -598,8 +598,7 @@ emacs_doprnt_1 (Lisp_Object stream, const Bufbyte *format_nonreloc,
 	      char *text_to_print =
 		alloca_array (char, 32 +
 			      max (spec->minwidth,
-				   (EMACS_INT)
-				    max (sizeof (double), sizeof (long)) * 3 +
+				   max (sizeof (double), sizeof (long)) * 3 +
 				   max (spec->precision, 0)));
 	      char constructed_spec[100];
 	      char *p = constructed_spec;
@@ -615,11 +614,15 @@ emacs_doprnt_1 (Lisp_Object stream, const Bufbyte *format_nonreloc,
 	      if (spec->zero_flag)   *p++ = '0';
 
 	      if (spec->minwidth >= 0)
-		p = long_to_string (p, spec->minwidth);
+		{
+		  long_to_string (p, spec->minwidth);
+		  p += strlen (p);
+		}
 	      if (spec->precision >= 0)
 		{
 		  *p++ = '.';
-		  p = long_to_string (p, spec->precision);
+		  long_to_string (p, spec->precision);
+		  p += strlen (p);
 		}
 	      
 	      if (strchr (double_converters, ch))
