@@ -29,7 +29,6 @@ Boston, MA 02111-1307, USA.  */
 #include "sysfile.h"
 #include "console-stream.h"
 #include "dumper.h"
-#include "sysdep.h"
 
 #ifdef WIN32_NATIVE
 #include "nt.h"
@@ -45,7 +44,7 @@ Boston, MA 02111-1307, USA.  */
 
 typedef struct
 {
-  void *varaddress;
+  const void *varaddress;
   size_t size;
 } pdump_opaque;
 
@@ -85,7 +84,7 @@ static Lisp_Object_ptr_dynarr *pdump_weak_object_chains;
 /* Mark SIZE bytes at non-heap address VARADDRESS for dumping as is,
    without any bit-twiddling. */
 void
-dump_add_opaque (void *varaddress, size_t size)
+dump_add_opaque (const void *varaddress, size_t size)
 {
   pdump_opaque info;
   info.varaddress = varaddress;
@@ -415,7 +414,7 @@ pdump_get_indirect_count (EMACS_INT code,
 			  const struct lrecord_description *idesc,
 			  const void *idata)
 {
-  EMACS_INT count = 0;		/* initialize to shut up GCC */
+  EMACS_INT count;
   const void *irdata;
 
   int line = XD_INDIRECT_VAL (code);
@@ -440,7 +439,7 @@ pdump_get_indirect_count (EMACS_INT code,
       stderr_out ("Unsupported count type : %d (line = %d, code=%ld)\n",
 		  idesc[line].type, line, (long)code);
       pdump_backtrace ();
-      ABORT ();
+      abort ();
     }
   count += delta;
   return count;
@@ -540,7 +539,7 @@ pdump_register_sub (const void *data, const struct lrecord_description *desc, in
 	default:
 	  stderr_out ("Unsupported dump type : %d\n", desc[pos].type);
 	  pdump_backtrace ();
-	  ABORT ();
+	  abort ();
 	};
     }
 }
@@ -569,7 +568,7 @@ pdump_register_object (Lisp_Object obj)
       if (me>65536)
 	{
 	  stderr_out ("Backtrace overflow, loop ?\n");
-	  ABORT ();
+	  abort ();
 	}
       backtrace[me].obj = objh;
       backtrace[me].position = 0;
@@ -604,7 +603,7 @@ pdump_register_struct (const void *data,
       if (me>65536)
 	{
 	  stderr_out ("Backtrace overflow, loop ?\n");
-	  ABORT ();
+	  abort ();
 	}
       backtrace[me].obj = 0;
       backtrace[me].position = 0;
@@ -717,7 +716,7 @@ pdump_dump_data (pdump_entry_list_elt *elt,
 		  }
 		default:
 		  stderr_out ("Unsupported dump type : %d\n", desc[pos].type);
-		  ABORT ();
+		  abort ();
 		}
 	    }
 	}
@@ -795,7 +794,7 @@ pdump_reloc_one (void *data, EMACS_INT delta,
 	  }
 	default:
 	  stderr_out ("Unsupported dump type : %d\n", desc[pos].type);
-	  ABORT ();
+	  abort ();
 	};
     }
 }
@@ -819,7 +818,7 @@ pdump_scan_by_alignment (void (*f)(pdump_entry_list_elt *,
 
   for (align = ALIGNOF (max_align_t); align; align>>=1)
     {
-      size_t i;
+      int i;
       pdump_entry_list_elt *elt;
 
       for (i=0; i<lrecord_type_count; i++)
@@ -844,7 +843,7 @@ pdump_scan_by_alignment (void (*f)(pdump_entry_list_elt *,
 static void
 pdump_dump_root_struct_ptrs (void)
 {
-  size_t i;
+  int i;
   size_t count = Dynarr_length (pdump_root_struct_ptrs);
   pdump_static_pointer *data = alloca_array (pdump_static_pointer, count);
   for (i = 0; i < count; i++)
@@ -871,7 +870,7 @@ pdump_dump_opaques (void)
 static void
 pdump_dump_rtables (void)
 {
-  size_t i;
+  int i;
   pdump_entry_list_elt *elt;
   pdump_reloc_table rt;
 
@@ -923,7 +922,7 @@ pdump_dump_root_objects (void)
 {
   size_t count = (Dynarr_length (pdump_root_objects) +
 		  Dynarr_length (pdump_weak_object_chains));
-  EMACS_INT i;
+  size_t i;
 
   PDUMP_WRITE_ALIGNED (size_t, count);
   PDUMP_ALIGN_OUTPUT (pdump_static_Lisp_Object);
@@ -935,7 +934,9 @@ pdump_dump_root_objects (void)
       obj.value   = * obj.address;
 
       if (POINTER_TYPE_P (XTYPE (obj.value)))
-	obj.value = wrap_object ((void *) pdump_get_entry (XRECORD_LHEADER (obj.value))->save_offset);
+	obj.value =
+	  wrap_pointer_1 ((void *) pdump_get_entry (XRECORD_LHEADER
+						    (obj.value))->save_offset);
 
       PDUMP_WRITE (pdump_static_Lisp_Object, obj);
     }
@@ -961,7 +962,7 @@ pdump_dump_root_objects (void)
 
 	  obj.value = *(Lisp_Object *)(desc[pos].offset + (char *)(XRECORD_LHEADER (obj.value)));
 	}
-      obj.value = wrap_object ((void *) elt->save_offset);
+      obj.value = wrap_pointer_1 ((void *) elt->save_offset);
 
       PDUMP_WRITE (pdump_static_Lisp_Object, obj);
     }
@@ -970,7 +971,7 @@ pdump_dump_root_objects (void)
 void
 pdump (void)
 {
-  size_t i;
+  int i;
   Lisp_Object t_console, t_device, t_frame;
   int none;
   pdump_header header;
@@ -991,7 +992,7 @@ pdump (void)
   t_frame   = Vterminal_frame;   Vterminal_frame   = Qnil;
   t_device  = Vterminal_device;  Vterminal_device  = Qnil;
 
-  dump_add_opaque ((void *) &lrecord_implementations_table,
+  dump_add_opaque (&lrecord_implementations_table,
 		   lrecord_type_count * sizeof (lrecord_implementations_table[0]));
   dump_add_opaque (&lrecord_markers,
 		   lrecord_type_count * sizeof (lrecord_markers[0]));
@@ -1028,7 +1029,7 @@ pdump (void)
   if (!none)
     return;
 
-  for (i=0; i<(size_t)Dynarr_length (pdump_root_struct_ptrs); i++)
+  for (i=0; i<Dynarr_length (pdump_root_struct_ptrs); i++)
     {
       pdump_root_struct_ptr info = Dynarr_at (pdump_root_struct_ptrs, i);
       pdump_register_struct (*(info.ptraddress), info.desc, 1);
@@ -1115,7 +1116,7 @@ pdump_load_finish (void)
   for (i=0; i<header->nb_opaques; i++)
     {
       pdump_opaque info = PDUMP_READ_ALIGNED (p, pdump_opaque);
-      memcpy (info.varaddress, p, info.size);
+      memcpy ((void*)info.varaddress, p, info.size);
       p += info.size;
     }
 
@@ -1148,7 +1149,7 @@ pdump_load_finish (void)
       pdump_static_Lisp_Object obj = PDUMP_READ (p, pdump_static_Lisp_Object);
 
       if (POINTER_TYPE_P (XTYPE (obj.value)))
-	obj.value = wrap_object ((char *) XPNTR (obj.value) + delta);
+	obj.value = wrap_pointer_1 ((char *) XPNTR (obj.value) + delta);
 
       (* obj.address) = obj.value;
     }
@@ -1365,11 +1366,9 @@ pdump_file_try (char *exe_path)
 int
 pdump_load (const char *argv0)
 {
-  char exe_path[PATH_MAX], real_exe_path[PATH_MAX];
+  char exe_path[PATH_MAX];
 #ifdef WIN32_NATIVE
   GetModuleFileName (NULL, exe_path, PATH_MAX);
-  /* #### urk, needed for xrealpath() below */
-  Vdirectory_sep_char = make_char ('\\');
 #else /* !WIN32_NATIVE */
   char *w;
   const char *dir, *p;
@@ -1415,17 +1414,13 @@ pdump_load (const char *argv0)
 	    }
 	  strcpy (w, name);
 
-	  /* Check that exe_path is executable and not a directory */
-#undef access /* avoid !@#$%^& encapsulated access */
-#undef stat   /* avoid !@#$%^& encapsulated stat */
-	  {
-	    struct stat statbuf;
-	    if (access (exe_path, X_OK) == 0
-		&& stat (exe_path, &statbuf) == 0
-		&& ! S_ISDIR (statbuf.st_mode))
-	      break;
-	  }
+	  /* ### #$%$#^$^@%$^#%@$ ! */
+#ifdef access
+#undef access
+#endif
 
+	  if (!access (exe_path, X_OK))
+	    break;
 	  if (!*p)
 	    {
 	      /* Oh well, let's have some kind of default */
@@ -1437,11 +1432,7 @@ pdump_load (const char *argv0)
     }
 #endif /* WIN32_NATIVE */
 
-  /* Save exe_path because pdump_file_try() modifies it */
-  strcpy(real_exe_path, exe_path);
-  if (pdump_file_try (exe_path)
-      || (xrealpath(real_exe_path, real_exe_path)
-	  && pdump_file_try (real_exe_path)))
+  if (pdump_file_try (exe_path))
     {
       pdump_load_finish ();
       return 1;
