@@ -462,6 +462,7 @@ typedef struct Lisp_Timeout Lisp_Timeout;
 DECLARE_LRECORD (timeout, Lisp_Timeout);
 #define XTIMEOUT(x) XRECORD (x, timeout, Lisp_Timeout)
 #define XSETTIMEOUT(x, p) XSETRECORD (x, p, timeout)
+#define wrap_timeout(p) wrap_record (p, timeout)
 #define TIMEOUTP(x) RECORDP (x, timeout)
 #define CHECK_TIMEOUT(x) CHECK_RECORD (x, timeout)
 #define CONCHECK_TIMEOUT(x) CONCHECK_RECORD (x, timeout)
@@ -496,6 +497,7 @@ struct Lisp_Event
 DECLARE_LRECORD (event, Lisp_Event);
 #define XEVENT(x) XRECORD (x, event, Lisp_Event)
 #define XSETEVENT(x, p) XSETRECORD (x, p, event)
+#define wrap_event(p) wrap_record (p, event)
 #define EVENTP(x) RECORDP (x, event)
 #define CHECK_EVENT(x) CHECK_RECORD (x, event)
 #define CONCHECK_EVENT(x) CONCHECK_RECORD (x, event)
@@ -626,11 +628,13 @@ int event_stream_generate_wakeup (unsigned int milliseconds,
 				  Lisp_Object function,
 				  Lisp_Object object,
 				  int async_p);
+int event_stream_resignal_wakeup (int interval_id, int async_p,
+				  Lisp_Object *function, Lisp_Object *object);
 void event_stream_disable_wakeup (int id, int async_p);
-void event_stream_deal_with_async_timeout (int interval_id);
 
-int event_stream_add_async_timeout (EMACS_TIME thyme);
-void event_stream_remove_async_timeout (int id);
+/* from signal.c */
+int signal_add_async_interval_timeout (EMACS_TIME thyme);
+void signal_remove_async_interval_timeout (int id);
 
 /* from event-stream.c -- focus sanity */
 extern int focus_follows_mouse;
