@@ -294,7 +294,7 @@ DEFINE_LRECORD_IMPLEMENTATION_WITH_PROPS ("face", face,
 
 static int
 face_name_validate (Lisp_Object keyword, Lisp_Object value,
-		    Error_behavior errb)
+		    Error_Behavior errb)
 {
   if (ERRB_EQ (errb, ERROR_ME))
     {
@@ -306,7 +306,7 @@ face_name_validate (Lisp_Object keyword, Lisp_Object value,
 }
 
 static int
-face_validate (Lisp_Object data, Error_behavior errb)
+face_validate (Lisp_Object data, Error_Behavior errb)
 {
   int name_seen = 0;
   Lisp_Object valw = Qnil;
@@ -327,13 +327,13 @@ face_validate (Lisp_Object data, Error_behavior errb)
 
   if (!name_seen)
     {
-      maybe_error (Qface, errb, "No face name given");
+      maybe_sferror ("No face name given", Qunbound, Qface, errb);
       return 0;
     }
 
   if (NILP (Ffind_face (valw)))
     {
-      maybe_signal_simple_error ("No such face", valw, Qface, errb);
+      maybe_invalid_argument ("No such face", valw, Qface, errb);
       return 0;
     }
 
@@ -555,7 +555,7 @@ update_faces_inheritance (Lisp_Object face, Lisp_Object property)
 Lisp_Object
 face_property_matching_instance (Lisp_Object face, Lisp_Object property,
 				 Lisp_Object charset, Lisp_Object domain,
-				 Error_behavior errb, int no_fallback,
+				 Error_Behavior errb, int no_fallback,
 				 Lisp_Object depth)
 {
   Lisp_Object retval =
@@ -636,7 +636,7 @@ face instead of returning nil.
   Lisp_Object face = Ffind_face (name);
 
   if (NILP (face))
-    signal_simple_error ("No such face", name);
+    invalid_argument ("No such face", name);
   return face;
 }
 
@@ -1828,10 +1828,10 @@ syms_of_faces (void)
   INIT_LRECORD_IMPLEMENTATION (face);
 
   /* Qdefault, Qwidget, Qleft_margin, Qright_margin defined in general.c */
-  defsymbol (&Qmodeline, "modeline");
-  defsymbol (&Qgui_element, "gui-element");
-  defsymbol (&Qtext_cursor, "text-cursor");
-  defsymbol (&Qvertical_divider, "vertical-divider");
+  DEFSYMBOL (Qmodeline);
+  DEFSYMBOL (Qgui_element);
+  DEFSYMBOL (Qtext_cursor);
+  DEFSYMBOL (Qvertical_divider);
 
   DEFSUBR (Ffacep);
   DEFSUBR (Ffind_face);
@@ -1842,22 +1842,22 @@ syms_of_faces (void)
   DEFSUBR (Fmake_face);
   DEFSUBR (Fcopy_face);
 
-  defsymbol (&Qfacep, "facep");
-  defsymbol (&Qforeground, "foreground");
-  defsymbol (&Qbackground, "background");
+  DEFSYMBOL (Qfacep);
+  DEFSYMBOL (Qforeground);
+  DEFSYMBOL (Qbackground);
   /* Qfont defined in general.c */
-  defsymbol (&Qdisplay_table, "display-table");
-  defsymbol (&Qbackground_pixmap, "background-pixmap");
-  defsymbol (&Qunderline, "underline");
-  defsymbol (&Qstrikethru, "strikethru");
+  DEFSYMBOL (Qdisplay_table);
+  DEFSYMBOL (Qbackground_pixmap);
+  DEFSYMBOL (Qunderline);
+  DEFSYMBOL (Qstrikethru);
   /* Qhighlight, Qreverse defined in general.c */
-  defsymbol (&Qdim, "dim");
-  defsymbol (&Qblinking, "blinking");
+  DEFSYMBOL (Qdim);
+  DEFSYMBOL (Qblinking);
 
-  defsymbol (&Qinit_face_from_resources, "init-face-from-resources");
-  defsymbol (&Qinit_global_faces, "init-global-faces");
-  defsymbol (&Qinit_device_faces, "init-device-faces");
-  defsymbol (&Qinit_frame_faces, "init-frame-faces");
+  DEFSYMBOL (Qinit_face_from_resources);
+  DEFSYMBOL (Qinit_global_faces);
+  DEFSYMBOL (Qinit_device_faces);
+  DEFSYMBOL (Qinit_frame_faces);
 }
 
 void
@@ -1942,6 +1942,10 @@ complex_vars_of_faces (void)
   {
     Lisp_Object fg_fb = Qnil, bg_fb = Qnil;
 
+#ifdef HAVE_GTK
+    fg_fb = acons (list1 (Qgtk), build_string ("black"), fg_fb);
+    bg_fb = acons (list1 (Qgtk), build_string ("white"), bg_fb);
+#endif
 #ifdef HAVE_X_WINDOWS
     fg_fb = acons (list1 (Qx), build_string ("black"), fg_fb);
     bg_fb = acons (list1 (Qx), build_string ("white"), bg_fb);
@@ -1964,7 +1968,15 @@ complex_vars_of_faces (void)
      support is compiled in. */
   {
     Lisp_Object inst_list = Qnil;
-#ifdef HAVE_X_WINDOWS
+
+#if defined(HAVE_X_WINDOWS) || defined(HAVE_GTK)
+    /* This is kind of ugly because stephen wanted this to be CPP
+    ** identical to the old version, at least for the initial
+    ** checkin
+    **
+    ** WMP March 9, 2001
+    */
+    
     /* The same gory list from x-faces.el.
        (#### Perhaps we should remove the stuff from x-faces.el
        and only depend on this stuff here?  That should work.)
@@ -1989,11 +2001,20 @@ complex_vars_of_faces (void)
     };
     const char **fontptr;
 
+#ifdef HAVE_X_WINDOWS
     for (fontptr = fonts + countof(fonts) - 1; fontptr >= fonts; fontptr--)
       inst_list = Fcons (Fcons (list1 (Qx), build_string (*fontptr)),
 			 inst_list);
 #endif /* HAVE_X_WINDOWS */
 
+#ifdef HAVE_GTK
+    for (fontptr = fonts + countof(fonts) - 1; fontptr >= fonts; fontptr--)
+      inst_list = Fcons (Fcons (list1 (Qgtk), build_string (*fontptr)),
+			 inst_list);
+#endif /* HAVE_GTK */
+#endif /* HAVE_X_WINDOWS || HAVE_GTK */
+
+
 #ifdef HAVE_TTY
     inst_list = Fcons (Fcons (list1 (Qtty), build_string ("normal")),
 		       inst_list);
@@ -2001,16 +2022,16 @@ complex_vars_of_faces (void)
 #ifdef HAVE_MS_WINDOWS
     /* Fixedsys does not exist for printers */
     inst_list = Fcons (Fcons (list1 (Qmsprinter),
-		       build_string ("Courier:Regular:10::Western")), inst_list);
+			      build_string ("Courier:Regular:10::Western")), inst_list);
     inst_list = Fcons (Fcons (list1 (Qmsprinter),
-		       build_string ("Courier New:Regular:10::Western")), inst_list);
+			      build_string ("Courier New:Regular:10::Western")), inst_list);
 
     inst_list = Fcons (Fcons (list1 (Qmswindows),
-		       build_string ("Fixedsys:Regular:9::Western")), inst_list);
+			      build_string ("Fixedsys:Regular:9::Western")), inst_list);
     inst_list = Fcons (Fcons (list1 (Qmswindows),
-		       build_string ("Courier:Regular:10::Western")), inst_list);
+			      build_string ("Courier:Regular:10::Western")), inst_list);
     inst_list = Fcons (Fcons (list1 (Qmswindows),
-		       build_string ("Courier New:Regular:10::Western")), inst_list);
+			      build_string ("Courier New:Regular:10::Western")), inst_list);
 #endif /* HAVE_MS_WINDOWS */
     set_specifier_fallback (Fget (Vdefault_face, Qfont, Qnil), inst_list);
   }
@@ -2039,6 +2060,13 @@ complex_vars_of_faces (void)
   {
     Lisp_Object fg_fb = Qnil, bg_fb = Qnil;
 
+#ifdef HAVE_GTK
+    /* We need to put something in there, or error checking gets
+       #%!@#ed up before the styles are set, which override the
+       fallbacks. */
+    fg_fb = acons (list1 (Qgtk), build_string ("black"), fg_fb);
+    bg_fb = acons (list1 (Qgtk), build_string ("Gray80"), bg_fb);
+#endif
 #ifdef HAVE_X_WINDOWS
     fg_fb = acons (list1 (Qx), build_string ("black"), fg_fb);
     bg_fb = acons (list1 (Qx), build_string ("Gray80"), bg_fb);
