@@ -1,19 +1,19 @@
 /* Copyright (C) 1985, 86, 87, 93, 94, 96 Free Software Foundation, Inc.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU Emacs; see the file COPYING.  If not, write to
+along with XEmacs; see the file COPYING.  If not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
@@ -492,9 +492,8 @@ syms_of_filelock (void)
   DEFSUBR (Flock_buffer);
   DEFSUBR (Ffile_locked_p);
 
-  defsymbol (&Qask_user_about_supersession_threat,
-             "ask-user-about-supersession-threat");
-  defsymbol (&Qask_user_about_lock, "ask-user-about-lock");
+  DEFSYMBOL (Qask_user_about_supersession_threat);
+  DEFSYMBOL (Qask_user_about_lock);
 }
 
 void
