@@ -391,30 +391,26 @@ setup_context_cache (struct buffer *buf, Bufpos pt)
   }
 }
 
-/* GCC 2.95.4 seems to need the casts */
 #define SYNTAX_START_STYLE(c1, c2)					\
-  ((enum comment_style)                                                 \
-   (SYNTAX_CODES_MATCH_START_P (c1, c2, SYNTAX_COMMENT_STYLE_A) ?	\
+  (SYNTAX_CODES_MATCH_START_P (c1, c2, SYNTAX_COMMENT_STYLE_A) ?	\
    comment_style_a :							\
    SYNTAX_CODES_MATCH_START_P (c1, c2, SYNTAX_COMMENT_STYLE_B) ?	\
    comment_style_b :							\
-   comment_style_none))
+   comment_style_none)
 
 #define SYNTAX_END_STYLE(c1, c2)				\
-  ((enum comment_style)                                         \
-   (SYNTAX_CODES_MATCH_END_P (c1, c2, SYNTAX_COMMENT_STYLE_A) ?	\
+  (SYNTAX_CODES_MATCH_END_P (c1, c2, SYNTAX_COMMENT_STYLE_A) ?	\
    comment_style_a :						\
    SYNTAX_CODES_MATCH_END_P (c1, c2, SYNTAX_COMMENT_STYLE_B) ?	\
    comment_style_b :						\
-   comment_style_none))
+   comment_style_none)
 
-#define SINGLE_SYNTAX_STYLE(c)					\
-  ((enum comment_style)                                         \
-   (SYNTAX_CODE_MATCHES_1CHAR_P (c, SYNTAX_COMMENT_STYLE_A) ?	\
-   comment_style_a :						\
-   SYNTAX_CODE_MATCHES_1CHAR_P (c, SYNTAX_COMMENT_STYLE_B) ?	\
-   comment_style_b :						\
-   comment_style_none))
+#define SINGLE_SYNTAX_STYLE(c)						\
+      (SYNTAX_CODE_MATCHES_1CHAR_P (c, SYNTAX_COMMENT_STYLE_A) ?	\
+       comment_style_a :						\
+       SYNTAX_CODE_MATCHES_1CHAR_P (c, SYNTAX_COMMENT_STYLE_B) ?	\
+       comment_style_b :						\
+       comment_style_none)
 
 /* Set up context_cache for position PT in BUF. */
 
@@ -432,7 +428,6 @@ find_context (struct buffer *buf, Bufpos pt)
   setup_context_cache (buf, pt);
   pt = context_cache.cur_point;
 
-  SCS_STATISTICS_SET_FUNCTION (scs_find_context);
   SETUP_SYNTAX_CACHE (pt - 1, 1);
   if (pt > BUF_BEGV (buf))
     {
@@ -515,7 +510,7 @@ find_context (struct buffer *buf, Bufpos pt)
 	      context_cache.context = context_comment;
 	      context_cache.ccontext = ccontext_none;
 	      context_cache.style = SINGLE_SYNTAX_STYLE (syncode);
-	      if (context_cache.style == comment_style_none) ABORT ();
+	      if (context_cache.style == comment_style_none) abort ();
 	    }
 	  break;
 
@@ -607,7 +602,7 @@ find_context (struct buffer *buf, Bufpos pt)
 	{
 	  context_cache.ccontext = ccontext_start2;
 	  context_cache.style = SYNTAX_START_STYLE (prev_syncode, syncode);
-	  if (context_cache.style == comment_style_none) ABORT ();
+	  if (context_cache.style == comment_style_none) abort ();
 	}
       else if ((SYNTAX_CODE_COMMENT_BITS (syncode) &
 		SYNTAX_FIRST_CHAR_START) &&
@@ -635,31 +630,26 @@ find_context (struct buffer *buf, Bufpos pt)
       else if ((SYNTAX_CODE_COMMENT_BITS (syncode) &
 		SYNTAX_FIRST_CHAR_END) &&
 	       context_cache.context == context_block_comment &&
-#if 0
-	       /* #### pre-Matt code had: */
-	       (context_cache.style ==
-		SYNTAX_END_STYLE (c, BUF_FETCH_CHAR (buf, pt+1))) &&
-	       /* why do these differ here?! */
-#endif
 	       context_cache.style == SINGLE_SYNTAX_STYLE (syncode) &&
 	       (context_cache.ccontext == ccontext_start2 ||
 		context_cache.ccontext == ccontext_end1))
-	/* check end1, to detect a repetition of the first char of a
-	   comment-end sequence. ie, '/xxx foo xxx/' or '/xxx foo x/',
-	   where 'x' = '*' -- mct */
+	/* #### is it right to check for end1 here?? 
+	   yes, because this might be a repetition of the first char
+	   of a comment-end sequence. ie, '/xxx foo xxx/' or
+	   '/xxx foo x/', where 'x' = '*' -- mct */
 	{
-	  if (context_cache.style == comment_style_none) ABORT ();
+	  if (context_cache.style == comment_style_none) abort ();
 	  context_cache.ccontext = ccontext_end1;
 	}
 
       else if (context_cache.ccontext == ccontext_start1)
 	{
-	  if (context_cache.context != context_none) ABORT ();
+	  if (context_cache.context != context_none) abort ();
 	  context_cache.ccontext = ccontext_none;
 	}
       else if (context_cache.ccontext == ccontext_end1)
 	{
-	  if (context_cache.context != context_block_comment) ABORT ();
+	  if (context_cache.context != context_block_comment) abort ();
 	  context_cache.context = context_none;
 	  context_cache.ccontext = ccontext_start2;
 	}
@@ -668,7 +658,7 @@ find_context (struct buffer *buf, Bufpos pt)
 	  context_cache.context == context_none)
 	{
 	  context_cache.context = context_block_comment;
-	  if (context_cache.style == comment_style_none) ABORT ();
+	  if (context_cache.style == comment_style_none) abort ();
 	}
       else if (context_cache.ccontext == ccontext_none &&
 	       context_cache.context == context_block_comment)
@@ -691,7 +681,7 @@ context_to_symbol (enum syntactic_context context)
     case context_block_comment:		return Qblock_comment;
     case context_generic_comment:	return Qblock_comment;
     case context_generic_string:	return Qstring;
-    default: ABORT (); return Qnil; /* suppress compiler warning */
+    default: abort (); return Qnil; /* suppress compiler warning */
     }
 }
 
@@ -822,9 +812,9 @@ WARNING: this may alter match-data.
 void
 syms_of_font_lock (void)
 {
-  defsymbol (&Qcomment, "comment");
-  defsymbol (&Qblock_comment, "block-comment");
-  defsymbol (&Qbeginning_of_defun, "beginning-of-defun");
+  DEFSYMBOL (Qcomment);
+  DEFSYMBOL (Qblock_comment);
+  DEFSYMBOL (Qbeginning_of_defun);
 
   DEFSUBR (Fbuffer_syntactic_context);
   DEFSUBR (Fbuffer_syntactic_context_depth);
