@@ -27,7 +27,6 @@ Boston, MA 02111-1307, USA.  */
 #include <config.h>
 #include "lisp.h"
 
-#include "elhash.h"
 #include "console-gtk.h"
 #include "ui-gtk.h"
 #include "glyphs-gtk.h"
@@ -55,6 +54,7 @@ Boston, MA 02111-1307, USA.  */
 #define INTERNAL_BORDER_WIDTH 0
 
 #define TRANSIENT_DATA_IDENTIFIER "xemacs::transient_for"
+#define FRAME_DATA_IDENTIFIER "xemacs::frame"
 #define UNMAPPED_DATA_IDENTIFIER "xemacs::initially_unmapped"
 
 #define STUPID_X_SPECIFIC_GTK_STUFF
@@ -98,23 +98,6 @@ static guint dnd_n_targets = sizeof(dnd_target_table) / sizeof(dnd_target_table[
 /*                          helper functions                            */
 /************************************************************************/
 
-/* Return the Emacs frame-object which contains the given widget. */
-struct frame *
-gtk_widget_to_frame (GtkWidget *w)
-{
-  struct frame *f = NULL;
-
-  for (; w; w = w->parent)
-    {
-      if ((f = (struct frame *) gtk_object_get_data (GTK_OBJECT (w),
-						     GTK_DATA_FRAME_IDENTIFIER)))
-	return (f);
-    }
-
-  return (selected_frame());
-}
-
-
 /* Return the Emacs frame-object corresponding to an X window */
 struct frame *
 gtk_window_to_frame (struct device *d, GdkWindow *wdesc)
@@ -801,7 +784,7 @@ gtk_create_widgets (struct frame *f, Lisp_Object lisp_window_id, Lisp_Object par
 
       if (!GTK_IS_CONTAINER (XGTK_OBJECT (lisp_window_id)->object))
 	{
-	  signal_simple_error ("Window ID must be a GtkContainer subclass", lisp_window_id);
+	  invalid_argument ("Window ID must be a GtkContainer subclass", lisp_window_id);
 	}
 
       shell = gtk_vbox_new (FALSE, 0);
@@ -828,7 +811,7 @@ gtk_create_widgets (struct frame *f, Lisp_Object lisp_window_id, Lisp_Object par
 
   gtk_container_set_border_width (GTK_CONTAINER (shell), 0);
 
-  gtk_object_set_data (GTK_OBJECT (shell), GTK_DATA_FRAME_IDENTIFIER, f);
+  gtk_object_set_data (GTK_OBJECT (shell), FRAME_DATA_IDENTIFIER, f);
 
   FRAME_GTK_SHELL_WIDGET (f) = shell;
 
@@ -864,11 +847,9 @@ gtk_create_widgets (struct frame *f, Lisp_Object lisp_window_id, Lisp_Object par
     }
 #endif /* HAVE_MENUBARS */
 
-#ifdef HAVE_GNOME
   if (GNOME_IS_APP (shell))
     gnome_app_set_contents (GNOME_APP (shell), text);
   else
-#endif
     /* Now comes the drawing area, which should fill the rest of the
     ** frame completely.
     */
@@ -954,18 +935,6 @@ allocate_gtk_frame_struct (struct frame *f)
   /* yeah, except the lisp ones */
   FRAME_GTK_ICON_PIXMAP (f) = Qnil;
   FRAME_GTK_ICON_PIXMAP_MASK (f) = Qnil;
-
-  /*
-    Hashtables of callback data for glyphs on the frame.  Make them EQ because
-    we only use ints as keys.  Otherwise we run into stickiness in redisplay
-    because internal_equal() can QUIT.  See enter_redisplay_critical_section().
-  */
-  FRAME_GTK_WIDGET_INSTANCE_HASH_TABLE (f) =
-    make_lisp_hash_table (50, HASH_TABLE_VALUE_WEAK, HASH_TABLE_EQ);
-  FRAME_GTK_WIDGET_CALLBACK_HASH_TABLE (f) =
-    make_lisp_hash_table (50, HASH_TABLE_VALUE_WEAK, HASH_TABLE_EQ);
-  FRAME_GTK_WIDGET_CALLBACK_EX_HASH_TABLE (f) =
-    make_lisp_hash_table (50, HASH_TABLE_VALUE_WEAK, HASH_TABLE_EQ);
 }
 
 
@@ -988,8 +957,8 @@ gtk_init_frame_1 (struct frame *f, Lisp_Object props)
 	popup = Fselected_frame (device);
       CHECK_LIVE_FRAME (popup);
       if (!EQ (device, FRAME_DEVICE (XFRAME (popup))))
-	signal_simple_error_2 ("Parent must be on same device as frame",
-			       device, popup);
+	invalid_argument_2 ("Parent must be on same device as frame",
+			    device, popup);
     }
 
   initially_unmapped = Fplist_get (props, Qinitially_unmapped, Qnil);
@@ -1051,9 +1020,6 @@ gtk_mark_frame (struct frame *f)
   mark_object (FRAME_GTK_LISP_WIDGETS (f)[0]);
   mark_object (FRAME_GTK_LISP_WIDGETS (f)[1]);
   mark_object (FRAME_GTK_LISP_WIDGETS (f)[2]);
-  mark_object (FRAME_GTK_WIDGET_INSTANCE_HASH_TABLE (f));
-  mark_object (FRAME_GTK_WIDGET_CALLBACK_HASH_TABLE (f));
-  mark_object (FRAME_GTK_WIDGET_CALLBACK_EX_HASH_TABLE (f));
 }
 
 static void
@@ -1216,7 +1182,7 @@ gtk_get_mouse_position (struct device *d, Lisp_Object *frame, int *x, int *y)
 static void
 gtk_cant_notify_wm_error (void)
 {
-  error ("Can't notify window manager of iconification.");
+  signal_error (Qgui_error, "Can't notify window manager of iconification", Qunbound);
 }
 
 /* Raise frame F.  */
@@ -1251,7 +1217,7 @@ gtk_lower_frame (struct frame *f)
 static void
 gtk_make_frame_visible (struct frame *f)
 {
-    gtk_widget_map (FRAME_GTK_SHELL_WIDGET (f));
+    gtk_widget_show_all (FRAME_GTK_SHELL_WIDGET (f));
     gtk_raise_frame_1 (f, 0);
 }
 
@@ -1259,7 +1225,7 @@ gtk_make_frame_visible (struct frame *f)
 static void
 gtk_make_frame_invisible (struct frame *f)
 {
-    gtk_widget_unmap(FRAME_GTK_SHELL_WIDGET (f));
+    gtk_widget_hide (FRAME_GTK_SHELL_WIDGET (f));
 }
 
 static int
@@ -1423,11 +1389,11 @@ gtk_update_frame_external_traits (struct frame* frm, Lisp_Object name)
 void
 syms_of_frame_gtk (void)
 {
-  defsymbol (&Qwindow_id, "window-id");
-  defsymbol (&Qtext_widget, "text-widget");
-  defsymbol (&Qcontainer_widget, "container-widget");
-  defsymbol (&Qshell_widget, "shell-widget");
-  defsymbol (&Qdetachable_menubar, "detachable-menubar");
+  DEFSYMBOL (Qwindow_id);
+  DEFSYMBOL (Qtext_widget);
+  DEFSYMBOL (Qcontainer_widget);
+  DEFSYMBOL (Qshell_widget);
+  DEFSYMBOL (Qdetachable_menubar);
 
 #ifdef HAVE_DRAGNDROP
   staticpro (&Vcurrent_drag_object);
