@@ -675,7 +675,7 @@ gif_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
 
     for (slice = 0; slice < unwind.giffile->ImageCount; slice++)
       {
-	/* We check here that that the current image covers the full "screen" size. */
+	/* We check here that the current image covers the full "screen" size. */
 	if (unwind.giffile->SavedImages[slice].ImageDesc.Height != height
 	    || unwind.giffile->SavedImages[slice].ImageDesc.Width != width
 	    || unwind.giffile->SavedImages[slice].ImageDesc.Left != 0
@@ -1123,11 +1123,11 @@ static toff_t tiff_memory_seek(thandle_t data, toff_t off, int whence)
     break;
   default:
     fprintf(stderr,"Eh? invalid seek mode in tiff_memory_seek\n");
-    return -1;
+    return (toff_t) -1;
   }
 
   if ((newidx > mem->len) || (newidx < 0))
-    return -1;
+    return (toff_t) -1;
 
   mem->index = newidx;
   return newidx;
