@@ -38,6 +38,7 @@ Boston, MA 02111-1307, USA.  */
 #include "frame.h"
 #include "insdel.h"
 #include "opaque.h"
+#include "sysdep.h"
 #include "sysfile.h"
 #include "faces.h"
 #include "imgproc.h"
@@ -45,11 +46,6 @@ Boston, MA 02111-1307, USA.  */
 #ifdef FILE_CODING
 #include "file-coding.h"
 #endif
-#include <stdio.h>
-#include <ctype.h>
-#ifdef HAVE_XFACE
-#include <setjmp.h>
-#endif
 
 #define WIDGET_GLYPH_SLOT 0
 
@@ -98,7 +94,6 @@ Lisp_Object Vmswindows_bitmap_file_path;
 static	COLORREF transparent_color = RGB (1,1,1);
 
 DEFINE_IMAGE_INSTANTIATOR_FORMAT (mswindows_resource);
-Lisp_Object Q_resource_type, Q_resource_id;
 Lisp_Object Qmswindows_resource;
 
 static void
@@ -165,16 +160,16 @@ static void init_image_instance_geometry (Lisp_Image_Instance *ii)
 /************************************************************************/
 static BITMAPINFO* convert_EImage_to_DIBitmap (Lisp_Object device,
 					       int width, int height,
-					       unsigned char *pic,
+					       UChar_Binary *pic,
 					       int *bit_count,
-					       unsigned char** bmp_data)
+					       UChar_Binary** bmp_data)
 {
   struct device *d = XDEVICE (device);
   int i,j;
   RGBQUAD* colortbl;
   int		ncolors;
   BITMAPINFO*	bmp_info;
-  unsigned char *ip, *dp;
+  UChar_Binary *ip, *dp;
 
   if (GetDeviceCaps (get_device_compdc (d), BITSPIXEL) > 0)
     {
@@ -199,7 +194,7 @@ static BITMAPINFO* convert_EImage_to_DIBitmap (Lisp_Object device,
 
       /* bitmap data needs to be in blue, green, red triples - in that
 	 order, eimage is in RGB format so we need to convert */
-      *bmp_data = xnew_array_and_zero (unsigned char, bpline * height);
+      *bmp_data = xnew_array_and_zero (UChar_Binary, bpline * height);
       *bit_count = bpline * height;
 
       if (!bmp_data)
@@ -239,7 +234,7 @@ static BITMAPINFO* convert_EImage_to_DIBitmap (Lisp_Object device,
 	  return NULL;
 	}
 
-      colortbl=(RGBQUAD*)(((unsigned char*)bmp_info)+sizeof(BITMAPINFOHEADER));
+      colortbl=(RGBQUAD*)(((UChar_Binary*)bmp_info)+sizeof(BITMAPINFOHEADER));
 
       bmp_info->bmiHeader.biBitCount=8;
       bmp_info->bmiHeader.biCompression=BI_RGB;
@@ -247,7 +242,7 @@ static BITMAPINFO* convert_EImage_to_DIBitmap (Lisp_Object device,
       bmp_info->bmiHeader.biClrUsed=ncolors;
       bmp_info->bmiHeader.biClrImportant=ncolors;
 
-      *bmp_data = (unsigned char *) xmalloc_and_zero (bpline * height);
+      *bmp_data = (UChar_Binary *) xmalloc_and_zero (bpline * height);
       *bit_count = bpline * height;
 
       if (!*bmp_data)
@@ -371,7 +366,7 @@ init_image_instance_from_dibitmap (Lisp_Image_Instance *ii,
 			     0, 0);
 
   if (!bitmap || !bmp_buf)
-    signal_simple_error ("Unable to create bitmap", instantiator);
+    signal_image_error ("Unable to create bitmap", instantiator);
 
   /* copy in the actual bitmap */
   memcpy (bmp_buf, bmp_data, bmp_bits);
@@ -423,7 +418,7 @@ image_instance_add_dibitmap (Lisp_Image_Instance *ii,
 				     0,0);
 
   if (!bitmap || !bmp_buf)
-    signal_simple_error ("Unable to create bitmap", instantiator);
+    signal_image_error ("Unable to create bitmap", instantiator);
 
   /* copy in the actual bitmap */
   memcpy (bmp_buf, bmp_data, bmp_bits);
@@ -434,14 +429,14 @@ static void
 mswindows_init_image_instance_from_eimage (Lisp_Image_Instance *ii,
 					   int width, int height,
 					   int slices,
-					   unsigned char *eimage,
+					   UChar_Binary *eimage,
 					   int dest_mask,
 					   Lisp_Object instantiator,
 					   Lisp_Object domain)
 {
   Lisp_Object device = IMAGE_INSTANCE_DEVICE (ii);
   BITMAPINFO*		bmp_info;
-  unsigned char*	bmp_data;
+  UChar_Binary*	bmp_data;
   int			bmp_bits;
   COLORREF		bkcolor;
   int slice;
@@ -460,8 +455,8 @@ mswindows_init_image_instance_from_eimage (Lisp_Image_Instance *ii,
 						 eimage + (width * height * 3 * slice),
 						 &bmp_bits, &bmp_data)))
 	{
-	  signal_simple_error ("EImage to DIBitmap conversion failed",
-			       instantiator);
+	  signal_image_error ("EImage to DIBitmap conversion failed",
+			      instantiator);
 	}
 
       /* Now create the pixmap and set up the image instance */
@@ -479,18 +474,18 @@ mswindows_init_image_instance_from_eimage (Lisp_Image_Instance *ii,
 }
 
 inline static void
-set_mono_pixel (unsigned char* bits,
+set_mono_pixel (UChar_Binary* bits,
 		int bpline, int height,
 		int x, int y, int white)
 {
   int i;
-  unsigned char bitnum;
+  UChar_Binary bitnum;
   /* Find the byte on which this scanline begins */
   i = (height - y - 1) * bpline;
   /* Find the byte containing this pixel */
   i += (x >> 3);
   /* Which bit is it? */
-  bitnum = (unsigned char) (7 - (x & 7));
+  bitnum = (UChar_Binary) (7 - (x & 7));
   if (white)	/* Turn it on */
     bits[i] |= (1 << bitnum);
   else          /* Turn it off */
@@ -503,7 +498,7 @@ mswindows_initialize_image_instance_mask (Lisp_Image_Instance* image,
 {
   HBITMAP mask;
   HGDIOBJ old = NULL;
-  unsigned char *dibits, *and_bits;
+  UChar_Binary *dibits, *and_bits;
   BITMAPINFO *bmp_info =
     (BITMAPINFO*) xmalloc_and_zero (sizeof (BITMAPINFO) + sizeof (RGBQUAD));
   int i, j;
@@ -557,7 +552,7 @@ mswindows_initialize_image_instance_mask (Lisp_Image_Instance* image,
   bmp_info->bmiHeader.biClrImportant = 0;
   bmp_info->bmiHeader.biSizeImage = height * bpline;
 
-  dibits = (unsigned char*) xmalloc_and_zero (bpline * height);
+  dibits = (UChar_Binary*) xmalloc_and_zero (bpline * height);
   if (GetDIBits (hcdc,
 		 IMAGE_INSTANCE_MSWINDOWS_BITMAP (image),
 		 0,
@@ -576,7 +571,7 @@ mswindows_initialize_image_instance_mask (Lisp_Image_Instance* image,
     {
       for (j=0; j<height; j++)
 	{
-	  unsigned char* idx = &dibits[j * bpline + i * 3];
+	  UChar_Binary* idx = &dibits[j * bpline + i * 3];
 
 	  if (RGB (idx[2], idx[1], idx[0]) == transparent_color)
 	    {
@@ -791,7 +786,7 @@ extract_xpm_color_names (Lisp_Object device,
 }
 
 static int xpm_to_eimage (Lisp_Object image, const Extbyte *buffer,
-			  unsigned char** data,
+			  UChar_Binary** data,
 			  int* width, int* height,
 			  int* x_hot, int* y_hot,
 			  int* transp,
@@ -801,7 +796,7 @@ static int xpm_to_eimage (Lisp_Object image, const Extbyte *buffer,
   XpmImage xpmimage;
   XpmInfo xpminfo;
   int result, i, j, transp_idx, maskbpline;
-  unsigned char* dptr;
+  UChar_Binary* dptr;
   unsigned int* sptr;
   COLORREF color; /* the american spelling virus hits again .. */
   COLORREF* colortbl;
@@ -820,18 +815,18 @@ static int xpm_to_eimage (Lisp_Object image, const Extbyte *buffer,
       break;
     case XpmFileInvalid:
       {
-	signal_simple_error ("Invalid XPM data", image);
+	signal_image_error ("Invalid XPM data", image);
       }
     case XpmNoMemory:
       {
-	signal_double_file_error ("Parsing pixmap data",
-				  "out of memory", image);
+	signal_double_image_error ("Parsing pixmap data",
+				   "out of memory", image);
       }
     default:
       {
-	signal_double_file_error_2 ("Parsing pixmap data",
-				    "unknown error",
-				    make_int (result), image);
+	signal_double_image_error_2 ("Parsing pixmap data",
+				     "unknown error",
+				     make_int (result), image);
       }
     }
 
@@ -839,7 +834,7 @@ static int xpm_to_eimage (Lisp_Object image, const Extbyte *buffer,
   *height = xpmimage.height;
   maskbpline = BPLINE ((~7UL & (unsigned long)(*width + 7)) / 8);
 
-  *data = xnew_array_and_zero (unsigned char, *width * *height * 3);
+  *data = xnew_array_and_zero (UChar_Binary, *width * *height * 3);
 
   if (!*data)
     {
@@ -948,10 +943,10 @@ mswindows_xpm_instantiate (Lisp_Object image_instance,
   Lisp_Object device = IMAGE_INSTANCE_DEVICE (ii);
   const Extbyte		*bytes;
   Extcount 		len;
-  unsigned char		*eimage;
+  UChar_Binary		*eimage;
   int			width, height, x_hot, y_hot;
   BITMAPINFO*		bmp_info;
-  unsigned char*	bmp_data;
+  UChar_Binary*	bmp_data;
   int			bmp_bits;
   int 			nsymbols=0, transp;
   struct color_symbol*	color_symbols=NULL;
@@ -976,8 +971,8 @@ mswindows_xpm_instantiate (Lisp_Object image_instance,
   if (!xpm_to_eimage (image_instance, bytes, &eimage, &width, &height,
 		      &x_hot, &y_hot, &transp, color_symbols, nsymbols))
     {
-      signal_simple_error ("XPM to EImage conversion failed",
-			   image_instance);
+      signal_image_error ("XPM to EImage conversion failed",
+			  image_instance);
     }
 
   if (color_symbols)
@@ -993,8 +988,8 @@ mswindows_xpm_instantiate (Lisp_Object image_instance,
   if (!(bmp_info=convert_EImage_to_DIBitmap (device, width, height, eimage,
 					     &bmp_bits, &bmp_data)))
     {
-      signal_simple_error ("XPM to EImage conversion failed",
-			   image_instance);
+      signal_image_error ("XPM to EImage conversion failed",
+			  image_instance);
     }
   xfree (eimage);
 
@@ -1077,49 +1072,15 @@ bmp_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
 static void
 mswindows_resource_validate (Lisp_Object instantiator)
 {
-  if ((NILP (find_keyword_in_vector (instantiator, Q_file))
-       &&
-       NILP (find_keyword_in_vector (instantiator, Q_resource_id)))
-      ||
-      NILP (find_keyword_in_vector (instantiator, Q_resource_type)))
-    signal_simple_error ("Must supply :file, :resource-id and :resource-type",
-			 instantiator);
+  shared_resource_validate (instantiator);
 }
 
 static Lisp_Object
 mswindows_resource_normalize (Lisp_Object inst, Lisp_Object console_type,
 			      Lisp_Object dest_mask)
 {
-  /* This function can call lisp */
-  Lisp_Object file = Qnil;
-  struct gcpro gcpro1, gcpro2;
-  Lisp_Object alist = Qnil;
-
-  GCPRO2 (file, alist);
-
-  file = potential_pixmap_file_instantiator (inst, Q_file, Q_data,
-					     console_type);
-
-  if (CONSP (file)) /* failure locating filename */
-    signal_double_file_error ("Opening pixmap file",
-			      "no such file or directory",
-			      Fcar (file));
-
-  if (NILP (file)) /* no conversion necessary */
-    RETURN_UNGCPRO (inst);
-
-  alist = tagged_vector_to_alist (inst);
-
-  {
-    alist = remassq_no_quit (Q_file, alist);
-    alist = Fcons (Fcons (Q_file, file), alist);
-  }
-
-  {
-    Lisp_Object result = alist_to_tagged_vector (Qmswindows_resource, alist);
-    free_alist (alist);
-    RETURN_UNGCPRO (result);
-  }
+  return shared_resource_normalize (inst, console_type, dest_mask,
+				    Qmswindows_resource);
 }
 
 static int
@@ -1222,7 +1183,7 @@ static int resource_name_to_resource (Lisp_Object name, int type)
     }
   else if (!STRINGP (name))
     {
-      signal_simple_error ("invalid resource identifier", name);
+      invalid_argument ("invalid resource identifier", name);
     }
 
   do {
@@ -1315,7 +1276,7 @@ mswindows_resource_instantiate (Lisp_Object image_instance,
     }
   else if (!(resid = MAKEINTRESOURCE (resource_name_to_resource (resource_id,
 							       type))))
-    signal_simple_error ("Invalid resource identifier", resource_id);
+    invalid_argument ("Invalid resource identifier", resource_id);
 
   /* load the image */
   if (xLoadImageA) /* not in NT 3.5 */
@@ -1324,7 +1285,7 @@ mswindows_resource_instantiate (Lisp_Object image_instance,
 				  LR_CREATEDIBSECTION | LR_DEFAULTSIZE |
 				  LR_SHARED |
 				  (!NILP (file) ? LR_LOADFROMFILE : 0))))
-	signal_simple_error ("Cannot load image", instantiator);
+	signal_image_error ("Cannot load image", instantiator);
     }
   else
     {
@@ -1343,7 +1304,7 @@ mswindows_resource_instantiate (Lisp_Object image_instance,
 	}
 
       if (!himage)
-	signal_simple_error ("Cannot load image", instantiator);
+	signal_image_error ("Cannot load image", instantiator);
     }
 
   if (hinst)
@@ -1385,7 +1346,7 @@ check_valid_resource_symbol (Lisp_Object data)
 {
   CHECK_SYMBOL (data);
   if (!resource_symbol_to_type (data))
-    signal_simple_error ("invalid resource type", data);
+    invalid_constant ("invalid resource type", data);
 }
 
 static void
@@ -1396,285 +1357,12 @@ check_valid_resource_id (Lisp_Object data)
       !resource_name_to_resource (data, IMAGE_ICON)
       &&
       !resource_name_to_resource (data, IMAGE_BITMAP))
-    signal_simple_error ("invalid resource identifier", data);
+    invalid_constant ("invalid resource identifier", data);
 }
 
 /**********************************************************************
  *                             XBM                                    *
  **********************************************************************/
-#ifndef HAVE_X_WINDOWS
-/* $XConsortium: RdBitF.c,v 1.10 94/04/17 20:16:13 kaleb Exp $ */
-
-/*
-
-Copyright (c) 1988  X Consortium
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-Except as contained in this notice, the name of the X Consortium shall not be
-used in advertising or otherwise to promote the sale, use or other dealings
-in this Software without prior written authorization from the X Consortium.
-
-*/
-
-/*
- * This file contains miscellaneous utility routines and is not part of the
- * Xlib standard.
- *
- * Public entry points:
- *
- *     XmuReadBitmapData		read data from FILE descriptor
- *     XmuReadBitmapDataFromFile	read X10 or X11 format bitmap files
- *					and return data
- *
- * Note that this file and ../X/XRdBitF.c look very similar....  Keep them
- * that way (but don't use common source code so that people can have one
- * without the other).
- */
-
-
-/*
- * Based on an optimized version provided by Jim Becker, August 5, 1988.
- */
-#ifndef BitmapSuccess
-#define BitmapSuccess           0
-#define BitmapOpenFailed        1
-#define BitmapFileInvalid       2
-#define BitmapNoMemory          3
-#endif
-#define MAX_SIZE 255
-
-/* shared data for the image read/parse logic */
-static short hexTable[256];		/* conversion value */
-static int initialized = FALSE;	/* easier to fill in at run time */
-
-/*
- *	Table index for the hex values. Initialized once, first time.
- *	Used for translation value or delimiter significance lookup.
- */
-static void
-initHexTable (void)
-{
-    /*
-     * We build the table at run time for several reasons:
-     *
-     *     1.  portable to non-ASCII machines.
-     *     2.  still reentrant since we set the init flag after setting table.
-     *     3.  easier to extend.
-     *     4.  less prone to bugs.
-     */
-    hexTable['0'] = 0;	hexTable['1'] = 1;
-    hexTable['2'] = 2;	hexTable['3'] = 3;
-    hexTable['4'] = 4;	hexTable['5'] = 5;
-    hexTable['6'] = 6;	hexTable['7'] = 7;
-    hexTable['8'] = 8;	hexTable['9'] = 9;
-    hexTable['A'] = 10;	hexTable['B'] = 11;
-    hexTable['C'] = 12;	hexTable['D'] = 13;
-    hexTable['E'] = 14;	hexTable['F'] = 15;
-    hexTable['a'] = 10;	hexTable['b'] = 11;
-    hexTable['c'] = 12;	hexTable['d'] = 13;
-    hexTable['e'] = 14;	hexTable['f'] = 15;
-
-    /* delimiters of significance are flagged w/ negative value */
-    hexTable[' '] = -1;	hexTable[','] = -1;
-    hexTable['}'] = -1;	hexTable['\n'] = -1;
-    hexTable['\t'] = -1;
-
-    initialized = TRUE;
-}
-
-/*
- *	read next hex value in the input stream, return -1 if EOF
- */
-static int
-NextInt (FILE *fstream)
-{
-    int	ch;
-    int	value = 0;
-    int gotone = 0;
-    int done = 0;
-
-    /* loop, accumulate hex value until find delimiter  */
-    /* skip any initial delimiters found in read stream */
-
-    while (!done) {
-	ch = getc(fstream);
-	if (ch == EOF) {
-	    value	= -1;
-	    done++;
-	} else {
-	    /* trim high bits, check type and accumulate */
-	    ch &= 0xff;
-	    if (isascii(ch) && isxdigit(ch)) {
-		value = (value << 4) + hexTable[ch];
-		gotone++;
-	    } else if ((hexTable[ch]) < 0 && gotone)
-	      done++;
-	}
-    }
-    return value;
-}
-
-
-/*
- * The data returned by the following routine is always in left-most byte
- * first and left-most bit first.  If it doesn't return BitmapSuccess then
- * its arguments won't have been touched.  This routine should look as much
- * like the Xlib routine XReadBitmapfile as possible.
- */
-int read_bitmap_data (FILE* fstream, unsigned int *width,
-		      unsigned int *height, unsigned char **datap,
-		      int *x_hot, int *y_hot)
-{
-    unsigned char *data = NULL;		/* working variable */
-    char line[MAX_SIZE];		/* input line from file */
-    int size;				/* number of bytes of data */
-    char name_and_type[MAX_SIZE];	/* an input line */
-    char *type;				/* for parsing */
-    int value;				/* from an input line */
-    int version10p;			/* boolean, old format */
-    int padding;			/* to handle alignment */
-    int bytes_per_line;			/* per scanline of data */
-    unsigned int ww = 0;		/* width */
-    unsigned int hh = 0;		/* height */
-    int hx = -1;			/* x hotspot */
-    int hy = -1;			/* y hotspot */
-
-#define Xmalloc(size) malloc(size)
-
-    /* first time initialization */
-    if (initialized == FALSE) initHexTable();
-
-    /* error cleanup and return macro	*/
-#define	RETURN(code) { if (data) free (data); return code; }
-
-    while (fgets(line, MAX_SIZE, fstream)) {
-	if (strlen(line) == MAX_SIZE-1) {
-	    RETURN (BitmapFileInvalid);
-	}
-	if (sscanf(line,"#define %s %d",name_and_type,&value) == 2) {
-	    if (!(type = strrchr(name_and_type, '_')))
-	      type = name_and_type;
-	    else
-	      type++;
-
-	    if (!strcmp("width", type))
-	      ww = (unsigned int) value;
-	    if (!strcmp("height", type))
-	      hh = (unsigned int) value;
-	    if (!strcmp("hot", type)) {
-		if (type-- == name_and_type || type-- == name_and_type)
-		  continue;
-		if (!strcmp("x_hot", type))
-		  hx = value;
-		if (!strcmp("y_hot", type))
-		  hy = value;
-	    }
-	    continue;
-	}
-
-	if (sscanf(line, "static short %s = {", name_and_type) == 1)
-	  version10p = 1;
-	else if (sscanf(line,"static unsigned char %s = {",name_and_type) == 1)
-	  version10p = 0;
-	else if (sscanf(line, "static char %s = {", name_and_type) == 1)
-	  version10p = 0;
-	else
-	  continue;
-
-	if (!(type = strrchr(name_and_type, '_')))
-	  type = name_and_type;
-	else
-	  type++;
-
-	if (strcmp("bits[]", type))
-	  continue;
-
-	if (!ww || !hh)
-	  RETURN (BitmapFileInvalid);
-
-	if ((ww % 16) && ((ww % 16) < 9) && version10p)
-	  padding = 1;
-	else
-	  padding = 0;
-
-	bytes_per_line = (ww+7)/8 + padding;
-
-	size = bytes_per_line * hh;
-	data = (unsigned char *) Xmalloc ((unsigned int) size);
-	if (!data)
-	  RETURN (BitmapNoMemory);
-
-	if (version10p) {
-	    unsigned char *ptr;
-	    int bytes;
-
-	    for (bytes=0, ptr=data; bytes<size; (bytes += 2)) {
-		if ((value = NextInt(fstream)) < 0)
-		  RETURN (BitmapFileInvalid);
-		*(ptr++) = value;
-		if (!padding || ((bytes+2) % bytes_per_line))
-		  *(ptr++) = value >> 8;
-	    }
-	} else {
-	    unsigned char *ptr;
-	    int bytes;
-
-	    for (bytes=0, ptr=data; bytes<size; bytes++, ptr++) {
-		if ((value = NextInt(fstream)) < 0)
-		  RETURN (BitmapFileInvalid);
-		*ptr=value;
-	    }
-	}
-	break;
-    }					/* end while */
-
-    if (data == NULL) {
-	RETURN (BitmapFileInvalid);
-    }
-
-    *datap = data;
-    data = NULL;
-    *width = ww;
-    *height = hh;
-    if (x_hot) *x_hot = hx;
-    if (y_hot) *y_hot = hy;
-
-    RETURN (BitmapSuccess);
-}
-
-
-int read_bitmap_data_from_file (const char *filename, unsigned int *width,
-				unsigned int *height, unsigned char **datap,
-				int *x_hot, int *y_hot)
-{
-    FILE *fstream;
-    int status;
-
-    if ((fstream = fopen (filename, "r")) == NULL) {
-	return BitmapOpenFailed;
-    }
-    status = read_bitmap_data (fstream, width, height, datap, x_hot, y_hot);
-    fclose (fstream);
-    return status;
-}
-#endif /* HAVE_X_WINDOWS */
-
 /* this table flips four bits around. */
 static int flip_table[] =
 {
@@ -1689,15 +1377,15 @@ static int flip_table[] =
    byte order from left to right, big-endian within a byte.  0 =
    black, 1 = white.  */
 static HBITMAP
-xbm_create_bitmap_from_data (HDC hdc, char *data,
+xbm_create_bitmap_from_data (HDC hdc, const UChar_Binary *data,
 			     unsigned int width, unsigned int height,
 			     int mask, COLORREF fg, COLORREF bg)
 {
   int old_width = (width + 7)/8;
   int new_width = BPLINE (2*((width + 15)/16));
-  unsigned char *offset;
+  const UChar_Binary *offset;
   void *bmp_buf = 0;
-  unsigned char *new_data, *new_offset;
+  UChar_Binary *new_data, *new_offset;
   int i, j;
   BITMAPINFO *bmp_info =
     (BITMAPINFO*) xmalloc_and_zero (sizeof(BITMAPINFO) + sizeof(RGBQUAD));
@@ -1706,7 +1394,7 @@ xbm_create_bitmap_from_data (HDC hdc, char *data,
   if (!bmp_info)
     return NULL;
 
-  new_data = (unsigned char *) xmalloc_and_zero (height * new_width);
+  new_data = (UChar_Binary *) xmalloc_and_zero (height * new_width);
 
   if (!new_data)
     {
@@ -1722,7 +1410,7 @@ xbm_create_bitmap_from_data (HDC hdc, char *data,
       for (j=0; j<old_width; j++)
 	{
 	  int byte = offset[j];
-	  new_offset[j] = ~ (unsigned char)
+	  new_offset[j] = ~ (UChar_Binary)
 	    ((flip_table[byte & 0xf] << 4) + flip_table[byte >> 4]);
 	}
     }
@@ -1782,8 +1470,7 @@ xbm_create_bitmap_from_data (HDC hdc, char *data,
 static void
 init_image_instance_from_xbm_inline (Lisp_Image_Instance *ii,
 				     int width, int height,
-				     /* Note that data is in ext-format! */
-				     const char *bits,
+				     const UChar_Binary *bits,
 				     Lisp_Object instantiator,
 				     Lisp_Object pointer_fg,
 				     Lisp_Object pointer_bg,
@@ -1834,14 +1521,13 @@ init_image_instance_from_xbm_inline (Lisp_Image_Instance *ii,
   init_image_instance_geometry (ii);
 
   IMAGE_INSTANCE_MSWINDOWS_MASK (ii) = mask ? mask :
-    xbm_create_bitmap_from_data (hdc, (Extbyte *) bits, width, height,
-				 TRUE, black, white);
+    xbm_create_bitmap_from_data (hdc, bits, width, height, TRUE, black, white);
 
   switch (type)
     {
     case IMAGE_MONO_PIXMAP:
       IMAGE_INSTANCE_MSWINDOWS_BITMAP (ii) =
-	xbm_create_bitmap_from_data (hdc, (Extbyte *) bits, width, height,
+	xbm_create_bitmap_from_data (hdc, bits, width, height,
 				     FALSE, black, black);
       break;
 
@@ -1870,7 +1556,7 @@ init_image_instance_from_xbm_inline (Lisp_Image_Instance *ii,
 	IMAGE_INSTANCE_PIXMAP_BG (ii) = background;
 
 	IMAGE_INSTANCE_MSWINDOWS_BITMAP (ii) =
-	  xbm_create_bitmap_from_data (hdc, (Extbyte *) bits, width, height,
+	  xbm_create_bitmap_from_data (hdc, bits, width, height,
 				       FALSE, fg, black);
       }
       break;
@@ -1897,7 +1583,7 @@ init_image_instance_from_xbm_inline (Lisp_Image_Instance *ii,
 	  bg = COLOR_INSTANCE_MSWINDOWS_COLOR (XCOLOR_INSTANCE (background));
 
 	IMAGE_INSTANCE_MSWINDOWS_BITMAP (ii) =
-	  xbm_create_bitmap_from_data (hdc, (Extbyte *) bits, width, height,
+	  xbm_create_bitmap_from_data (hdc, bits, width, height,
 				       TRUE, fg, black);
 	mswindows_initialize_image_instance_icon (ii, TRUE);
       }
@@ -1912,8 +1598,7 @@ static void
 xbm_instantiate_1 (Lisp_Object image_instance, Lisp_Object instantiator,
 		   Lisp_Object pointer_fg, Lisp_Object pointer_bg,
 		   int dest_mask, int width, int height,
-		   /* Note that data is in ext-format! */
-		   const char *bits)
+		   const UChar_Binary *bits)
 {
   Lisp_Object mask_data = find_keyword_in_vector (instantiator, Q_mask_data);
   Lisp_Object mask_file = find_keyword_in_vector (instantiator, Q_mask_file);
@@ -1923,13 +1608,13 @@ xbm_instantiate_1 (Lisp_Object image_instance, Lisp_Object instantiator,
 
   if (!NILP (mask_data))
     {
-      const char *ext_data;
+      UChar_Binary *ext_data;
 
       TO_EXTERNAL_FORMAT (LISP_STRING, XCAR (XCDR (XCDR (mask_data))),
 			  C_STRING_ALLOCA, ext_data,
 			  Qbinary);
       mask = xbm_create_bitmap_from_data (hdc,
-					  (unsigned char *) ext_data,
+					  ext_data,
 					  XINT (XCAR (mask_data)),
 					  XINT (XCAR (XCDR (mask_data))),
 					  FALSE,
@@ -1951,7 +1636,7 @@ mswindows_xbm_instantiate (Lisp_Object image_instance,
 			   int dest_mask, Lisp_Object domain)
 {
   Lisp_Object data = find_keyword_in_vector (instantiator, Q_data);
-  const char *ext_data;
+  const UChar_Binary *ext_data;
 
   assert (!NILP (data));
 
@@ -1996,9 +1681,9 @@ mswindows_xface_instantiate (Lisp_Object image_instance,
 {
   Lisp_Object data = find_keyword_in_vector (instantiator, Q_data);
   int i, stattis;
-  char *p, *bits, *bp;
-  const char * volatile emsg = 0;
-  const char * volatile dstring;
+  UChar_Binary *p, *bits, *bp;
+  const CBufbyte * volatile emsg = 0;
+  const UChar_Binary * volatile dstring;
 
   assert (!NILP (data));
 
@@ -2006,7 +1691,7 @@ mswindows_xface_instantiate (Lisp_Object image_instance,
 		      C_STRING_ALLOCA, dstring,
 		      Qbinary);
 
-  if ((p = strchr (dstring, ':')))
+  if ((p = (UChar_Binary *) strchr ((char *) dstring, ':')))
     {
       dstring = p + 1;
     }
@@ -2032,9 +1717,9 @@ mswindows_xface_instantiate (Lisp_Object image_instance,
     }
 
   if (emsg)
-    signal_simple_error_2 (emsg, data, Qimage);
+    signal_image_error_2 (emsg, data, Qimage);
 
-  bp = bits = (char *) alloca (PIXELS / 8);
+  bp = bits = (UChar_Binary *) alloca (PIXELS / 8);
 
   /* the compface library exports char F[], which uses a single byte per
      pixel to represent a 48x48 bitmap.  Yuck. */
@@ -2046,7 +1731,7 @@ mswindows_xface_instantiate (Lisp_Object image_instance,
 	{
 	  n |= ((*p++) << b);
 	}
-      *bp++ = (char) n;
+      *bp++ = (UChar_Binary) n;
     }
 
   xbm_instantiate_1 (image_instance, instantiator, pointer_fg,
@@ -2092,6 +1777,12 @@ mswindows_print_image_instance (Lisp_Image_Instance *p,
 extern int debug_widget_instances;
 #endif
 
+static void
+finalize_destroy_window (void *win)
+{
+  DestroyWindow ((HWND) win);
+}
+
 static void
 mswindows_finalize_image_instance (Lisp_Image_Instance *p)
 {
@@ -2109,8 +1800,14 @@ mswindows_finalize_image_instance (Lisp_Image_Instance *p)
 #endif
 	  if (IMAGE_INSTANCE_SUBWINDOW_ID (p))
 	    {
-	      DestroyWindow (WIDGET_INSTANCE_MSWINDOWS_HANDLE (p));
-	      DestroyWindow (IMAGE_INSTANCE_MSWINDOWS_CLIPWINDOW (p));
+	      /* DestroyWindow is not safe here, as it will send messages
+		 to our window proc. */
+	      register_post_gc_action
+		(finalize_destroy_window,
+		 (void *) (WIDGET_INSTANCE_MSWINDOWS_HANDLE (p)));
+	      register_post_gc_action
+		(finalize_destroy_window,
+		 (void *) (IMAGE_INSTANCE_MSWINDOWS_CLIPWINDOW (p)));
 	      IMAGE_INSTANCE_SUBWINDOW_ID (p) = 0;
 	    }
 	}
@@ -2412,8 +2109,8 @@ mswindows_subwindow_instantiate (Lisp_Object image_instance,
 			NULL,       /* No menu */
 			NULL, /* must be null for this class */
 			NULL)) == NULL)
-    signal_simple_error ("window creation failed with code",
-			 make_int (GetLastError()));
+    gui_error ("window creation failed with code",
+	       make_int (GetLastError()));
 
   wnd = CreateWindow( "STATIC",
 		      "",
@@ -2551,8 +2248,8 @@ mswindows_widget_instantiate (Lisp_Object image_instance,
 			(HMENU)id,       /* No menu */
 			NULL, /* must be null for this class */
 			NULL)) == NULL)
-    signal_simple_error ("window creation failed with code",
-			 make_int (GetLastError()));
+    gui_error ("window creation failed with code",
+	       make_int (GetLastError()));
 
   if ((wnd = CreateWindowEx(
 			    exflags /* | WS_EX_NOPARENTNOTIFY*/,
@@ -2571,8 +2268,8 @@ mswindows_widget_instantiate (Lisp_Object image_instance,
 			    (FRAME_MSWINDOWS_HANDLE (XFRAME (frame)),
 			     GWL_HINSTANCE),
 			    NULL)) == NULL)
-    signal_simple_error ("window creation failed with code",
-			 make_int (GetLastError()));
+    gui_error ("window creation failed with code",
+	       make_int (GetLastError()));
 
   IMAGE_INSTANCE_SUBWINDOW_ID (ii) = wnd;
   SetWindowLong (wnd, GWL_USERDATA, (LONG)LISP_TO_VOID(image_instance));
@@ -2783,7 +2480,7 @@ static HTREEITEM add_tree_item (Lisp_Object image_instance,
 
   if ((ret = (HTREEITEM)SendMessage (wnd, TVM_INSERTITEM,
 				     0, (LPARAM)&tvitem)) == 0)
-    signal_simple_error ("error adding tree view entry", item);
+    gui_error ("error adding tree view entry", item);
 
   return ret;
 }
@@ -2906,7 +2603,7 @@ add_tab_item (Lisp_Object image_instance,
 
   if ((ret = SendMessage (wnd, TCM_INSERTITEM,
 			  i, (LPARAM)&tvitem)) < 0)
-    signal_simple_error ("error adding tab entry", item);
+    gui_error ("error adding tab entry", item);
 
   return ret;
 }
@@ -3107,7 +2804,7 @@ mswindows_combo_box_instantiate (Lisp_Object image_instance,
 			  C_STRING_ALLOCA, lparam,
 			  Qnative);
       if (SendMessage (wnd, CB_ADDSTRING, 0, (LPARAM)lparam) == CB_ERR)
-	signal_simple_error ("error adding combo entries", instantiator);
+	gui_error ("error adding combo entries", instantiator);
     }
 }
 
@@ -3218,8 +2915,6 @@ mswindows_control_wnd_proc (HWND hwnd, UINT msg,
 void
 syms_of_glyphs_mswindows (void)
 {
-  defkeyword (&Q_resource_id, ":resource-id");
-  defkeyword (&Q_resource_type, ":resource-type");
 }
 
 void
