@@ -4,7 +4,7 @@
    Copyright (C) 1995 Tinker Systems
    Copyright (C) 1995, 1996 Ben Wing
    Copyright (C) 1995 Sun Microsystems
-   Copyright (C) 1999, 2000, 2002 Andy Piper
+   Copyright (C) 1999, 2000 Andy Piper
 
 This file is part of XEmacs.
 
@@ -80,6 +80,7 @@ Boston, MA 02111-1307, USA.  */
 
 #ifdef LWLIB_WIDGETS_MOTIF
 #include <Xm/Xm.h>
+#include <Xm/Scale.h>
 #endif
 #include <X11/IntrinsicP.h>
 
@@ -158,8 +159,6 @@ update_tab_widget_face (widget_value* wv,
 #endif
 void
 emacs_Xt_handle_widget_losing_focus (struct frame* f, Widget losing_widget);
-void
-enqueue_focus_event (Widget wants_it, Lisp_Object frame, int in_p);
 
 #include "bitmaps.h"
 
@@ -233,8 +232,7 @@ convert_EImage_to_XImage (Lisp_Object device, int width, int height,
   if (vis->class == PseudoColor)
     {
       unsigned long pixarray[256];
-      int pixcount;
-      unsigned int n;
+      int pixcount, n;
       /* use our quantize table to allocate the colors */
       pixcount = 32;
       *pixtbl = xnew_array (unsigned long, pixcount);
@@ -435,7 +433,7 @@ x_finalize_image_instance (Lisp_Image_Instance *p)
 	}
       else
 	{
-	  unsigned int i;
+	  int i;
 	  if (IMAGE_INSTANCE_PIXMAP_TIMEOUT (p))
 	    disable_glyph_animated_timeout (IMAGE_INSTANCE_PIXMAP_TIMEOUT (p));
 
@@ -683,7 +681,7 @@ write_lisp_string_to_temp_file (Lisp_Object string, char *filename_out)
 	  errno = old_errno;
 	}
       report_file_error ("Creating temp file",
-			 list1 (build_string (filename_out)));
+			 build_string (filename_out));
     }
 
   CHECK_STRING (string);
@@ -744,7 +742,7 @@ write_lisp_string_to_temp_file (Lisp_Object string, char *filename_out)
 
   if (fubar)
     report_file_error ("Writing temp file",
-		       list1 (build_string (filename_out)));
+		       build_string (filename_out));
 }
 #endif /* 0 */
 
@@ -766,13 +764,13 @@ check_pointer_sizes (Screen *xs, unsigned int width, unsigned int height,
 			  width, height, &best_width, &best_height))
     /* this means that an X error of some sort occurred (we trap
        these so they're not fatal). */
-    signal_simple_error ("XQueryBestCursor() failed?", instantiator);
+    gui_error ("XQueryBestCursor() failed?", instantiator);
 
   if (width > best_width || height > best_height)
-    error_with_frob (instantiator,
-		     "pointer too large (%dx%d): "
-		     "server requires %dx%d or smaller",
-		     width, height, best_width, best_height);
+    signal_ferror_with_frob (Qgui_error, instantiator,
+			     "pointer too large (%dx%d): "
+			     "server requires %dx%d or smaller",
+			     width, height, best_width, best_height);
 }
 
 
@@ -865,7 +863,7 @@ init_image_instance_from_x_image (Lisp_Image_Instance *ii,
   Pixmap pixmap;
 
   if (!DEVICE_X_P (XDEVICE (device)))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   dpy = DEVICE_X_DISPLAY (XDEVICE (device));
   d = XtWindow(DEVICE_XT_APP_SHELL (XDEVICE (device)));
@@ -877,13 +875,13 @@ init_image_instance_from_x_image (Lisp_Image_Instance *ii,
   pixmap = XCreatePixmap (dpy, d, ximage->width,
 			  ximage->height, ximage->depth);
   if (!pixmap)
-    signal_simple_error ("Unable to create pixmap", instantiator);
+    gui_error ("Unable to create pixmap", instantiator);
 
   gc = XCreateGC (dpy, pixmap, 0, NULL);
   if (!gc)
     {
       XFreePixmap (dpy, pixmap);
-      signal_simple_error ("Unable to create GC", instantiator);
+      gui_error ("Unable to create GC", instantiator);
     }
 
   XPutImage (dpy, pixmap, gc, ximage, 0, 0, 0, 0,
@@ -926,13 +924,13 @@ image_instance_add_x_image (Lisp_Image_Instance *ii,
   pixmap = XCreatePixmap (dpy, d, ximage->width,
 			  ximage->height, ximage->depth);
   if (!pixmap)
-    signal_simple_error ("Unable to create pixmap", instantiator);
+    gui_error ("Unable to create pixmap", instantiator);
 
   gc = XCreateGC (dpy, pixmap, 0, NULL);
   if (!gc)
     {
       XFreePixmap (dpy, pixmap);
-      signal_simple_error ("Unable to create GC", instantiator);
+      gui_error ("Unable to create GC", instantiator);
     }
 
   XPutImage (dpy, pixmap, gc, ximage, 0, 0, 0, 0,
@@ -991,14 +989,6 @@ x_init_image_instance_from_eimage (Lisp_Image_Instance *ii,
     }
 }
 
-int read_bitmap_data_from_file (const char *filename, unsigned int *width,
-				unsigned int *height, unsigned char **datap,
-				int *x_hot, int *y_hot)
-{
-  return XmuReadBitmapDataFromFile (filename, width, height,
-				    datap, x_hot, y_hot);
-}
-
 /* Given inline data for a mono pixmap, create and return the
    corresponding X object. */
 
@@ -1038,7 +1028,7 @@ init_image_instance_from_xbm_inline (Lisp_Image_Instance *ii,
   enum image_instance_type type;
 
   if (!DEVICE_X_P (XDEVICE (device)))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   dpy = DEVICE_X_DISPLAY (XDEVICE (device));
   draw = XtWindow(DEVICE_XT_APP_SHELL (XDEVICE (device)));
@@ -1326,7 +1316,7 @@ x_xpm_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
   unsigned int w, h;
 
   if (!DEVICE_X_P (XDEVICE (device)))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   dpy = DEVICE_X_DISPLAY (XDEVICE (device));
   xs = DefaultScreenOfDisplay (dpy);
@@ -1425,19 +1415,13 @@ x_xpm_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
 	if (force_mono)
 	  {
 	    /* second time; blow out. */
-	    signal_double_file_error ("Reading pixmap data",
-				      "color allocation failed",
-				      data);
+	    gui_error ("XPM color allocation failed", data);
 	  }
 	else
 	  {
+	    /* second time; blow out. */
 	    if (! (dest_mask & IMAGE_MONO_PIXMAP_MASK))
-	      {
-		/* second time; blow out. */
-		signal_double_file_error ("Reading pixmap data",
-					  "color allocation failed",
-					  data);
-	      }
+	      gui_error ("XPM color allocation failed", data);
 	    force_mono = 1;
 	    IMAGE_INSTANCE_TYPE (ii) = IMAGE_MONO_PIXMAP;
 	    goto retry;
@@ -1446,15 +1430,14 @@ x_xpm_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
     case XpmNoMemory:
       {
 	xpm_free (&xpmattrs);
-	signal_double_file_error ("Parsing pixmap data",
-				  "out of memory", data);
+	out_of_memory ("Parsing pixmap data", data);
       }
     default:
       {
 	xpm_free (&xpmattrs);
-	signal_double_file_error_2 ("Parsing pixmap data",
-				    "unknown error code",
-				    make_int (result), data);
+	signal_error_2 (Qgui_error,
+			"Parsing pixmap data: unknown error code",
+			make_int (result), data);
       }
     }
 
@@ -1708,7 +1691,7 @@ x_xface_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
     }
 
   if (emsg)
-    signal_simple_error_2 (emsg, data, Qimage);
+    gui_error_2 (emsg, data, Qimage);
 
   bp = bits = (char *) alloca (PIXELS / 8);
 
@@ -1951,13 +1934,13 @@ font_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
   Lisp_Object foreground, background;
 
   if (!DEVICE_X_P (XDEVICE (device)))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   dpy = DEVICE_X_DISPLAY (XDEVICE (device));
 
   if (!STRINGP (data) ||
       strncmp ("FONT ", (char *) XSTRING_DATA (data), 5))
-    signal_simple_error ("Invalid font-glyph instantiator",
+    invalid_argument ("Invalid font-glyph instantiator",
 			 instantiator);
 
   if (!(dest_mask & IMAGE_POINTER_MASK))
@@ -1981,12 +1964,11 @@ font_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
     count = 4, mask_name[0] = 0;
 
   if (count != 2 && count != 4)
-    signal_simple_error ("invalid cursor specification", data);
+    syntax_error ("invalid cursor specification", data);
   source = safe_XLoadFont (dpy, source_name);
   if (! source)
-    signal_simple_error_2 ("couldn't load font",
-			   build_string (source_name),
-			   data);
+    signal_error_2 (Qgui_error,
+		    "couldn't load font", build_string (source_name), data);
   if (count == 2)
     mask = 0;
   else if (!mask_name[0])
@@ -1995,9 +1977,9 @@ font_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
     {
       mask = safe_XLoadFont (dpy, mask_name);
       if (!mask)
-	/* continuable */
-	Fsignal (Qerror, list3 (build_string ("couldn't load font"),
-				build_string (mask_name), data));
+	signal_continuable_error_2 (Qgui_error,
+				    "couldn't load font",
+				    build_string (mask_name), data);
     }
   if (!mask)
     mask_char = 0;
@@ -2046,7 +2028,7 @@ cursor_font_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
   Lisp_Object foreground, background;
 
   if (!DEVICE_X_P (XDEVICE (device)))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   dpy = DEVICE_X_DISPLAY (XDEVICE (device));
 
@@ -2055,7 +2037,7 @@ cursor_font_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
 
   LISP_STRING_TO_EXTERNAL (data, name_ext, Qfile_name);
   if ((i = XmuCursorNameToIndex (name_ext)) == -1)
-    signal_simple_error ("Unrecognized cursor-font name", data);
+    invalid_argument ("Unrecognized cursor-font name", data);
 
   x_initialize_pixmap_image_instance (ii, 1, IMAGE_POINTER);
   IMAGE_INSTANCE_X_CURSOR (ii) = XCreateFontCursor (dpy, i);
@@ -2174,14 +2156,6 @@ x_map_subwindow (Lisp_Image_Instance *p, int x, int y,
 		    -dga->xoffset, -dga->yoffset);
       if (!IMAGE_INSTANCE_SUBWINDOW_DISPLAYEDP (p))
 	XtMapWidget (IMAGE_INSTANCE_X_CLIPWIDGET (p));
-      /* See comments in glyphs-msw.c about keyboard focus. */
-      if (IMAGE_INSTANCE_WANTS_INITIAL_FOCUS (p)) {
-	/* #### FIXME to pop-up the find dialog we map the text-field
-	   seven times! This doesn't show on a fast linux box but does
-	   under X on windows. */
-	enqueue_focus_event (IMAGE_INSTANCE_X_WIDGET_ID (p),
-			     IMAGE_INSTANCE_FRAME (p), 1);
-      }
     }
 }
 
@@ -2276,7 +2250,8 @@ x_redisplay_widget (Lisp_Image_Instance *p)
 	{
 	  Lisp_Object sw;
 	  XSETIMAGE_INSTANCE (sw, p);
-	  signal_simple_error ("XEmacs bug: subwindow is deleted", sw);
+	  signal_error (Qinternal_error,
+			     "XEmacs bug: subwindow is deleted", sw);
 	}
 
       lw_add_widget_value_arg (wv, XtNwidth,
@@ -2322,7 +2297,7 @@ x_subwindow_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
     h = IMAGE_INSTANCE_HEIGHT (ii);
 
   if (!DEVICE_X_P (XDEVICE (device)))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   dpy = DEVICE_X_DISPLAY (XDEVICE (device));
   xs = DefaultScreenOfDisplay (dpy);
@@ -2356,14 +2331,6 @@ x_subwindow_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
   IMAGE_INSTANCE_SUBWINDOW_ID (ii) = (void*)win;
 }
 
-/* Account for some of the limitations with widget images. */
-static int
-x_widget_border_width (void)
-{
-  return DEFAULT_WIDGET_BORDER_WIDTH * 2;
-}
-
-
 #if 0
 /* #### Should this function exist? If there's any doubt I'm not implementing it --andyp */
 DEFUN ("change-subwindow-property", Fchange_subwindow_property, 3, 3, 0, /*
@@ -2491,7 +2458,7 @@ x_widget_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
   XColor fcolor, bcolor;
 
   if (!DEVICE_X_P (d))
-    signal_simple_error ("Not an X device", device);
+    gui_error ("Not an X device", device);
 
   /* have to set the type this late in case there is no device
      instantiation for a widget. But we can go ahead and do it without
@@ -2526,10 +2493,6 @@ x_widget_instantiate (Lisp_Object image_instance, Lisp_Object instantiator,
 
   free_widget_value_tree (clip_wv);
 
-  /* create a sensible name. */
-  if (wv->name == 0 || strcmp(wv->name, "") == 0)
-    wv->name = xstrdup (type);
-
   /* copy any args we were given */
   ac = 0;
   lw_add_value_args_to_args (wv, al, &ac);
@@ -2705,18 +2668,18 @@ x_progress_gauge_instantiate (Lisp_Object image_instance, Lisp_Object instantiat
 static void
 x_progress_gauge_redisplay (Lisp_Object image_instance)
 {
-  Lisp_Image_Instance *ii = XIMAGE_INSTANCE (image_instance);
+  Lisp_Image_Instance *p = XIMAGE_INSTANCE (image_instance);
 
-  if (IMAGE_INSTANCE_WIDGET_ITEMS_CHANGED (ii))
+  if (IMAGE_INSTANCE_WIDGET_ITEMS_CHANGED (p))
     {
       Arg al [1];
       Lisp_Object val;
 #ifdef ERROR_CHECK_GLYPHS
-      assert (GUI_ITEMP (IMAGE_INSTANCE_WIDGET_PENDING_ITEMS (ii)));
+      assert (GUI_ITEMP (IMAGE_INSTANCE_WIDGET_PENDING_ITEMS (p)));
 #endif
-      val = XGUI_ITEM (IMAGE_INSTANCE_WIDGET_PENDING_ITEMS (ii))->value;
+      val = XGUI_ITEM (IMAGE_INSTANCE_WIDGET_PENDING_ITEMS (p))->value;
       XtSetArg (al[0], XtNvalue, XINT (val));
-      XtSetValues (IMAGE_INSTANCE_X_WIDGET_ID (ii), al, 1);
+      XtSetValues (IMAGE_INSTANCE_X_WIDGET_ID (p), al, 1);
     }
 }
 
@@ -2801,7 +2764,7 @@ x_tab_control_redisplay (Lisp_Object image_instance)
 		     but I couldn't find it. */
 		  Lisp_Object old_selected =gui_item_list_find_selected
 		    (XCDR (IMAGE_INSTANCE_WIDGET_ITEMS (ii)));
-		  Arg al [2];
+		  Arg al [1];
 		  char* name;
 		  unsigned int num_children, i;
 		  Widget* children;
@@ -2817,9 +2780,7 @@ x_tab_control_redisplay (Lisp_Object image_instance)
 		      if (!strcmp (XtName (children [i]), name))
 			{
 			  XtSetArg (al [0], XtNtopWidget, children [i]);
-			  XtSetArg (al [1], XtNhighlightWidget,
-				    children [i]);
-			  XtSetValues (IMAGE_INSTANCE_X_WIDGET_ID (ii), al, 2);
+			  XtSetValues (IMAGE_INSTANCE_X_WIDGET_ID (ii), al, 1);
 			  break;
 			}
 		    }
@@ -2905,7 +2866,6 @@ console_type_create_glyphs_x (void)
   CONSOLE_HAS_METHOD (x, map_subwindow);
   CONSOLE_HAS_METHOD (x, redisplay_widget);
   CONSOLE_HAS_METHOD (x, redisplay_subwindow);
-  CONSOLE_HAS_METHOD (x, widget_border_width);
 }
 
 void
