@@ -331,9 +331,9 @@ do {										\
 
 struct image_instantiator_methods *
 decode_device_ii_format (Lisp_Object device, Lisp_Object format,
-			 Error_behavior errb);
+			 Error_Behavior errb);
 struct image_instantiator_methods *
-decode_image_instantiator_format (Lisp_Object format, Error_behavior errb);
+decode_image_instantiator_format (Lisp_Object format, Error_Behavior errb);
 
 void add_entry_to_image_instantiator_format_list (Lisp_Object symbol,
 			struct image_instantiator_methods *meths);
@@ -382,7 +382,15 @@ DECLARE_DOESNT_RETURN (incompatible_image_types (Lisp_Object instantiator,
                                                  int given_dest_mask,
                                                  int desired_dest_mask));
 DECLARE_DOESNT_RETURN (signal_image_error (const char *, Lisp_Object));
-DECLARE_DOESNT_RETURN (signal_image_error_2 (const char *, Lisp_Object, Lisp_Object));
+DECLARE_DOESNT_RETURN (signal_image_error_2 (const char *, Lisp_Object,
+					     Lisp_Object));
+DECLARE_DOESNT_RETURN (signal_double_image_error (const char *string1,
+						  const char *string2,
+						  Lisp_Object data));
+DECLARE_DOESNT_RETURN (signal_double_image_error_2 (const char *string1,
+						    const char *string2,
+						    Lisp_Object data1,
+						    Lisp_Object data2));
 
 /************************************************************************/
 /*			Image Specifier Object				*/
@@ -405,7 +413,7 @@ struct image_specifier
   Lisp_Object attachee_property;/* property of that face or glyph */
 };
 
-#define IMAGE_SPECIFIER_DATA(g) (SPECIFIER_TYPE_DATA (g, image))
+#define IMAGE_SPECIFIER_DATA(g) SPECIFIER_TYPE_DATA (g, image)
 #define IMAGE_SPECIFIER_ALLOWED(g) (IMAGE_SPECIFIER_DATA (g)->allowed)
 #define IMAGE_SPECIFIER_ATTACHEE(g) (IMAGE_SPECIFIER_DATA (g)->attachee)
 #define IMAGE_SPECIFIER_ATTACHEE_PROPERTY(g) \
@@ -421,6 +429,7 @@ struct image_specifier
 DECLARE_LRECORD (image_instance, Lisp_Image_Instance);
 #define XIMAGE_INSTANCE(x) XRECORD (x, image_instance, Lisp_Image_Instance)
 #define XSETIMAGE_INSTANCE(x, p) XSETRECORD (x, p, image_instance)
+#define wrap_image_instance(p) wrap_record (p, image_instance)
 #define IMAGE_INSTANCEP(x) RECORDP (x, image_instance)
 #define CHECK_IMAGE_INSTANCE(x) CHECK_RECORD (x, image_instance)
 #define CONCHECK_IMAGE_INSTANCE(x) CONCHECK_RECORD (x, image_instance)
@@ -930,6 +939,7 @@ typedef struct Lisp_Glyph Lisp_Glyph;
 DECLARE_LRECORD (glyph, Lisp_Glyph);
 #define XGLYPH(x) XRECORD (x, glyph, Lisp_Glyph)
 #define XSETGLYPH(x, p) XSETRECORD (x, p, glyph)
+#define wrap_glyph(p) wrap_record (p, glyph)
 #define GLYPHP(x) RECORDP (x, glyph)
 #define CHECK_GLYPH(x) CHECK_RECORD (x, glyph)
 #define CONCHECK_GLYPH(x) CONCHECK_RECORD (x, glyph)
@@ -991,7 +1001,7 @@ Lisp_Object glyph_face (Lisp_Object glyph, Lisp_Object domain);
 int glyph_contrib_p (Lisp_Object glyph, Lisp_Object domain);
 Lisp_Object glyph_image_instance (Lisp_Object glyph,
 				  Lisp_Object domain,
-				  Error_behavior errb, int no_quit);
+				  Error_Behavior errb, int no_quit);
 void file_or_data_must_be_present (Lisp_Object instantiator);
 void data_must_be_present (Lisp_Object instantiator);
 Lisp_Object make_string_from_file (Lisp_Object file);
@@ -1127,7 +1137,9 @@ void get_display_tables (struct window *, face_index,
 void unmap_subwindow (Lisp_Object subwindow);
 void map_subwindow (Lisp_Object subwindow, int x, int y,
 		    struct display_glyph_area *dga);
-int find_matching_subwindow (struct frame* f, int x, int y, int width, int height);
+int find_matching_subwindow (struct frame* f, 
+			     unsigned int x, unsigned int y, 
+			     unsigned int width, unsigned int height);
 void redisplay_widget (Lisp_Object widget);
 void update_widget_instances (Lisp_Object frame);
 void redisplay_subwindow (Lisp_Object subwindow);
@@ -1145,7 +1157,9 @@ struct expose_ignore
   struct expose_ignore *next;
 };
 
-int check_for_ignored_expose (struct frame* f, int x, int y, int width, int height);
+int check_for_ignored_expose (struct frame* f, unsigned int x, 
+			      unsigned int y, unsigned int width, 
+			      unsigned int height);
 extern int hold_ignored_expose_registration;
 
 #endif /* INCLUDED_glyphs_h_ */
