@@ -39,13 +39,9 @@ Boston, MA 02111-1307, USA.  */
 #include "gpmevent.h"
 #include <gpm.h>
 
-#if (!defined(__linux__))	/* possible under xterm */
 #define KG_SHIFT	0
 #define KG_CTRL		2
 #define KG_ALT		3
-#else
-#include <linux/keyboard.h>
-#endif
 
 extern int gpm_tried;
 extern void *gpm_stack;
@@ -536,7 +532,7 @@ Toggle accepting of GPM mouse events.
 
 	if (noninteractive)
 	{
-		error ("Can't connect to GPM in batch mode.");
+	 invalid_operation ("Can't connect to GPM in batch mode.", Qunbound);
 	}
 
 	if (!console_name)
@@ -560,7 +556,7 @@ Toggle accepting of GPM mouse events.
 	*/
 	if (!NILP (Fgpm_enabled_p (device)))
 	{
-		error ("GPM already enabled for this console.");
+	 invalid_operation ("GPM already enabled for this console.", Qunbound);
 	}
 
 	conn.eventMask = GPM_DOWN|GPM_UP|GPM_MOVE|GPM_DRAG;
