@@ -207,10 +207,7 @@ free_popup_widget_value_tree (widget_value *wv)
 }
 
 /* The following is actually called from somewhere within XtDispatchEvent(),
-   called from XtAppProcessEvent() in event-Xt.c
-
-   Callback function for widgets and menus.
- */
+   called from XtAppProcessEvent() in event-Xt.c */
 
 void
 popup_selection_callback (Widget widget, LWLIB_ID ignored_id,
@@ -408,12 +405,12 @@ button_item_to_widget_value (Lisp_Object gui_object_instance,
       return 1;
     }
   else if (!GUI_ITEMP (gui_item))
-    syntax_error ("need a string or a gui_item here", gui_item);
+    invalid_argument ("need a string or a gui_item here", gui_item);
 
   pgui = XGUI_ITEM (gui_item);
 
   if (!NILP (pgui->filter))
-    syntax_error (":filter keyword not permitted on leaf nodes", gui_item);
+    sferror (":filter keyword not permitted on leaf nodes", gui_item);
 
 #ifdef HAVE_MENUBARS
   if (menu_entry_p && !gui_item_included_p (gui_item, Vmenubar_configuration))
@@ -536,13 +533,13 @@ button_item_to_widget_value (Lisp_Object gui_object_instance,
 #endif
     }
   else
-    syntax_error_2 ("Unknown style", pgui->style, gui_item);
+    invalid_constant_2 ("Unknown style", pgui->style, gui_item);
 
   if (!allow_text_field_p && (wv->type == TEXT_TYPE))
-    syntax_error ("Text field not allowed in this context", gui_item);
+    sferror ("Text field not allowed in this context", gui_item);
 
   if (!NILP (pgui->selected) && EQ (pgui->style, Qtext))
-    syntax_error
+    sferror
       (":selected only makes sense with :style toggle, radio or button",
        gui_item);
   return 1;
@@ -587,7 +584,7 @@ gui_items_to_widget_values_1 (Lisp_Object gui_object_instance,
     {
       /* first one is the parent */
       if (CONSP (XCAR (items)))
-	syntax_error ("parent item must not be a list", XCAR (items));
+	sferror ("parent item must not be a list", XCAR (items));
 
       if (parent)
 	wv = gui_items_to_widget_values_1 (gui_object_instance,
@@ -634,7 +631,7 @@ gui_items_to_widget_values (Lisp_Object gui_object_instance, Lisp_Object items,
   Lisp_Object wv_closure;
 
   if (NILP (items))
-    syntax_error ("must have some items", items);
+    sferror ("must have some items", items);
 
   /* Inhibit GC during this conversion.  The reasons for this are
      the same as in menu_item_descriptor_to_widget_value(); see
@@ -666,64 +663,6 @@ gui_items_to_widget_values (Lisp_Object gui_object_instance, Lisp_Object items,
   return control;
 }
 
-/* This is a kludge to make sure emacs can only link against a version of
-   lwlib that was compiled in the right way.  Emacs references symbols which
-   correspond to the way it thinks lwlib was compiled, and if lwlib wasn't
-   compiled in that way, then somewhat meaningful link errors will result.
-   The alternatives to this range from obscure link errors, to obscure
-   runtime errors that look a lot like bugs.
- */
-
-static void
-sanity_check_lwlib (void)
-{
-#define MACROLET(v) { extern int v; v = 1; }
-
-#if (XlibSpecificationRelease == 4)
-  MACROLET (lwlib_uses_x11r4);
-#elif (XlibSpecificationRelease == 5)
-  MACROLET (lwlib_uses_x11r5);
-#elif (XlibSpecificationRelease == 6)
-  MACROLET (lwlib_uses_x11r6);
-#else
-  MACROLET (lwlib_uses_unknown_x11);
-#endif
-#ifdef LWLIB_USES_MOTIF
-  MACROLET (lwlib_uses_motif);
-#else
-  MACROLET (lwlib_does_not_use_motif);
-#endif
-#if (XmVersion >= 1002)
-  MACROLET (lwlib_uses_motif_1_2);
-#else
-  MACROLET (lwlib_does_not_use_motif_1_2);
-#endif
-#ifdef LWLIB_MENUBARS_LUCID
-  MACROLET (lwlib_menubars_lucid);
-#elif defined (HAVE_MENUBARS)
-  MACROLET (lwlib_menubars_motif);
-#endif
-#ifdef LWLIB_SCROLLBARS_LUCID
-  MACROLET (lwlib_scrollbars_lucid);
-#elif defined (LWLIB_SCROLLBARS_MOTIF)
-  MACROLET (lwlib_scrollbars_motif);
-#elif defined (HAVE_SCROLLBARS)
-  MACROLET (lwlib_scrollbars_athena);
-#endif
-#ifdef LWLIB_DIALOGS_MOTIF
-  MACROLET (lwlib_dialogs_motif);
-#elif defined (HAVE_DIALOGS)
-  MACROLET (lwlib_dialogs_athena);
-#endif
-#ifdef LWLIB_WIDGETS_MOTIF
-  MACROLET (lwlib_widgets_motif);
-#elif defined (HAVE_WIDGETS)
-  MACROLET (lwlib_widgets_athena);
-#endif
-
-#undef MACROLET
-}
-
 void
 syms_of_gui_x (void)
 {
@@ -737,9 +676,6 @@ reinit_vars_of_gui_x (void)
 #ifdef HAVE_POPUPS
   popup_up_p = 0;
 #endif
-
-  /* this makes only safe calls as in emacs.c */
-  sanity_check_lwlib ();
 }
 
 void
