@@ -37,6 +37,9 @@ Lisp_Object Qmenu_no_selection_hook;
 Lisp_Object Vmenu_no_selection_hook;
 
 static Lisp_Object parse_gui_item_tree_list (Lisp_Object list);
+Lisp_Object find_keyword_in_vector (Lisp_Object vector, Lisp_Object keyword);
+
+Lisp_Object Qgui_error;
 
 #ifdef HAVE_POPUPS
 
@@ -111,39 +114,63 @@ get_gui_callback (Lisp_Object data, Lisp_Object *fn, Lisp_Object *arg)
  * structure. If KEY is not a keyword, or is an unknown keyword, then
  * error is signaled.
  */
-void
+int
 gui_item_add_keyval_pair (Lisp_Object gui_item,
 			  Lisp_Object key, Lisp_Object val,
-			  Error_behavior errb)
+			  Error_Behavior errb)
 {
   Lisp_Gui_Item *pgui_item = XGUI_ITEM (gui_item);
+  int retval = 0;
 
   if (!KEYWORDP (key))
-    syntax_error_2 ("Non-keyword in gui item", key, pgui_item->name);
+    sferror_2 ("Non-keyword in gui item", key, pgui_item->name);
 
-  if	  (EQ (key, Q_suffix))	 pgui_item->suffix   = val;
-  else if (EQ (key, Q_active))	 pgui_item->active   = val;
-  else if (EQ (key, Q_included)) pgui_item->included = val;
-  else if (EQ (key, Q_config))	 pgui_item->config   = val;
-  else if (EQ (key, Q_filter))	 pgui_item->filter   = val;
-  else if (EQ (key, Q_style))	 pgui_item->style    = val;
-  else if (EQ (key, Q_selected)) pgui_item->selected = val;
-  else if (EQ (key, Q_keys))	 pgui_item->keys     = val;
-  else if (EQ (key, Q_callback)) pgui_item->callback = val;
-  else if (EQ (key, Q_callback_ex)) pgui_item->callback_ex = val;
-  else if (EQ (key, Q_value))	 pgui_item->value     = val;
+  if (EQ (key, Q_descriptor))
+    {
+      if (!EQ (pgui_item->name, val))
+	{
+	  retval = 1;
+	  pgui_item->name   = val;
+	}
+    }
+#define FROB(slot) \
+  else if (EQ (key, Q_##slot))			\
+  {						\
+    if (!EQ (pgui_item->slot, val))			\
+      {						\
+	retval = 1;				\
+	pgui_item->slot   = val;			\
+      }						\
+  }
+  FROB (suffix)
+  FROB (active)
+  FROB (included)
+  FROB (config)
+  FROB (filter)
+  FROB (style)
+  FROB (selected)
+  FROB (keys)
+  FROB (callback)
+  FROB (callback_ex)
+  FROB (value)
+#undef FROB
   else if (EQ (key, Q_key_sequence)) ;   /* ignored for FSF compatibility */
   else if (EQ (key, Q_label)) ;   /* ignored for 21.0 implement in 21.2  */
   else if (EQ (key, Q_accelerator))
     {
-      if (SYMBOLP (val) || CHARP (val))
-	pgui_item->accelerator = val;
-      else if (ERRB_EQ (errb, ERROR_ME))
-	syntax_error ("Bad keyboard accelerator", val);
+      if (!EQ (pgui_item->accelerator, val))
+	{
+	  retval = 1;
+	  if (SYMBOLP (val) || CHARP (val))
+	    pgui_item->accelerator = val;
+	  else if (ERRB_EQ (errb, ERROR_ME))
+	    invalid_argument ("Bad keyboard accelerator", val);
+	}
     }
   else if (ERRB_EQ (errb, ERROR_ME))
-    syntax_error_2 ("Unknown keyword in gui item", key,
+    invalid_argument_2 ("Unknown keyword in gui item", key,
 			   pgui_item->name);
+  return retval;
 }
 
 void
@@ -187,7 +214,7 @@ allocate_gui_item (void)
  */
 static Lisp_Object
 make_gui_item_from_keywords_internal (Lisp_Object item,
-				      Error_behavior errb)
+				      Error_Behavior errb)
 {
   int length, plist_p, start;
   Lisp_Object *contents;
@@ -199,7 +226,7 @@ make_gui_item_from_keywords_internal (Lisp_Object item,
   contents = XVECTOR_DATA (item);
 
   if (length < 1)
-    syntax_error ("GUI item descriptors must be at least 1 elts long", item);
+    sferror ("GUI item descriptors must be at least 1 elts long", item);
 
   /* length 1:     		[ "name" ]
      length 2:		[ "name" callback ]
@@ -234,7 +261,7 @@ make_gui_item_from_keywords_internal (Lisp_Object item,
     {
       int i;
       if ((length - start) & 1)
-	syntax_error (
+	sferror (
 		"GUI item descriptor has an odd number of keywords and values",
 			     item);
 
@@ -248,6 +275,69 @@ make_gui_item_from_keywords_internal (Lisp_Object item,
   return gui_item;
 }
 
+/* This will only work with descriptors in the new format. */
+Lisp_Object
+widget_gui_parse_item_keywords (Lisp_Object item)
+{
+  int i, length;
+  Lisp_Object *contents;
+  Lisp_Object gui_item = allocate_gui_item ();
+  Lisp_Object desc = find_keyword_in_vector (item, Q_descriptor);
+
+  CHECK_VECTOR (item);
+  length = XVECTOR_LENGTH (item);
+  contents = XVECTOR_DATA (item);
+
+  if (!NILP (desc) && !STRINGP (desc) && !VECTORP (desc))
+    sferror ("Invalid GUI item descriptor", item);
+
+  if (length & 1)
+    {
+      if (!SYMBOLP (contents [0]))
+	sferror ("Invalid GUI item descriptor", item);
+      contents++;			/* Ignore the leading symbol. */
+      length--;
+    }
+
+  for (i = 0; i < length;)
+    {
+      Lisp_Object key = contents [i++];
+      Lisp_Object val = contents [i++];
+      gui_item_add_keyval_pair (gui_item, key, val, ERROR_ME_NOT);
+    }
+
+  return gui_item;
+}
+
+/* Update a gui item from a partial descriptor. */
+int
+update_gui_item_keywords (Lisp_Object gui_item, Lisp_Object item)
+{
+  int i, length, retval = 0;
+  Lisp_Object *contents;
+
+  CHECK_VECTOR (item);
+  length = XVECTOR_LENGTH (item);
+  contents = XVECTOR_DATA (item);
+
+ if (length & 1)
+    {
+      if (!SYMBOLP (contents [0]))
+	sferror ("Invalid GUI item descriptor", item);
+      contents++;			/* Ignore the leading symbol. */
+      length--;
+    }
+
+  for (i = 0; i < length;)
+    {
+      Lisp_Object key = contents [i++];
+      Lisp_Object val = contents [i++];
+      if (gui_item_add_keyval_pair (gui_item, key, val, ERROR_ME_NOT))
+	retval = 1;
+    }
+  return retval;
+}
+
 Lisp_Object
 gui_parse_item_keywords (Lisp_Object item)
 {
@@ -398,7 +488,7 @@ gui_item_included_p (Lisp_Object gui_item, Lisp_Object conflist)
 static DOESNT_RETURN
 signal_too_long_error (Lisp_Object name)
 {
-  syntax_error ("GUI item produces too long displayable string", name);
+  invalid_argument ("GUI item produces too long displayable string", name);
 }
 
 #ifdef HAVE_WINDOW_SYSTEM
@@ -611,14 +701,14 @@ print_gui_item (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
   char buf[20];
 
   if (print_readably)
-    error ("printing unreadable object #<gui-item 0x%x>", g->header.uid);
+    printing_unreadable_object ("#<gui-item 0x%x>", g->header.uid);
 
   write_c_string ("#<gui-item ", printcharfun);
   sprintf (buf, "0x%x>", g->header.uid);
   write_c_string (buf, printcharfun);
 }
 
-static Lisp_Object
+Lisp_Object
 copy_gui_item (Lisp_Object gui_item)
 {
   Lisp_Object  ret = allocate_gui_item ();
@@ -683,7 +773,7 @@ parse_gui_item_tree_item (Lisp_Object entry)
       CHECK_STRING (entry);
     }
   else
-    syntax_error ("item must be a vector or a string", entry);
+    sferror ("item must be a vector or a string", entry);
 
   RETURN_UNGCPRO (ret);
 }
@@ -735,6 +825,19 @@ DEFINE_LRECORD_IMPLEMENTATION ("gui-item", gui_item,
 			       0,
 			       Lisp_Gui_Item);
 
+
+DOESNT_RETURN
+gui_error (const char *reason, Lisp_Object frob)
+{
+  signal_error (Qgui_error, reason, frob);
+}
+
+DOESNT_RETURN
+gui_error_2 (const char *reason, Lisp_Object frob0, Lisp_Object frob1)
+{
+  signal_error_2 (Qgui_error, reason, frob0, frob1);
+}
+
 void
 syms_of_gui (void)
 {
@@ -742,6 +845,8 @@ syms_of_gui (void)
 
   DEFSYMBOL (Qmenu_no_selection_hook);
 
+  DEFERROR_STANDARD (Qgui_error, Qio_error);
+
 #ifdef HAVE_POPUPS
   DEFSUBR (Fpopup_up_p);
 #endif
