@@ -41,7 +41,7 @@ Boston, MA 02111-1307, USA.  */
  bits are the Lisp object.  Some people call such Lisp_Objects "immediate".
 
  The object is obtained by masking off the type bits.
- Bit 1 is used as a value bit by splitting the Lisp integer type
+     Bit 1 is used as a value bit by splitting the Lisp integer type
  into two subtypes, Lisp_Type_Int_Even and Lisp_Type_Int_Odd.
  By this trickery we get 31 bits for integers instead of 30.
 
@@ -49,7 +49,7 @@ Boston, MA 02111-1307, USA.  */
  a pointer to a structure containing the object.  The pointer is
  obtained by masking off the type and mark bits.
 
- All pointer-based types are coalesced under a single type called
+     All pointer-based types are coalesced under a single type called
  Lisp_Type_Record.  The type bits for this type are required by the
  implementation to be 00, just like the least significant bits of
  word-aligned struct pointers on 32-bit hardware.  This requires that
@@ -78,7 +78,7 @@ Boston, MA 02111-1307, USA.  */
 typedef EMACS_INT Lisp_Object;
 
 #define Lisp_Type_Int_Bit (Lisp_Type_Int_Even & Lisp_Type_Int_Odd)
-#define wrap_object(ptr) ((Lisp_Object) (ptr))
+#define wrap_pointer_1(ptr) ((Lisp_Object) (ptr))
 #define make_int(x) ((Lisp_Object) (((x) << INT_GCBITS) | Lisp_Type_Int_Bit))
 #define make_char(x) ((Lisp_Object) (((x) << GCBITS) | Lisp_Type_Char))
 #define VALMASK (((1UL << VALBITS) - 1UL) << GCTYPEBITS)
@@ -98,7 +98,7 @@ typedef EMACS_INT Lisp_Object;
 #define EQ(x,y) ((x) == (y))
 #define XSETINT(var, value) ((void) ((var) = make_int (value)))
 #define XSETCHAR(var, value) ((void) ((var) = make_char (value)))
-#define XSETOBJ(var, value) ((void) ((var) = wrap_object (value)))
+#define XSETOBJ(var, value) ((void) ((var) = wrap_pointer_1 (value)))
 
 /* Convert between a (void *) and a Lisp_Object, as when the
    Lisp_Object is passed to a toolkit callback function */
