@@ -36,15 +36,6 @@ Boston, MA 02111-1307, USA.  */
    and temacs will do (load "loadup") automatically unless told otherwise.  */
 /* #define CANNOT_DUMP */
 
-/* Define VIRT_ADDR_VARIES if the virtual addresses of
-   pure and impure space as loaded can vary, and even their
-   relative order cannot be relied on.
-
-   Otherwise Emacs assumes that text space precedes data space,
-   numerically.  */
-
-/* #define VIRT_ADDR_VARIES */  /* Karl Kleinpaste says this isn't needed.  */
-
 /* Define C_ALLOCA if this machine does not support a true alloca
    and the one written in C should be used instead.
    Define HAVE_ALLOCA to say that the system provides a properly
@@ -82,5 +73,4 @@ Boston, MA 02111-1307, USA.  */
 /* omit next three lines if no TCP installed */
 
 #define select gnu_select		/* avoid select() name clash */
-#define HAVE_PTYS			/* we do have PTYs if we have TCP */
 #define LIBS_SYSTEM "-lsocket"		/* get TCP networking functions */
