@@ -59,7 +59,7 @@ print_marker (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
   char buf[200];
 
   if (print_readably)
-    error ("printing unreadable object #<marker 0x%lx>", (long) marker);
+    printing_unreadable_object ("#<marker 0x%lx>", (long) marker);
 
   write_c_string (GETTEXT ("#<marker "), printcharfun);
   if (!marker->buffer)
@@ -168,8 +168,8 @@ check_marker_circularities (struct buffer *buf)
 #endif
 
 static Lisp_Object
-set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
-		     int restricted_p)
+set_marker_internal (Lisp_Object marker, Lisp_Object position,
+		     Lisp_Object buffer, int restricted_p)
 {
   Bufpos charno;
   struct buffer *b;
@@ -182,18 +182,18 @@ set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
 
   /* If position is nil or a marker that points nowhere,
      make this marker point nowhere.  */
-  if (NILP (pos) ||
-      (MARKERP (pos) && !XMARKER (pos)->buffer))
+  if (NILP (position) ||
+      (MARKERP (position) && !XMARKER (position)->buffer))
     {
       if (point_p)
-	signal_simple_error ("Can't make point-marker point nowhere",
-			     marker);
+	invalid_operation ("Can't make point-marker point nowhere",
+			   marker);
       if (XMARKER (marker)->buffer)
 	unchain_marker (marker);
       return marker;
     }
 
-  CHECK_INT_COERCE_MARKER (pos);
+  CHECK_INT_COERCE_MARKER (position);
   if (NILP (buffer))
     b = current_buffer;
   else
@@ -204,7 +204,7 @@ set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
       if (!BUFFER_LIVE_P (XBUFFER (buffer)))
 	{
 	  if (point_p)
-	    signal_simple_error
+	    invalid_operation
 	      ("Can't move point-marker in a killed buffer", marker);
 	  if (XMARKER (marker)->buffer)
 	    unchain_marker (marker);
@@ -212,7 +212,7 @@ set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
 	}
     }
 
-  charno = XINT (pos);
+  charno = XINT (position);
   m = XMARKER (marker);
 
   if (restricted_p)
@@ -231,8 +231,8 @@ set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
 #ifndef moving_point_by_moving_its_marker_is_a_bug
       BUF_SET_PT (b, charno);	/* this will move the marker */
 #else  /* It's not a feature, so it must be a bug */
-      signal_simple_error ("DEBUG: attempt to move point via point-marker",
-			   marker);
+      invalid_operation ("DEBUG: attempt to move point via point-marker",
+			 marker);
 #endif
     }
   else
@@ -243,7 +243,7 @@ set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
   if (m->buffer != b)
     {
       if (point_p)
-	signal_simple_error ("Can't change buffer of point-marker", marker);
+	invalid_operation ("Can't change buffer of point-marker", marker);
       if (m->buffer != 0)
 	unchain_marker (marker);
       m->buffer = b;
@@ -259,26 +259,32 @@ set_marker_internal (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer,
 
 
 DEFUN ("set-marker", Fset_marker, 2, 3, 0, /*
-Position MARKER before character number NUMBER in BUFFER.
+Move MARKER to position POSITION in BUFFER.
+POSITION can be a marker, an integer or nil.  If POSITION is an
+integer, make MARKER point before the POSITIONth character in BUFFER.
+If POSITION is nil, makes MARKER point nowhere.  Then it no longer
+slows down editing in any buffer.  If POSITION is less than 1, move
+MARKER to the beginning of BUFFER.  If POSITION is greater than the
+size of BUFFER, move MARKER to the end of BUFFER.
 BUFFER defaults to the current buffer.
-If NUMBER is nil, makes marker point nowhere.
-Then it no longer slows down editing in any buffer.
-If this marker was returned by (point-marker t), then changing its position
-moves point.  You cannot change its buffer or make it point nowhere.
-Returns MARKER.
+If this marker was returned by (point-marker t), then changing its
+position moves point.  You cannot change its buffer or make it point
+nowhere.
+The return value is MARKER.
 */
-       (marker, number, buffer))
+       (marker, position, buffer))
 {
-  return set_marker_internal (marker, number, buffer, 0);
+  return set_marker_internal (marker, position, buffer, 0);
 }
 
 
 /* This version of Fset_marker won't let the position
    be outside the visible part.  */
 Lisp_Object
-set_marker_restricted (Lisp_Object marker, Lisp_Object pos, Lisp_Object buffer)
+set_marker_restricted (Lisp_Object marker, Lisp_Object position,
+		       Lisp_Object buffer)
 {
-  return set_marker_internal (marker, pos, buffer, 1);
+  return set_marker_internal (marker, position, buffer, 1);
 }
 
 
@@ -321,7 +327,7 @@ bi_marker_position (Lisp_Object marker)
   Bytind pos;
 
   if (!buf)
-    error ("Marker does not point anywhere");
+    invalid_argument ("Marker does not point anywhere", Qunbound);
 
   /* FSF claims that marker indices could end up denormalized, i.e.
      in the gap.  This is way bogus if it ever happens, and means
@@ -345,7 +351,7 @@ marker_position (Lisp_Object marker)
   struct buffer *buf = XMARKER (marker)->buffer;
 
   if (!buf)
-    error ("Marker does not point anywhere");
+    invalid_argument ("Marker does not point anywhere", Qunbound);
 
   return bytind_to_bufpos (buf, bi_marker_position (marker));
 }
@@ -357,7 +363,7 @@ set_bi_marker_position (Lisp_Object marker, Bytind pos)
   struct buffer *buf = m->buffer;
 
   if (!buf)
-    error ("Marker does not point anywhere");
+    invalid_argument ("Marker does not point anywhere", Qunbound);
 
 #ifdef ERROR_CHECK_BUFPOS
   if (pos < BI_BUF_BEG (buf) || pos > BI_BUF_Z (buf))
@@ -373,7 +379,7 @@ set_marker_position (Lisp_Object marker, Bufpos pos)
   struct buffer *buf = XMARKER (marker)->buffer;
 
   if (!buf)
-    error ("Marker does not point anywhere");
+    invalid_argument ("Marker does not point anywhere", Qunbound);
 
   set_bi_marker_position (marker, bufpos_to_bytind (buf, pos));
 }
@@ -404,21 +410,21 @@ copy_marker_1 (Lisp_Object marker, Lisp_Object type, int noseeum)
 }
 
 DEFUN ("copy-marker", Fcopy_marker, 1, 2, 0, /*
-Return a new marker pointing at the same place as MARKER.
-If argument is a number, makes a new marker pointing
+Return a new marker pointing at the same place as MARKER-OR-INTEGER.
+If MARKER-OR-INTEGER is an integer, return a new marker pointing
 at that position in the current buffer.
-The optional argument TYPE specifies the insertion type of the new marker;
-see `marker-insertion-type'.
+Optional argument MARKER-TYPE specifies the insertion type of the new
+marker; see `marker-insertion-type'.
 */
-       (marker, type))
+       (marker_or_integer, marker_type))
 {
-  return copy_marker_1 (marker, type, 0);
+  return copy_marker_1 (marker_or_integer, marker_type, 0);
 }
 
 Lisp_Object
-noseeum_copy_marker (Lisp_Object marker, Lisp_Object type)
+noseeum_copy_marker (Lisp_Object marker, Lisp_Object marker_type)
 {
-  return copy_marker_1 (marker, type, 1);
+  return copy_marker_1 (marker, marker_type, 1);
 }
 
 DEFUN ("marker-insertion-type", Fmarker_insertion_type, 1, 1, 0, /*
