@@ -502,7 +502,7 @@ md5_coding_system (Lisp_Object object, Lisp_Object coding, Lisp_Object istream,
 	    /* Default to binary.  */
 	    coding_system = Fget_coding_system (Qbinary);
 	  else
-	    signal_simple_error ("No such coding system", coding);
+	    invalid_argument ("No such coding system", coding);
 	}
     }
   return coding_system;
@@ -579,7 +579,7 @@ file-coding or Mule support.  Otherwise, they are ignored.
   while (1)
     {
       Bufbyte tempbuf[1024];	/* some random amount */
-      ssize_t size_in_bytes =
+      Lstream_data_count size_in_bytes =
 	Lstream_read (XLSTREAM (instream), tempbuf, sizeof (tempbuf));
       if (!size_in_bytes)
 	break;
