@@ -2,20 +2,20 @@
    Copyright (C) 1995, 1997 Electrotechnical Laboratory, JAPAN.
    Licensed to the Free Software Foundation.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU Emacs; see the file COPYING.  If not, write to
+along with XEmacs; see the file COPYING.  If not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
@@ -41,6 +41,8 @@ Boston, MA 02111-1307, USA.  */
 
 #endif /* not emacs */
 
+Lisp_Object Qccl_error;
+
 /* This contains all code conversion map available to CCL.  */
 Lisp_Object Vcode_conversion_map_vector;
 
@@ -833,9 +835,6 @@ static int stack_idx_of_map_multiple;
       }							\
   } while (0)
 
-#define POSSIBLE_LEADING_BYTE_P(leading_byte) \
-  ((leading_byte > MIN_LEADING_BYTE) && \
-   (leading_byte - MIN_LEADING_BYTE) < NUM_LEADING_BYTES)
 
 /* Set C to the character code made from CHARSET and CODE.  This is
    like MAKE_CHAR but check the validity of CHARSET and CODE.  If they
@@ -1299,16 +1298,6 @@ ccl_driver (struct ccl_program *ccl,
 		    reg[rrr] = i;
 		    reg[RRR] = LEADING_BYTE_ASCII;
 		  }
-		/* Previously, these next two elses were reversed in order,
-		   which should have worked fine, but is more fragile than
-		   this order. */
-		else if (LEADING_BYTE_CONTROL_1 == i)
- 		  {
- 		    if (src >= src_end)
- 		      goto ccl_read_multibyte_character_suspend;
- 		    reg[RRR] = i;
-		    reg[rrr] = (*src++ - 0xA0);
-		  }
 		else if (i <= MAX_LEADING_BYTE_OFFICIAL_1)
 		  {
 		    if (src >= src_end)
@@ -1316,13 +1305,6 @@ ccl_driver (struct ccl_program *ccl,
 		    reg[RRR] = i;
 		    reg[rrr] = (*src++ & 0x7F);
 		  }
-		else if (LEADING_BYTE_CONTROL_1 == i)
-		  {
-		    if (src >= src_end)
-		      goto ccl_read_multibyte_character_suspend;
-		    reg[RRR] = i;
-		    reg[rrr] = (*src++ - 0xA0);
-		  }
 		else if (i <= MAX_LEADING_BYTE_OFFICIAL_2)
 		  {
 		    if ((src + 1) >= src_end)
@@ -1370,29 +1352,15 @@ ccl_driver (struct ccl_program *ccl,
 
 	    case CCL_WriteMultibyteChar2:
 	      i = reg[RRR]; /* charset */
-	      if (i == LEADING_BYTE_ASCII) 
+	      if (i == LEADING_BYTE_ASCII)
 		i = reg[rrr] & 0xFF;
-	      else if (LEADING_BYTE_CONTROL_1 == i)
-		i = ((reg[rrr] & 0xFF) - 0xA0);
-	      else if (POSSIBLE_LEADING_BYTE_P(i) &&
-		       !NILP(CHARSET_BY_LEADING_BYTE(i)))
-		{
-		  if (XCHARSET_DIMENSION (CHARSET_BY_LEADING_BYTE (i)) == 1)
-		    i = (((i - FIELD2_TO_OFFICIAL_LEADING_BYTE) << 7)
-			 | (reg[rrr] & 0x7F));
-		  else if (i <= MAX_LEADING_BYTE_OFFICIAL_2)
-		    i = ((i - FIELD1_TO_OFFICIAL_LEADING_BYTE) << 14) 
-		      | reg[rrr];
-		  else
-		    i = ((i - FIELD1_TO_PRIVATE_LEADING_BYTE) << 14) | reg[rrr];
-		}
-	      else 
-		{
-		  /* No charset we know about; use U+3012 GETA MARK */
-		  i = MAKE_CHAR
-		    (CHARSET_BY_LEADING_BYTE(LEADING_BYTE_JAPANESE_JISX0208),
-		     34, 46);
-		}
+	      else if (XCHARSET_DIMENSION (CHARSET_BY_LEADING_BYTE (i)) == 1)
+		i = (((i - FIELD2_TO_OFFICIAL_LEADING_BYTE) << 7)
+		     | (reg[rrr] & 0x7F));
+	      else if (i < MAX_LEADING_BYTE_OFFICIAL_2)
+		i = ((i - FIELD1_TO_OFFICIAL_LEADING_BYTE) << 14) | reg[rrr];
+	      else
+		i = ((i - FIELD1_TO_PRIVATE_LEADING_BYTE) << 14) | reg[rrr];
 
 	      CCL_WRITE_CHAR (i);
 
@@ -1451,6 +1419,7 @@ ccl_driver (struct ccl_program *ccl,
 
 		for (;i < j;i++)
 		  {
+
 		    size = XVECTOR (Vcode_conversion_map_vector)->size;
 		    point = XINT (ccl_prog[ic++]);
 		    if (point >= size) continue;
@@ -2026,11 +1995,11 @@ See the documentation of `define-ccl-program' for the detail of CCL program.
   int i;
 
   if (setup_ccl_program (&ccl, ccl_prog) < 0)
-    error ("Invalid CCL program");
+    syntax_error ("Invalid CCL program", Qunbound);
 
   CHECK_VECTOR (reg);
   if (XVECTOR_LENGTH (reg) != 8)
-    error ("Length of vector REGISTERS is not 8");
+    syntax_error ("Length of vector REGISTERS is not 8", Qunbound);
 
   for (i = 0; i < 8; i++)
     ccl.reg[i] = (INTP (XVECTOR_DATA (reg)[i])
@@ -2042,7 +2011,7 @@ See the documentation of `define-ccl-program' for the detail of CCL program.
 	      CCL_MODE_ENCODING);
   QUIT;
   if (ccl.status != CCL_STAT_SUCCESS)
-    error ("Error in CCL program at %dth code", ccl.ic);
+    signal_error (Qccl_error, "Error in CCL program at code numbered ...", make_int (ccl.ic));
 
   for (i = 0; i < 8; i++)
     XSETINT (XVECTOR (reg)->contents[i], ccl.reg[i]);
@@ -2083,11 +2052,11 @@ See the documentation of `define-ccl-program' for the detail of CCL program.
   struct gcpro gcpro1, gcpro2;
 
   if (setup_ccl_program (&ccl, ccl_prog) < 0)
-    error ("Invalid CCL program");
+    syntax_error ("Invalid CCL program", Qunbound);
 
   CHECK_VECTOR (status);
   if (XVECTOR (status)->size != 9)
-    error ("Length of vector STATUS is not 9");
+    syntax_error ("Length of vector STATUS is not 9", Qunbound);
   CHECK_STRING (string);
 
   GCPRO2 (status, string);
@@ -2120,10 +2089,10 @@ See the documentation of `define-ccl-program' for the detail of CCL program.
   Dynarr_free (outbuf);
   QUIT;
   if (ccl.status == CCL_STAT_SUSPEND_BY_DST)
-    error ("Output buffer for the CCL programs overflow");
+    signal_error (Qccl_error, "Output buffer for the CCL programs overflow", Qunbound);
   if (ccl.status != CCL_STAT_SUCCESS
       && ccl.status != CCL_STAT_SUSPEND_BY_SRC)
-    error ("Error in CCL program at %dth code", ccl.ic);
+    signal_error (Qccl_error, "Error in CCL program at code numbered...", make_int (ccl.ic));
 
   return val;
 }
@@ -2261,6 +2230,8 @@ Return index number of the registered map.
 void
 syms_of_mule_ccl (void)
 {
+  DEFERROR_STANDARD (Qccl_error, Qconversion_error);
+
   DEFSUBR (Fccl_program_p);
   DEFSUBR (Fccl_execute);
   DEFSUBR (Fccl_execute_on_string);
@@ -2274,10 +2245,10 @@ vars_of_mule_ccl (void)
   staticpro (&Vccl_program_table);
   Vccl_program_table = Fmake_vector (make_int (32), Qnil);
 
-  defsymbol (&Qccl_program, "ccl-program");
-  defsymbol (&Qccl_program_idx, "ccl-program-idx");
-  defsymbol (&Qcode_conversion_map, "code-conversion-map");
-  defsymbol (&Qcode_conversion_map_id, "code-conversion-map-id");
+  DEFSYMBOL (Qccl_program);
+  DEFSYMBOL (Qccl_program_idx);
+  DEFSYMBOL (Qcode_conversion_map);
+  DEFSYMBOL (Qcode_conversion_map_id);
 
   DEFVAR_LISP ("code-conversion-map-vector", &Vcode_conversion_map_vector /*
 Vector of code conversion maps.
