@@ -28,6 +28,7 @@ Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 #define getwd _getwd
 #include "lisp.h"
 #undef getwd
+
 #include "buffer.h"
 
 #include "systime.h"
@@ -444,11 +445,11 @@ win32_get_long_filename (char * name, char * buf, int size)
   char * o = buf;
   char * p;
   char * q;
-  char full[ MAX_PATH ];
+  char full[ PATH_MAX ];
   int len;
 
   len = strlen (name);
-  if (len >= MAX_PATH)
+  if (len >= PATH_MAX)
     return FALSE;
 
   /* Use local copy for destructive modification.  */
@@ -506,7 +507,7 @@ request_sigio (void)
 }
 #endif /* 0 */
 
-#define REG_ROOT "SOFTWARE\\XEmacs\\XEmacs"
+#define REG_ROOT "SOFTWARE\\GNU\\XEmacs"
 
 LPBYTE 
 nt_get_resource (char *key, LPDWORD lpdwtype)
@@ -633,9 +634,9 @@ init_environment (void)
 
   {
     char *p;
-    char modname[MAX_PATH];
+    char modname[PATH_MAX];
 
-    if (!GetModuleFileName (NULL, modname, MAX_PATH))
+    if (!GetModuleFileName (NULL, modname, PATH_MAX))
       abort ();
     if ((p = strrchr (modname, '\\')) == NULL)
       abort ();
@@ -771,12 +772,12 @@ volume_info_data *
 GetCachedVolumeInformation (char * root_dir)
 {
   volume_info_data * info;
-  char default_root[ MAX_PATH ];
+  char default_root[ PATH_MAX ];
 
   /* NULL for root_dir means use root from current directory.  */
   if (root_dir == NULL)
     {
-      if (GetCurrentDirectory (MAX_PATH, default_root) == 0)
+      if (GetCurrentDirectory (PATH_MAX, default_root) == 0)
 	return NULL;
       parse_root (default_root, &root_dir);
       *root_dir = 0;
@@ -861,7 +862,7 @@ GetCachedVolumeInformation (char * root_dir)
 int
 get_volume_info (const char * name, const char ** pPath)
 {
-  char temp[MAX_PATH];
+  char temp[PATH_MAX];
   char *rootname = NULL;  /* default to current volume */
   volume_info_data * info;
 
@@ -921,7 +922,7 @@ is_fat_volume (const char * name, const char ** pPath)
 const char *
 map_win32_filename (const char * name, const char ** pPath)
 {
-  static char shortname[MAX_PATH];
+  static char shortname[PATH_MAX];
   char * str = shortname;
   char c;
   const char * path;
@@ -1123,7 +1124,7 @@ readdir (DIR *dirp)
 int
 sys_rename (const char * oldname, const char * newname)
 {
-  char temp[MAX_PATH];
+  char temp[PATH_MAX];
   DWORD attr;
 
   /* MoveFile on Win95 doesn't correctly change the short file name
@@ -1183,6 +1184,8 @@ static int init = 0;
 
 #if 0
 
+static long double utc_base;
+
 time_t
 convert_time (FILETIME ft)
 {
@@ -1348,14 +1351,14 @@ hashval (const unsigned char * str)
 static DWORD
 generate_inode_val (const char * name)
 {
-  char fullname[ MAX_PATH ];
+  char fullname[ PATH_MAX ];
   char * p;
   unsigned hash;
 
   /* Get the truly canonical filename, if it exists.  (Note: this
      doesn't resolve aliasing due to subst commands, or recognize hard
      links.  */
-  if (!win32_get_long_filename ((char *)name, fullname, MAX_PATH))
+  if (!win32_get_long_filename ((char *)name, fullname, PATH_MAX))
     abort ();
 
   parse_root (fullname, &p);
@@ -1474,7 +1477,6 @@ mswindows_stat (const char * path, struct stat * buf)
   int permission;
   int len;
   int rootdir = FALSE;
-  int errm;
 
   if (path == NULL || buf == NULL)
     {
@@ -1497,16 +1499,13 @@ mswindows_stat (const char * path, struct stat * buf)
   rootdir = (path >= name + len - 1
 	     && (IS_DIRECTORY_SEP (*path) || *path == 0));
   name = strcpy ((char *)alloca (len + 2), name);
-  errm = SetErrorMode (SEM_FAILCRITICALERRORS
-		       | SEM_NOOPENFILEERRORBOX);
+
   if (rootdir)
     {
       if (!IS_DIRECTORY_SEP (name[len-1]))
 	strcat (name, "\\");
-
       if (GetDriveType (name) < 2)
 	{
-	  SetErrorMode (errm);
 	  errno = ENOENT;
 	  return -1;
 	}
@@ -1536,15 +1535,14 @@ mswindows_stat (const char * path, struct stat * buf)
 	}
       else
 	{
-	  fh = FindFirstFile (name, &wfd);
-	  if (fh == INVALID_HANDLE_VALUE)
-	    {
-	      SetErrorMode (errm);
-	      errno = ENOENT;
-	      return -1;
-	    }
-	  FindClose (fh);
+      fh = FindFirstFile (name, &wfd);
+      if (fh == INVALID_HANDLE_VALUE)
+	{
+	  errno = ENOENT;
+	  return -1;
 	}
+      FindClose (fh);
+    }
     }
 
   if (wfd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
@@ -1590,7 +1588,6 @@ mswindows_stat (const char * path, struct stat * buf)
 	}
       else
 	{
-	  SetErrorMode (errm);
 	  errno = EACCES;
 	  return -1;
 	}
@@ -1603,8 +1600,6 @@ mswindows_stat (const char * path, struct stat * buf)
       fake_inode = 0;
     }
 
-  SetErrorMode (errm);
-
 #if 0
   /* Not sure if there is any point in this.  */
   if (!NILP (Vwin32_generate_fake_inodes))
@@ -1693,11 +1688,6 @@ sys_pipe (int * phandles)
   return rc;
 }
 
-void
-term_ntproc (int unused)
-{
-}
-
 void
 init_ntproc (void)
 {
@@ -1760,10 +1750,6 @@ init_ntproc (void)
     _fdopen (2, "w");
   }
 
-  /* unfortunately, atexit depends on implementation of malloc */
-  /* atexit (term_ntproc); */
-  signal (SIGABRT, term_ntproc);
-
   /* determine which drives are fixed, for GetCachedVolumeInformation */
   {
     /* GetDriveType must have trailing backslash. */
@@ -1783,145 +1769,33 @@ init_ntproc (void)
 #ifndef HAVE_TTY
 Lisp_Object
 tty_semi_canonicalize_console_connection (Lisp_Object connection,
-					  Error_behavior errb)
+					  Error_Behavior errb)
 {
   return Vstdio_str;
 }
 
 Lisp_Object
 tty_canonicalize_console_connection (Lisp_Object connection,
-				     Error_behavior errb)
+				     Error_Behavior errb)
 {
   return Vstdio_str;
 }
 
 Lisp_Object
 tty_semi_canonicalize_device_connection (Lisp_Object connection,
-					 Error_behavior errb)
+					 Error_Behavior errb)
 {
   return Vstdio_str;
 }
 
 Lisp_Object
 tty_canonicalize_device_connection (Lisp_Object connection,
-				    Error_behavior errb)
+				    Error_Behavior errb)
 {
   return Vstdio_str;
 }
 #endif
 
-/*--------------------------------------------------------------------*/
-/* Signal support                                                     */
-/*--------------------------------------------------------------------*/
-
-/* We need MS-defined signal and raise here */
-#undef signal
-#undef raise
-
-#define sigmask(nsig) (1U << nsig)
-
-/* We can support as many signals as fit into word */
-#define SIG_MAX 32
-
-/* Signal handlers. Initial value = 0 = SIG_DFL */
-static void (__cdecl *signal_handlers[SIG_MAX])(int) = {0};
-
-/* Signal block mask: bit set to 1 means blocked */
-unsigned signal_block_mask = 0;
-
-/* Signal pending mask: bit set to 1 means sig is pending */
-unsigned signal_pending_mask = 0;
-
-mswindows_sighandler
-mswindows_sigset (int nsig, mswindows_sighandler handler)
-{
-  /* We delegate some signals to the system function */
-  if (nsig == SIGFPE || nsig == SIGABRT || nsig == SIGINT)
-    return signal (nsig, handler);
-
-  if (nsig < 0 || nsig > SIG_MAX)
-    {
-      errno = EINVAL;
-      return NULL;
-    }
-
-  /* Store handler ptr */
-  {
-    mswindows_sighandler old_handler = signal_handlers[nsig];
-    signal_handlers[nsig] = handler;
-    return old_handler;
-  }
-}
-  
-int
-mswindows_sighold (int nsig)
-{
-  if (nsig < 0 || nsig > SIG_MAX)
-    return errno = EINVAL;
-
-  signal_block_mask |= sigmask (nsig);
-  return 0;
-}
-
-int
-mswindows_sigrelse (int nsig)
-{
-  if (nsig < 0 || nsig > SIG_MAX)
-    return errno = EINVAL;
-
-  signal_block_mask &= ~sigmask (nsig);
-
-  if (signal_pending_mask & sigmask (nsig))
-    mswindows_raise (nsig);
-
-  return 0;
-}
-
-int
-mswindows_sigpause (int nsig)
-{
-  /* This is currently not called, because the only call to sigpause
-     inside XEmacs is with SIGCHLD parameter. Just in case, we put an
-     assert here, so anyone adds a call to sigpause will be surprised
-     (or surprise someone else...) */
-  assert (0);
-  return 0;
-}
-
-int
-mswindows_raise (int nsig)
-{
-  /* We delegate some raises to the system routine */
-  if (nsig == SIGFPE || nsig == SIGABRT || nsig == SIGINT)
-    return raise (nsig);
-
-  if (nsig < 0 || nsig > SIG_MAX)
-    return errno = EINVAL;
-
-  /* If the signal is blocked, remember to issue later */
-  if (signal_block_mask & sigmask (nsig))
-    {
-      signal_pending_mask |= sigmask (nsig);
-      return 0;
-    }
-
-  if (signal_handlers[nsig] == SIG_IGN)
-    return 0;
-
-  if (signal_handlers[nsig] != SIG_DFL)
-    {
-      (*signal_handlers[nsig]) (nsig);
-      return 0;
-    }
-
-  /* Default signal actions */
-  if (nsig == SIGALRM || nsig == SIGPROF)
-    exit (3);
-
-  /* Other signals are ignored by default */
-  return 0;
-}
-
 
 /*--------------------------------------------------------------------*/
 /*                        Memory-mapped files                         */
