@@ -1,4 +1,4 @@
-/* Process support for Windows NT port of XEMACS.
+/* Old process support under MS Windows, soon to die.
    Copyright (C) 1992, 1995 Free Software Foundation, Inc.
 
 This file is part of XEmacs.
@@ -24,6 +24,16 @@ Boston, MA 02111-1307, USA.
 /* Adapted for XEmacs by David Hobley <david@spook-le0.cia.com.au> */
 /* Synced with FSF Emacs 19.34.6 by Marc Paquette <marcpa@cam.org> */
 
+/* #### This ENTIRE file is only around because of callproc.c, which
+   in turn is only used in batch mode.
+
+   We only need two things to get rid of both this and callproc.c:
+
+   -- my `stderr-proc' ws, which adds support for a separate stderr
+      in asynch. subprocesses. (it's a feature in `old-call-process-internal'.)
+   -- a noninteractive event loop that supports processes.
+*/
+
 #include <config.h>
 #undef signal
 #undef wait
@@ -935,10 +945,6 @@ sys_kill (int pid, int sig)
   return rc;
 }
 
-#if 0
-/* Sync with FSF Emacs 19.34.6 note: ifdef'ed out in XEmacs */
-extern int report_file_error (const char *, Lisp_Object);
-#endif
 /* The following two routines are used to manipulate stdin, stdout, and
    stderr of our child processes.
 
@@ -976,7 +982,8 @@ prepare_standard_handles (int in, int out, int err, HANDLE handles[3])
 		       0, 
 		       TRUE, 
 		       DUPLICATE_SAME_ACCESS))
-    report_file_error ("Duplicating input handle for child", Qnil);
+    mswindows_report_process_error ("Duplicating input handle for child",
+				    Qunbound, GetLastError ());
   
   if (!DuplicateHandle (parent,
 		       (HANDLE) _get_osfhandle (out),
@@ -985,7 +992,8 @@ prepare_standard_handles (int in, int out, int err, HANDLE handles[3])
 		       0,
 		       TRUE,
 		       DUPLICATE_SAME_ACCESS))
-    report_file_error ("Duplicating output handle for child", Qnil);
+    mswindows_report_process_error ("Duplicating output handle for child",
+				    Qunbound, GetLastError ());
   
   if (!DuplicateHandle (parent,
 		       (HANDLE) _get_osfhandle (err),
@@ -994,17 +1002,21 @@ prepare_standard_handles (int in, int out, int err, HANDLE handles[3])
 		       0,
 		       TRUE,
 		       DUPLICATE_SAME_ACCESS))
-    report_file_error ("Duplicating error handle for child", Qnil);
+    mswindows_report_process_error ("Duplicating error handle for child",
+				    Qunbound, GetLastError ());
 
   /* and store them as our std handles */
   if (!SetStdHandle (STD_INPUT_HANDLE, newstdin))
-    report_file_error ("Changing stdin handle", Qnil);
+    mswindows_report_process_error ("Changing stdin handle",
+				    Qunbound, GetLastError ());
   
   if (!SetStdHandle (STD_OUTPUT_HANDLE, newstdout))
-    report_file_error ("Changing stdout handle", Qnil);
+    mswindows_report_process_error ("Changing stdout handle",
+				    Qunbound, GetLastError ());
 
   if (!SetStdHandle (STD_ERROR_HANDLE, newstderr))
-    report_file_error ("Changing stderr handle", Qnil);
+    mswindows_report_process_error ("Changing stderr handle",
+				    Qunbound, GetLastError ());
 }
 
 void
@@ -1037,7 +1049,7 @@ All path elements in FILENAME are converted to their short names.
 */
        (filename))
 {
-  char shortname[MAX_PATH];
+  char shortname[PATH_MAX];
 
   CHECK_STRING (filename);
 
@@ -1045,7 +1057,7 @@ All path elements in FILENAME are converted to their short names.
   filename = Fexpand_file_name (filename, Qnil);
 
   /* luckily, this returns the short version of each element in the path.  */
-  if (GetShortPathName (XSTRING_DATA (filename), shortname, MAX_PATH) == 0)
+  if (GetShortPathName (XSTRING_DATA (filename), shortname, PATH_MAX) == 0)
     return Qnil;
 
   CORRECT_DIR_SEPS (shortname);
@@ -1061,14 +1073,14 @@ All path elements in FILENAME are converted to their long names.
 */
        (filename))
 {
-  char longname[ MAX_PATH ];
+  char longname[ PATH_MAX ];
 
   CHECK_STRING (filename);
 
   /* first expand it.  */
   filename = Fexpand_file_name (filename, Qnil);
 
-  if (!win32_get_long_filename (XSTRING_DATA (filename), longname, MAX_PATH))
+  if (!win32_get_long_filename (XSTRING_DATA (filename), longname, PATH_MAX))
     return Qnil;
 
   CORRECT_DIR_SEPS (longname);
@@ -1289,8 +1301,8 @@ syms_of_ntproc (void)
 void
 vars_of_ntproc (void)
 {
-  defsymbol (&Qhigh, "high");
-  defsymbol (&Qlow, "low");
+  DEFSYMBOL (Qhigh);
+  DEFSYMBOL (Qlow);
 
   DEFVAR_LISP ("win32-quote-process-args", &Vwin32_quote_process_args /*
     Non-nil enables quoting of process arguments to ensure correct parsing.
@@ -1316,7 +1328,7 @@ When non-nil, they show their window in the method of their choice.
 	       &Vwin32_start_process_share_console /*
     When nil, processes started via start-process are given a new console.
 When non-nil, they share the Emacs console; this has the limitation of
-allowing only only DOS subprocess to run at a time (whether started directly
+allowing only one DOS subprocess to run at a time (whether started directly
 or indirectly by Emacs), and preventing Emacs from cleanly terminating the
 subprocess group, but may allow Emacs to interrupt a subprocess that doesn't
 otherwise respond to interrupts from Emacs.
