@@ -49,7 +49,7 @@ Boston, MA 02111-1307, USA.  */
 #include "device.h"
 #include "insdel.h"
 
-typedef struct colormap_t 
+typedef struct colormap_t
 {
   const char *name;
   COLORREF colorref;
@@ -58,10 +58,10 @@ typedef struct colormap_t
 /* Colors from X11R6 "XConsortium: rgb.txt,v 10.41 94/02/20 18:39:36 rws Exp" */
 /* MSWindows tends to round up the numbers in it's palette, ie where X uses
  * 127, MSWindows uses 128. Colors commented as "Adjusted" are tweaked to
- * match the Windows standard palette to increase the likelyhood of
+ * match the Windows standard palette to increase the likelihood of
  * mswindows_color_to_string() finding a named match.
  */
-static const colormap_t mswindows_X_color_map[] = 
+static const colormap_t mswindows_X_color_map[] =
 {
   {"white"		, PALETTERGB (255, 255, 255) },
   {"black"		, PALETTERGB (0, 0, 0) },
@@ -727,14 +727,14 @@ static const colormap_t mswindows_X_color_map[] =
 };
 
 
-typedef struct fontmap_t 
+typedef struct fontmap_t
 {
   const char *name;
   int value;
 } fontmap_t;
 
 /* Default weight first, preferred names listed before synonyms */
-static const fontmap_t fontweight_map[] = 
+static const fontmap_t fontweight_map[] =
 {
   {"Regular"		, FW_REGULAR},	/* The standard font weight */
   {"Thin"		, FW_THIN},
@@ -752,9 +752,9 @@ static const fontmap_t fontweight_map[] =
   {"Black"		, FW_BLACK}
 };
 
-/* Default charset first, no synonyms allowed because these names are 
+/* Default charset first, no synonyms allowed because these names are
  * matched against the names reported by win32 by match_font() */
-static const fontmap_t charset_map[] = 
+static const fontmap_t charset_map[] =
 {
   {"Western"		, ANSI_CHARSET},
   {"Symbol"		, SYMBOL_CHARSET},
@@ -784,7 +784,7 @@ static const fontmap_t charset_map[] =
 /************************************************************************/
 
 static int
-hexval (char c) 
+hexval (char c)
 {
   /* assumes ASCII and isxdigit(c) */
   if (c >= 'a')
@@ -805,7 +805,7 @@ mswindows_string_to_color(const char *name)
       /* numeric names look like "#RRGGBB", "#RRRGGGBBB" or "#RRRRGGGGBBBB"
 	 or "rgb:rrrr/gggg/bbbb" */
       unsigned int r, g, b;
-  
+
       for (i=1; i<strlen(name); i++)
 	{
 	  if (!isxdigit ((int)name[i]))
@@ -854,7 +854,7 @@ mswindows_string_to_color(const char *name)
 	    }
 	  return (PALETTERGB (r, g, b));
 	}
-      else 
+      else
 	return (COLORREF) -1;
     }
   else if (*name)	/* Can't be an empty string */
@@ -961,7 +961,70 @@ struct font_enum_t
 };
 
 static int CALLBACK
-font_enum_callback_2 (ENUMLOGFONTEX *lpelfe, NEWTEXTMETRICEX *lpntme, 
+old_font_enum_callback_2 (ENUMLOGFONT FAR *lpelfe, NEWTEXTMETRIC FAR *lpntme,
+			  int FontType, struct font_enum_t *font_enum)
+{
+  char fontname[MSW_FONTSIZE];
+  Lisp_Object fontname_lispstr;
+  int i;
+
+  /*
+   * The enumerated font weights are not to be trusted because:
+   *  a) lpelfe->elfStyle is only filled in for TrueType fonts.
+   *  b) Not all Bold and Italic styles of all fonts (including some Vector,
+   *     Truetype and Raster fonts) are enumerated.
+   * I guess that fonts for which Bold and Italic styles are generated
+   * 'on-the-fly' are not enumerated. It would be overly restrictive to
+   * disallow Bold And Italic weights for these fonts, so we just leave
+   * weights unspecified. This means that we have to weed out duplicates of
+   * those fonts that do get enumerated with different weights.
+   */
+  if (FontType == 0 /*vector*/ || FontType == TRUETYPE_FONTTYPE)
+    /* Scalable, so leave pointsize blank */
+    sprintf (fontname, "%s::::", lpelfe->elfLogFont.lfFaceName);
+  else
+    /* Formula for pointsize->height from LOGFONT docs in Platform SDK */
+    sprintf (fontname, "%s::%d::", lpelfe->elfLogFont.lfFaceName,
+	     MulDiv (lpntme->tmHeight - lpntme->tmInternalLeading,
+	             72, GetDeviceCaps (font_enum->hdc, LOGPIXELSY)));
+
+  /*
+   * The enumerated font character set strings are not to be trusted because
+   * lpelfe->elfScript is returned in the host language and not in English.
+   * We can't know a priori the translations of "Western", "Central European"
+   * etc into the host language, so we must use English. The same argument
+   * applies to the font weight string when matching fonts.
+   */
+  for (i=0; i<countof (charset_map); i++)
+    if (lpelfe->elfLogFont.lfCharSet == charset_map[i].value)
+      {
+	strcat (fontname, charset_map[i].name);
+	break;
+      }
+  if (i==countof (charset_map))
+    strcpy (fontname, charset_map[0].name);
+
+  /* Add the font name to the list if not already there */
+  fontname_lispstr = build_string (fontname);
+  if (NILP (memq_no_quit (fontname_lispstr, font_enum->list)))
+    font_enum->list = Fcons (fontname_lispstr, font_enum->list);
+
+  return 1;
+}
+
+static int CALLBACK
+old_font_enum_callback_1 (ENUMLOGFONT FAR *lpelfe, NEWTEXTMETRIC FAR *lpntme,
+			  int FontType, struct font_enum_t *font_enum)
+{
+  /* This function gets called once per facename per character set.
+   * We call a second callback to enumerate the fonts in each facename */
+  return EnumFontFamilies (font_enum->hdc, lpelfe->elfLogFont.lfFaceName,
+			   (FONTENUMPROC) old_font_enum_callback_2,
+			   (LPARAM) font_enum);
+}
+
+static int CALLBACK
+font_enum_callback_2 (ENUMLOGFONTEX *lpelfe, NEWTEXTMETRICEX *lpntme,
 		      int FontType, struct font_enum_t *font_enum)
 {
   char fontname[MSW_FONTSIZE];
@@ -971,7 +1034,7 @@ font_enum_callback_2 (ENUMLOGFONTEX *lpelfe, NEWTEXTMETRICEX *lpntme,
   /*
    * The enumerated font weights are not to be trusted because:
    *  a) lpelfe->elfStyle is only filled in for TrueType fonts.
-   *  b) Not all Bold and Italic styles of all fonts (inluding some Vector,
+   *  b) Not all Bold and Italic styles of all fonts (including some Vector,
    *     Truetype and Raster fonts) are enumerated.
    * I guess that fonts for which Bold and Italic styles are generated
    * 'on-the-fly' are not enumerated. It would be overly restrictive to
@@ -1013,14 +1076,14 @@ font_enum_callback_2 (ENUMLOGFONTEX *lpelfe, NEWTEXTMETRICEX *lpntme,
 }
 
 static int CALLBACK
-font_enum_callback_1 (ENUMLOGFONTEX *lpelfe, NEWTEXTMETRICEX *lpntme, 
+font_enum_callback_1 (ENUMLOGFONTEX *lpelfe, NEWTEXTMETRICEX *lpntme,
 		      int FontType, struct font_enum_t *font_enum)
 {
   /* This function gets called once per facename per character set.
    * We call a second callback to enumerate the fonts in each facename */
-  return EnumFontFamiliesEx (font_enum->hdc, &lpelfe->elfLogFont,
-			     (FONTENUMPROC) font_enum_callback_2,
-			     (LPARAM) font_enum, 0);
+  return xEnumFontFamiliesExA (font_enum->hdc, &lpelfe->elfLogFont,
+			       (FONTENUMPROC) font_enum_callback_2,
+			       (LPARAM) font_enum, 0);
 }
 
 /*
@@ -1040,8 +1103,13 @@ mswindows_enumerate_fonts (HDC hdc)
   logfont.lfPitchAndFamily = DEFAULT_PITCH;
   font_enum.hdc = hdc;
   font_enum.list = Qnil;
-  EnumFontFamiliesEx (hdc, &logfont, (FONTENUMPROC) font_enum_callback_1,
-		      (LPARAM) (&font_enum), 0);
+  if (xEnumFontFamiliesExA)
+    xEnumFontFamiliesExA (hdc, &logfont, (FONTENUMPROC) font_enum_callback_1,
+			  (LPARAM) (&font_enum), 0);
+  else /* NT 3.5x */
+    EnumFontFamilies (hdc, 0, (FONTENUMPROC) old_font_enum_callback_1,
+		      (LPARAM) (&font_enum));
+
   return font_enum.list;
 }
 
@@ -1101,7 +1169,7 @@ mswindows_get_hfont (Lisp_Font_Instance* f,
 
 static int
 mswindows_initialize_color_instance (Lisp_Color_Instance *c, Lisp_Object name,
-			       Lisp_Object device, Error_behavior errb)
+			       Lisp_Object device, Error_Behavior errb)
 {
   const char *extname;
   COLORREF color;
@@ -1116,7 +1184,8 @@ mswindows_initialize_color_instance (Lisp_Color_Instance *c, Lisp_Object name,
       COLOR_INSTANCE_MSWINDOWS_COLOR (c) = color;
       return 1;
     }
-  maybe_signal_simple_error ("Unrecognized color", name, Qcolor, errb);
+  maybe_signal_error (Qinvalid_constant,
+			   "Unrecognized color", name, Qcolor, errb);
   return(0);
 }
 
@@ -1189,13 +1258,13 @@ static void
 mswindows_finalize_font_instance (Lisp_Font_Instance *f);
 
 /*
- * This is a work horse for both mswindows_initialize_font_instanc and
+ * This is a work horse for both mswindows_initialize_font_instance and
  * msprinter_initialize_font_instance.
  */
 static int
 initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 			  Lisp_Object device_font_list, HDC hdc,
-			  Error_behavior errb)
+			  Error_Behavior errb)
 {
   const char *extname;
   LOGFONT logfont;
@@ -1207,7 +1276,8 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
   HFONT hfont, hfont2;
   TEXTMETRIC metrics;
 
-  extname = XSTRING_DATA (name);
+  /* !!#### more mule bogosity */
+  extname = (const char *) XSTRING_DATA (name);
 
   /*
    * mswindows fonts look like:
@@ -1233,7 +1303,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 
   if (fields < 0)
   {
-    maybe_signal_simple_error ("Invalid font", name, Qfont, errb);
+    maybe_signal_error (Qinvalid_argument, "Invalid font", name, Qfont, errb);
     return (0);
   }
 
@@ -1244,7 +1314,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
   }
   else
   {
-    maybe_signal_simple_error ("Must specify a font name", name, Qfont, errb);
+    maybe_signal_error (Qinvalid_argument, "Must specify a font name", name, Qfont, errb);
     return (0);
   }
 
@@ -1263,7 +1333,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 
   for (i=0; i<countof (fontweight_map); i++)
     if (!stricmp (weight, fontweight_map[i].name))
-      {	
+      {
 	logfont.lfWeight = fontweight_map[i].value;
 	break;
       }
@@ -1276,7 +1346,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 	}
       else
 	{
-	  maybe_signal_simple_error ("Invalid font weight", name, Qfont, errb);
+	  maybe_signal_error (Qinvalid_constant, "Invalid font weight", name, Qfont, errb);
 	  return (0);
 	}
     }
@@ -1288,7 +1358,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 	logfont.lfItalic = TRUE;
       else
       {
-        maybe_signal_simple_error ("Invalid font weight or style", name, Qfont, errb);
+        maybe_signal_error (Qinvalid_constant, "Invalid font weight or style", name, Qfont, errb);
 	return (0);
       }
 
@@ -1303,7 +1373,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
     pt = 10;	/* #### Should we reject strings that don't specify a size? */
   else if ((pt=atoi(points)) == 0)
     {
-      maybe_signal_simple_error ("Invalid font pointsize", name, Qfont, errb);
+      maybe_signal_error (Qinvalid_argument, "Invalid font pointsize", name, Qfont, errb);
       return (0);
     }
 
@@ -1333,7 +1403,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 	logfont.lfStrikeOut = TRUE;
       else
         {
-          maybe_signal_simple_error ("Invalid font effect", name, Qfont, errb);
+          maybe_signal_error (Qinvalid_constant, "Invalid font effect", name, Qfont, errb);
 	  return (0);
 	}
 
@@ -1345,7 +1415,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 	    logfont.lfStrikeOut = TRUE;
 	  else
 	    {
-	      maybe_signal_simple_error ("Invalid font effect", name,
+	      maybe_signal_error (Qinvalid_constant, "Invalid font effect", name,
 					 Qfont, errb);
 	      return (0);
 	    }
@@ -1366,7 +1436,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
     effects[0] = '\0';
 
   /* Charset */
-  /* charset can be specified even if earlier fields havn't been */
+  /* charset can be specified even if earlier fields haven't been */
   if (fields < 5)
     {
       if ((c=strchr (extname, ':')) && (c=strchr (c+1, ':')) &&
@@ -1388,7 +1458,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 
   if (i == countof (charset_map))	/* No matching charset */
     {
-      maybe_signal_simple_error ("Invalid charset", name, Qfont, errb);
+      maybe_signal_error (Qinvalid_argument, "Invalid charset", name, Qfont, errb);
       return 0;
     }
 
@@ -1420,25 +1490,26 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
       sprintf (truename, "%s:%s:%d:%s:%s", fontname, weight, pt, effects, charset);
       LIST_LOOP (fonttail, device_font_list)
 	{
-	  if (match_font (XSTRING_DATA (XCAR (fonttail)), truename, NULL))
+	  /* !!#### more mule bogosity */
+	  if (match_font ((char *) XSTRING_DATA (XCAR (fonttail)), truename, NULL))
 	    break;
 	}
       if (NILP (fonttail))
 	{
-	  maybe_signal_simple_error ("No matching font", name, Qfont, errb);
+	  maybe_signal_error (Qinvalid_argument, "No matching font", name, Qfont, errb);
 	  return 0;
 	}
     }
 
   if ((hfont = CreateFontIndirect(&logfont)) == NULL)
   {
-    maybe_signal_simple_error ("Couldn't create font", name, Qfont, errb);
+    maybe_signal_error (Qgui_error, "Couldn't create font", name, Qfont, errb);
     return 0;
   }
 
   f->data = xnew_and_zero (struct mswindows_font_instance_data);
   FONT_INSTANCE_MSWINDOWS_HFONT_VARIANT (f,0,0) = hfont;
-  
+
   /* Some underlined fonts have the descent of one pixel more than their
      non-underlined counterparts. Font variants though are assumed to have
      identical metrics. So get the font metrics from the underlined variant
@@ -1451,7 +1522,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
   if (!hfont2)
     {
       mswindows_finalize_font_instance (f);
-      maybe_signal_simple_error ("Couldn't map font", name, Qfont, errb);
+      maybe_signal_error (Qgui_error, "Couldn't map font", name, Qfont, errb);
       return 0;
     }
   GetTextMetrics (hdc, &metrics);
@@ -1468,7 +1539,7 @@ initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 
 static int
 mswindows_initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
-				    Lisp_Object device, Error_behavior errb)
+				    Lisp_Object device, Error_Behavior errb)
 {
   HDC hdc = CreateCompatibleDC (NULL);
   Lisp_Object font_list = DEVICE_MSWINDOWS_FONTLIST (XDEVICE (device));
@@ -1479,7 +1550,7 @@ mswindows_initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 
 static int
 msprinter_initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
-				    Lisp_Object device, Error_behavior errb)
+				    Lisp_Object device, Error_Behavior errb)
 {
   HDC hdc = DEVICE_MSPRINTER_HDC (XDEVICE (device));
   Lisp_Object font_list = DEVICE_MSPRINTER_FONTLIST (XDEVICE (device));
@@ -1518,7 +1589,7 @@ mswindows_print_font_instance (Lisp_Font_Instance *f,
 			       int escapeflag)
 {
   char buf[10];
-  sprintf (buf, " 0x%lx", 
+  sprintf (buf, " 0x%lx",
 	   (unsigned long)FONT_INSTANCE_MSWINDOWS_HFONT_VARIANT (f,0,0));
   write_c_string (buf, printcharfun);
 }
@@ -1535,7 +1606,8 @@ mswindows_list_fonts (Lisp_Object pattern, Lisp_Object device)
 
   LIST_LOOP (fonttail, DEVICE_MSWINDOWS_FONTLIST (XDEVICE (device)))
     {
-      if (match_font (XSTRING_DATA (XCAR (fonttail)), extpattern, NULL))
+      /* !!#### more mule bogosity */
+      if (match_font ((char *) XSTRING_DATA (XCAR (fonttail)), extpattern, NULL))
 	result = Fcons (XCAR (fonttail), result);
     }
 
@@ -1553,7 +1625,7 @@ mswindows_list_fonts (Lisp_Object pattern, Lisp_Object device)
  * Missing parts of the font spec should be filled in with these values:
  *	Courier New:Regular:10::Western */
 static Lisp_Object
-mswindows_font_instance_truename (Lisp_Font_Instance *f, Error_behavior errb)
+mswindows_font_instance_truename (Lisp_Font_Instance *f, Error_Behavior errb)
 {
   int nsep=0;
   char *name = (char *) XSTRING_DATA (f->name);
@@ -1583,7 +1655,7 @@ mswindows_font_instance_truename (Lisp_Font_Instance *f, Error_behavior errb)
       break;
     default:;
     }
-  
+
   return build_ext_string (extname, Qnative);
 }
 
@@ -1597,7 +1669,7 @@ mswindows_font_spec_matches_charset (struct device *d, Lisp_Object charset,
   /* #### Implement me */
   if (UNBOUNDP (charset))
     return 1;
-  
+
   return 1;
 }
 
@@ -1661,7 +1733,7 @@ console_type_create_objects_mswindows (void)
 /*  CONSOLE_HAS_METHOD (mswindows, mark_font_instance); */
   CONSOLE_HAS_METHOD (mswindows, print_font_instance);
   CONSOLE_HAS_METHOD (mswindows, finalize_font_instance);
-  CONSOLE_HAS_METHOD (mswindows, font_instance_truename); 
+  CONSOLE_HAS_METHOD (mswindows, font_instance_truename);
   CONSOLE_HAS_METHOD (mswindows, list_fonts);
 #ifdef MULE
   CONSOLE_HAS_METHOD (mswindows, font_spec_matches_charset);
@@ -1684,7 +1756,7 @@ console_type_create_objects_mswindows (void)
 /*  CONSOLE_INHERITS_METHOD (msprinter, mswindows, mark_font_instance); */
   CONSOLE_INHERITS_METHOD (msprinter, mswindows, print_font_instance);
   CONSOLE_INHERITS_METHOD (msprinter, mswindows, finalize_font_instance);
-  CONSOLE_INHERITS_METHOD (msprinter, mswindows, font_instance_truename); 
+  CONSOLE_INHERITS_METHOD (msprinter, mswindows, font_instance_truename);
   CONSOLE_INHERITS_METHOD (msprinter, mswindows, list_fonts);
 #ifdef MULE
   CONSOLE_INHERITS_METHOD (msprinter, mswindows, font_spec_matches_charset);
