@@ -226,7 +226,7 @@ allocate_nearest_color (Display *display, Colormap colormap, Visual *visual,
 
 static int
 x_parse_nearest_color (struct device *d, XColor *color, Lisp_Object name,
-		       Error_behavior errb)
+		       Error_Behavior errb)
 {
   Display *dpy   = DEVICE_X_DISPLAY  (d);
   Colormap cmap  = DEVICE_X_COLORMAP (d);
@@ -242,14 +242,15 @@ x_parse_nearest_color (struct device *d, XColor *color, Lisp_Object name,
   }
   if (!result)
     {
-      maybe_signal_simple_error ("Unrecognized color", name, Qcolor, errb);
+      maybe_signal_error (Qgui_error, "Unrecognized color",
+			  name, Qcolor, errb);
       return 0;
     }
   result = allocate_nearest_color (dpy, cmap, visual, color);
   if (!result)
     {
-      maybe_signal_simple_error ("Couldn't allocate color", name, Qcolor,
-				 errb);
+      maybe_signal_error (Qgui_error, "Couldn't allocate color",
+			  name, Qcolor, errb);
       return 0;
     }
 
@@ -258,7 +259,7 @@ x_parse_nearest_color (struct device *d, XColor *color, Lisp_Object name,
 
 static int
 x_initialize_color_instance (Lisp_Color_Instance *c, Lisp_Object name,
-			     Lisp_Object device, Error_behavior errb)
+			     Lisp_Object device, Error_Behavior errb)
 {
   XColor color;
   int result;
@@ -284,7 +285,7 @@ x_print_color_instance (Lisp_Color_Instance *c,
 			Lisp_Object printcharfun,
 			int escapeflag)
 {
-  Bufbyte buf[100];
+  char buf[100];
   XColor color = COLOR_INSTANCE_X_COLOR (c);
   sprintf (buf, " %ld=(%X,%X,%X)",
 	   color.pixel, color.red, color.green, color.blue);
@@ -363,7 +364,7 @@ x_valid_color_name_p (struct device *d, Lisp_Object color)
 
 static int
 x_initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
-			    Lisp_Object device, Error_behavior errb)
+			    Lisp_Object device, Error_Behavior errb)
 {
   Display *dpy = DEVICE_X_DISPLAY (XDEVICE (device));
   XFontStruct *xf;
@@ -374,8 +375,8 @@ x_initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
 
   if (!xf)
     {
-      maybe_signal_simple_error ("Couldn't load font", f->name,
-				 Qfont, errb);
+      maybe_signal_error (Qgui_error, "Couldn't load font", f->name, Qfont,
+			  errb);
       return 0;
     }
 
@@ -383,8 +384,8 @@ x_initialize_font_instance (Lisp_Font_Instance *f, Lisp_Object name,
     {
       /* yes, this has been known to happen. */
       XFreeFont (dpy, xf);
-      maybe_signal_simple_error ("X font is too small", f->name,
-				 Qfont, errb);
+      maybe_signal_error (Qgui_error, "X font is too small", f->name, Qfont,
+			  errb);
       return 0;
     }
 
@@ -466,7 +467,7 @@ x_print_font_instance (Lisp_Font_Instance *f,
 		       Lisp_Object printcharfun,
 		       int escapeflag)
 {
-  Bufbyte buf[200];
+  char buf[200];
   sprintf (buf, " 0x%lx", (unsigned long) FONT_INSTANCE_X_FONT (f)->fid);
   write_c_string (buf, printcharfun);
 }
@@ -577,7 +578,7 @@ valid_x_font_name_p (Display *dpy, Extbyte *name)
      might be more correct.
    */
   int nnames = 0;
-  SExtbyte **names = 0;
+  Extbyte **names = 0;
   if (! name)
     return 0;
   names = XListFonts (dpy, name, 1, &nnames);
@@ -687,7 +688,7 @@ static Extbyte *
 truename_via_XListFonts (Display *dpy, Extbyte *font_name)
 {
   Extbyte *result = 0;
-  SExtbyte **names;
+  Extbyte **names;
   int count = 0;
 
 #ifndef XOPENFONT_SORTS
@@ -773,7 +774,7 @@ x_font_truename (Display *dpy, Extbyte *name, XFontStruct *font)
 }
 
 static Lisp_Object
-x_font_instance_truename (Lisp_Font_Instance *f, Error_behavior errb)
+x_font_instance_truename (Lisp_Font_Instance *f, Error_Behavior errb)
 {
   struct device *d = XDEVICE (f->device);
 
@@ -792,14 +793,14 @@ x_font_instance_truename (Lisp_Font_Instance *f, Error_behavior errb)
 	  Lisp_Object font_instance;
 	  XSETFONT_INSTANCE (font_instance, f);
 
-	  maybe_signal_simple_error ("Couldn't determine font truename",
-				     font_instance, Qfont, errb);
+	  maybe_signal_error (Qgui_error, "Couldn't determine font truename",
+			      font_instance, Qfont, errb);
 	  /* Ok, just this once, return the font name as the truename.
 	     (This is only used by Fequal() right now.) */
 	  return f->name;
 	}
     }
-  return (FONT_INSTANCE_X_TRUENAME (f));
+  return FONT_INSTANCE_X_TRUENAME (f);
 }
 
 static Lisp_Object
@@ -808,22 +809,23 @@ x_font_instance_properties (Lisp_Font_Instance *f)
   struct device *d = XDEVICE (f->device);
   int i;
   Lisp_Object result = Qnil;
-  XFontProp *props;
-  Display *dpy;
+  Display *dpy = DEVICE_X_DISPLAY (d);
+  XFontProp *props = FONT_INSTANCE_X_FONT (f)->properties;
 
-  dpy = DEVICE_X_DISPLAY (d);
-  props = FONT_INSTANCE_X_FONT (f)->properties;
   for (i = FONT_INSTANCE_X_FONT (f)->n_properties - 1; i >= 0; i--)
     {
       Lisp_Object name, value;
       Atom atom = props [i].name;
       Bufbyte *name_str = 0;
+      size_t name_len;
       Extbyte *namestrext = XGetAtomName (dpy, atom);
 
       if (namestrext)
-	EXTERNAL_TO_C_STRING (namestrext, name_str, Qx_atom_name_encoding);
+	TO_INTERNAL_FORMAT (C_STRING, namestrext,
+			    ALLOCA, (name_str, name_len),
+			    Qx_atom_name_encoding);
 
-      name = (name_str ? intern (name_str) : Qnil);
+      name = (name_str ? intern ((char *) name_str) : Qnil);
       if (name_str &&
 	  (atom == XA_FONT ||
 	   atom == DEVICE_XATOM_FOUNDRY (d) ||
@@ -835,17 +837,17 @@ x_font_instance_properties (Lisp_Font_Instance *f)
 	   atom == DEVICE_XATOM_SPACING (d) ||
 	   atom == DEVICE_XATOM_CHARSET_REGISTRY (d) ||
 	   atom == DEVICE_XATOM_CHARSET_ENCODING (d) ||
-	   !strcmp (name_str, "CHARSET_COLLECTIONS") ||
-	   !strcmp (name_str, "FONTNAME_REGISTRY") ||
-	   !strcmp (name_str, "CLASSIFICATION") ||
-	   !strcmp (name_str, "COPYRIGHT") ||
-	   !strcmp (name_str, "DEVICE_FONT_NAME") ||
-	   !strcmp (name_str, "FULL_NAME") ||
-	   !strcmp (name_str, "MONOSPACED") ||
-	   !strcmp (name_str, "QUALITY") ||
-	   !strcmp (name_str, "RELATIVE_SET") ||
-	   !strcmp (name_str, "RELATIVE_WEIGHT") ||
-	   !strcmp (name_str, "STYLE")))
+	   !bufbyte_strcmp (name_str, "CHARSET_COLLECTIONS") ||
+	   !bufbyte_strcmp (name_str, "FONTNAME_REGISTRY") ||
+	   !bufbyte_strcmp (name_str, "CLASSIFICATION") ||
+	   !bufbyte_strcmp (name_str, "COPYRIGHT") ||
+	   !bufbyte_strcmp (name_str, "DEVICE_FONT_NAME") ||
+	   !bufbyte_strcmp (name_str, "FULL_NAME") ||
+	   !bufbyte_strcmp (name_str, "MONOSPACED") ||
+	   !bufbyte_strcmp (name_str, "QUALITY") ||
+	   !bufbyte_strcmp (name_str, "RELATIVE_SET") ||
+	   !bufbyte_strcmp (name_str, "RELATIVE_WEIGHT") ||
+	   !bufbyte_strcmp (name_str, "STYLE")))
 	{
 	  Extbyte *val_str = XGetAtomName (dpy, props [i].card32);
 
@@ -863,7 +865,7 @@ x_font_instance_properties (Lisp_Font_Instance *f)
 static Lisp_Object
 x_list_fonts (Lisp_Object pattern, Lisp_Object device)
 {
-  SExtbyte **names;
+  Extbyte **names;
   int count = 0;
   Lisp_Object result = Qnil;
   const Extbyte *patternext;
@@ -936,7 +938,7 @@ x_font_spec_matches_charset (struct device *d, Lisp_Object charset,
 static Lisp_Object
 x_find_charset_font (Lisp_Object device, Lisp_Object font, Lisp_Object charset)
 {
-  SExtbyte **names;
+  Extbyte **names;
   int count = 0;
   Lisp_Object result = Qnil;
   const Extbyte *patternext;
@@ -950,12 +952,15 @@ x_find_charset_font (Lisp_Object device, Lisp_Object font, Lisp_Object charset)
   for (i = 0; i < count; i ++)
     {
       const Bufbyte *intname;
+      Bytecount intlen;
 
-      EXTERNAL_TO_C_STRING (names[i], intname, Qx_font_name_encoding);
+      TO_INTERNAL_FORMAT (C_STRING, names[i],
+			  ALLOCA, (intname, intlen),
+			  Qx_font_name_encoding);
       if (x_font_spec_matches_charset (XDEVICE (device), charset,
 				       intname, Qnil, 0, -1))
 	{
-	  result = build_string (intname);
+	  result = make_string (intname, intlen);
 	  break;
 	}
     }
