@@ -113,15 +113,15 @@ TODO (in rough order of priority):
 Lisp_Object Vpg_coding_system;
 #endif
 
-#define CHECK_LIVE_CONNECTION(P) { \
-	if (!P || (PQstatus (P) != CONNECTION_OK)) { \
-		char *e = "bad value"; \
-		if (P) e = PQerrorMessage (P); \
-		error ("dead connection [%s]", e); \
-	} }
-#define PUKE_IF_NULL(p) { \
-	if (!p) error ("bad value"); \
-	}
+#define CHECK_LIVE_CONNECTION(P) do {					\
+	if (!P || (PQstatus (P) != CONNECTION_OK)) {			\
+		char *e = "bad value";					\
+		if (P) e = PQerrorMessage (P);				\
+	 signal_ferror (Qprocess_error, "dead connection [%s]", e);	\
+	} } while (0)
+#define PUKE_IF_NULL(p) do {						 \
+	if (!p) signal_error (Qinvalid_argument, "bad value", Qunbound); \
+	} while (0)
 
 static Lisp_Object VXPGHOST;
 static Lisp_Object VXPGUSER;
@@ -220,7 +220,7 @@ print_pgconn (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
     strcpy (buf, "#<PGconn connecting>"); /* evil! */
 
   if (print_readably)
-    error ("printing unreadable object %s", buf);
+    printing_unreadable_object ("%s", buf);
   else
     write_c_string (buf, printcharfun);
 }
@@ -245,8 +245,8 @@ finalize_pgconn (void *header, int for_disksave)
   Lisp_PGconn *pgconn = (Lisp_PGconn *)header;
 
   if (for_disksave)
-    signal_simple_error ("Can't dump an emacs containing PGconn objects",
-                         make_pgconn (pgconn));
+    invalid_operation ("Can't dump an emacs containing PGconn objects",
+		       make_pgconn (pgconn));
 
   if (pgconn->pgconn)
     {
@@ -335,7 +335,7 @@ notuples:
     strcpy (buf, "#<PGresult DEAD>"); /* evil! */
 
   if (print_readably)
-    error ("printing unreadable object %s", buf);
+    printing_unreadable_object ("%s", buf);
   else
     write_c_string (buf, printcharfun);
 }
@@ -364,8 +364,8 @@ finalize_pgresult (void *header, int for_disksave)
   Lisp_PGresult *pgresult = (Lisp_PGresult *)header;
 
   if (for_disksave)
-    signal_simple_error ("Can't dump an emacs containing PGresult objects",
-                         make_pgresult (pgresult));
+    invalid_operation ("Can't dump an emacs containing PGresult objects",
+		       make_pgresult (pgresult));
 
   if (pgresult->pgresult)
     {
@@ -482,7 +482,7 @@ Make a new connection to a PostgreSQL backend.
 	  buf[sizeof (buf) - 1] = '\0';
 	  PQfinish (P);
 	}
-      error ("libpq: %s", buf);
+      signal_ferror (Qprocess_error, "libpq: %s", buf);
     }
 }
 
@@ -525,7 +525,7 @@ Make a new asynchronous connection to a PostgreSQL backend.
 	  buf[sizeof (buf) - 1] = '\0';
 	  PQfinish (P);
 	}
-      error ("libpq: %s", buf);
+      signal_ferror (Qprocess_error, "libpq: %s", buf);
     }
 }
 
@@ -549,7 +549,7 @@ Poll an asynchronous connection for completion
       /* Something Bad has happened */
       {
 	char *e = PQerrorMessage (P);
-	error ("libpq: %s", e);
+	signal_ferror (Qprocess_error, "libpq: %s", e);
       }
     case PGRES_POLLING_OK:
       return Qpgres_polling_ok;
@@ -561,7 +561,7 @@ Poll an asynchronous connection for completion
       return Qpgres_polling_active;
     default:
       /* they've added a new field we don't know about */
-      error ("Help!  Unknown status code %08x from backend!", polling_status);
+      signal_ferror (Qprocess_error, "Help!  Unknown status code %08x from backend!", polling_status);
     }
 }
 
@@ -599,7 +599,7 @@ Set client coding system.
 		      C_STRING_ALLOCA, c_encoding, Qnative);
 
   if ((rc = PQsetClientEncoding (P, c_encoding)) < 0)
-    error ("bad encoding");
+    signal_error (Qinvalid_argument, "bad encoding", Qunbound);
   else
     return make_int (rc);
 }
@@ -715,7 +715,7 @@ Reset connection to the backend asynchronously.
   if (PQresetStart (P)) return Qt;
   {
     char *e = PQerrorMessage (P);
-    error ("libpq: %s", e);
+    signal_ferror (Qprocess_error, "libpq: %s", e);
   }
 }
 
@@ -739,7 +739,7 @@ Poll an asynchronous reset for completion.
       /* Something Bad has happened */
       {
 	char *e = PQerrorMessage (P);
-	error ("libpq: %s", e);
+	signal_ferror (Qprocess_error, "libpq: %s", e);
       }
     case PGRES_POLLING_OK:
       return Qpgres_polling_ok;
@@ -751,7 +751,7 @@ Poll an asynchronous reset for completion.
       return Qpgres_polling_active;
     default:
       /* they've added a new field we don't know about */
-      error ("Help!  Unknown status code %08x from backend!", polling_status);
+      signal_ferror (Qprocess_error, "Help!  Unknown status code %08x from backend!", polling_status);
     }
 }
 #endif
@@ -859,7 +859,7 @@ pq::backend-pid   Process ID of backend process
 #endif /* HAVE_POSTGRESQLV7 */
 	default:
 	  /* they've added a new field we don't know about */
-	  error ("Help!  Unknown connection status code %08x from backend!", cst);
+	  signal_ferror (Qprocess_error, "Help!  Unknown connection status code %08x from backend!", cst);
 	}
     }
   else if (EQ (field, Qpqerrormessage))
@@ -875,7 +875,7 @@ pq::backend-pid   Process ID of backend process
      */
     return make_int (PQbackendPID(P));
   else
-    error ("bad PGconn accessor");
+    signal_error (Qinvalid_argument, "bad PGconn accessor", Qunbound);
 }
 
 /* Query functions */
@@ -902,7 +902,7 @@ Submit a query to Postgres and wait for the result.
   {
     char *tag, buf[BLCKSZ];
 
-    if (!R) error ("query: out of memory");
+    if (!R) out_of_memory ("query: out of memory", Qunbound);
     else
       switch (PQresultStatus (R))
 	{
@@ -918,7 +918,7 @@ err:
 	  strncpy (buf, PQresultErrorMessage (R), sizeof (buf));
 	  buf [sizeof (buf) - 1] = '\0';
 	  PQclear (R);
-	  error (tag, buf);
+	  signal_ferror (Qprocess_error, tag, buf);
 	  /*NOTREACHED*/
 	default:
 	  break;
@@ -951,7 +951,7 @@ Returns: t if successfully submitted
 		      C_STRING_ALLOCA, c_query, Qnative);
 
   if (PQsendQuery (P, c_query)) return Qt;
-  else error ("async query: %s", PQerrorMessage (P));
+  else signal_ferror (Qprocess_error, "async query: %s", PQerrorMessage (P));
 }
 
 DEFUN ("pq-get-result", Fpq_get_result, 1, 1, 0, /*
@@ -989,7 +989,7 @@ err:
 	strncpy (buf, PQresultErrorMessage (R), sizeof (buf));
 	buf[sizeof (buf) - 1] = '\0';
 	PQclear (R);
-	error (tag, buf);
+	signal_ferror (Qprocess_error, tag, buf);
 	/*NOTREACHED*/
       default:
 	break;
@@ -1025,7 +1025,7 @@ Return result status of the query.
   case PGRES_FATAL_ERROR: return Qpgres_fatal_error;
   default:
     /* they've added a new field we don't know about */
-    error ("Help!  Unknown exec status code %08x from backend!", est);
+    signal_ferror (Qprocess_error, "Help!  Unknown exec status code %08x from backend!", est);
   }
 }
 
@@ -1434,10 +1434,10 @@ Make an empty PGresult object with the given status.
   else if (EQ (status, Qpgres_bad_response)) est = PGRES_BAD_RESPONSE;
   else if (EQ (status, Qpgres_nonfatal_error)) est = PGRES_NONFATAL_ERROR;
   else if (EQ (status, Qpgres_fatal_error)) est = PGRES_FATAL_ERROR;
-  else signal_simple_error ("bad status symbol", status);
+  else invalid_constant ("bad status symbol", status);
 
   R = PQmakeEmptyPGresult (P, est);
-  if (!R) error ("out of memory?");
+  if (!R) out_of_memory (0, Qunbound);
 
   lpgr = allocate_pgresult ();
   lpgr->pgresult = R;
@@ -1582,11 +1582,11 @@ syms_of_postgresql(void)
   INIT_LRECORD_IMPLEMENTATION (pgconn);
   INIT_LRECORD_IMPLEMENTATION (pgresult);
 #endif
-  defsymbol (&Qpostgresql, "postgresql");
+  DEFSYMBOL (Qpostgresql);
 
   /* opaque exported types */
-  defsymbol (&Qpgconnp, "pgconnp");
-  defsymbol (&Qpgresultp, "pgresultp");
+  DEFSYMBOL (Qpgconnp);
+  DEFSYMBOL (Qpgresultp);
 
   /* connection status types */
   defsymbol (&Qpg_connection_ok, "pg::connection-ok");
@@ -1698,8 +1698,6 @@ syms_of_postgresql(void)
 void
 vars_of_postgresql(void)
 {
-  char *p;
-
   Fprovide (Qpostgresql);
 #ifdef HAVE_POSTGRESQLV7
   Fprovide (intern ("postgresqlv7"));
@@ -1711,6 +1709,97 @@ Default Postgres client coding system.
 */ );
 #endif
 
+  DEFVAR_LISP ("pg:host", &VXPGHOST /*
+Default PostgreSQL server name.
+If not set, the server running on the local host is used.  The
+initial value is set from the PGHOST environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:user", &VXPGUSER /*
+Default PostgreSQL user name.
+This value is used when connecting to a database for authentication.
+The initial value is set from the PGUSER environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:options", &VXPGOPTIONS /*
+Default PostgreSQL user name.
+This value is used when connecting to a database for authentication.
+The initial value is set from the PGUSER environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:port", &VXPGPORT /*
+Default port to connect to PostgreSQL backend.
+This value is used when connecting to a database.
+The initial value is set from the PGPORT environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:tty", &VXPGTTY /*
+Default debugging TTY.
+There is no useful setting of this variable in the XEmacs Lisp API.
+The initial value is set from the PGTTY environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:database", &VXPGDATABASE /*
+Default database to connect to.
+The initial value is set from the PGDATABASE environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:realm", &VXPGREALM /*
+Default kerberos realm to use for authentication.
+The initial value is set from the PGREALM environment variable.
+*/ );
+
+#ifdef MULE
+  /* It's not clear whether this is any use.  My intent is to
+     autodetect the coding system from the database. */
+  DEFVAR_LISP ("pg:client-encoding", &VXPGCLIENTENCODING /*
+Default client encoding to use.
+The initial value is set from the PGCLIENTENCODING environment variable.
+*/ );
+#endif
+
+#if !defined(HAVE_POSTGRESQLV7)
+  DEFVAR_LISP ("pg:authtype", &VXPGAUTHTYPE /*
+Default authentication to use.
+The initial value is set from the PGAUTHTYPE environment variable.
+
+WARNING:  This variable has gone away in versions of PostgreSQL newer
+than 6.5.
+*/ );
+#endif
+
+  DEFVAR_LISP ("pg:geqo", &VXPGGEQO /*
+Genetic Query Optimizer options.
+The initial value is set from the PGGEQO environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:cost-index", &VXPGCOSTINDEX /*
+Default cost index options.
+The initial value is set from the PGCOSTINDEX environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:cost-heap", &VXPGCOSTHEAP /*
+Default cost heap options.
+The initial value is set from the PGCOSTHEAP environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:tz", &VXPGTZ /*
+Default timezone to use.
+The initial value is set from the PGTZ environment variable.
+*/ );
+
+  DEFVAR_LISP ("pg:date-style", &VXPGDATESTYLE /*
+Default date style to use.
+The initial value is set from the PGDATESTYLE environment variable.
+*/ );
+}
+
+/* These initializations should not be done at dump-time. */
+void
+init_postgresql_from_environment(void)
+{
+  char *p;
+
   if ((p = getenv ("PGHOST")))
     {
       VXPGHOST = build_ext_string (p, PG_OS_CODING);
@@ -1719,11 +1808,6 @@ Default Postgres client coding system.
     {
       VXPGHOST = Qnil;
     }
-  DEFVAR_LISP ("pg:host", &VXPGHOST /*
-Default PostgreSQL server name.
-If not set, the server running on the local host is used.  The
-initial value is set from the PGHOST environment variable.
-*/ );
 
   if ((p = getenv ("PGUSER")))
     {
@@ -1733,11 +1817,6 @@ initial value is set from the PGHOST environment variable.
     {
       VXPGUSER = Qnil;
     }
-  DEFVAR_LISP ("pg:user", &VXPGUSER /*
-Default PostgreSQL user name.
-This value is used when connecting to a database for authentication.
-The initial value is set from the PGUSER environment variable.
-*/ );
 
   if ((p = getenv ("PGOPTIONS")))
     {
@@ -1747,11 +1826,6 @@ The initial value is set from the PGUSER environment variable.
     {
       VXPGOPTIONS = Qnil;
     }
-  DEFVAR_LISP ("pg:options", &VXPGOPTIONS /*
-Default PostgreSQL user name.
-This value is used when connecting to a database for authentication.
-The initial value is set from the PGUSER environment variable.
-*/ );
 
   if ((p = getenv ("PGPORT")))
     {
@@ -1761,11 +1835,6 @@ The initial value is set from the PGUSER environment variable.
     {
       VXPGPORT = Qnil;
     }
-  DEFVAR_LISP ("pg:port", &VXPGPORT /*
-Default port to connect to PostgreSQL backend.
-This value is used when connecting to a database.
-The initial value is set from the PGPORT environment variable.
-*/ );
 
   if ((p = getenv ("PGTTY")))
     {
@@ -1775,11 +1844,6 @@ The initial value is set from the PGPORT environment variable.
     {
       VXPGTTY = Qnil;
     }
-  DEFVAR_LISP ("pg:tty", &VXPGTTY /*
-Default debugging TTY.
-There is no useful setting of this variable in the XEmacs Lisp API.
-The initial value is set from the PGTTY environment variable.
-*/ );
 
   if ((p = getenv ("PGDATABASE")))
     {
@@ -1789,10 +1853,6 @@ The initial value is set from the PGTTY environment variable.
     {
       VXPGDATABASE = Qnil;
     }
-  DEFVAR_LISP ("pg:database", &VXPGDATABASE /*
-Default database to connect to.
-The initial value is set from the PGDATABASE environment variable.
-*/ );
 
   if ((p = getenv ("PGREALM")))
     {
@@ -1802,10 +1862,6 @@ The initial value is set from the PGDATABASE environment variable.
     {
       VXPGREALM = Qnil;
     }
-  DEFVAR_LISP ("pg:realm", &VXPGREALM /*
-Default kerberos realm to use for authentication.
-The initial value is set from the PGREALM environment variable.
-*/ );
 
 #ifdef MULE
   /* It's not clear whether this is any use.  My intent is to
@@ -1818,10 +1874,6 @@ The initial value is set from the PGREALM environment variable.
     {
       VXPGCLIENTENCODING = Qnil;
     }
-  DEFVAR_LISP ("pg:client-encoding", &VXPGCLIENTENCODING /*
-Default client encoding to use.
-The initial value is set from the PGCLIENTENCODING environment variable.
-*/ );
 #endif
 
 #if !defined(HAVE_POSTGRESQLV7)
@@ -1833,13 +1885,6 @@ The initial value is set from the PGCLIENTENCODING environment variable.
     {
       VXPGAUTHTYPE = Qnil;
     }
-  DEFVAR_LISP ("pg:authtype", &VXPGAUTHTYPE /*
-Default authentication to use.
-The initial value is set from the PGAUTHTYPE environment variable.
-
-WARNING:  This variable has gone away in versions of PostgreSQL newer
-than 6.5.
-*/ );
 #endif
 
   if ((p = getenv ("PGGEQO")))
@@ -1850,10 +1895,6 @@ than 6.5.
     {
       VXPGGEQO = Qnil;
     }
-  DEFVAR_LISP ("pg:geqo", &VXPGGEQO /*
-Genetic Query Optimizer options.
-The initial value is set from the PGGEQO environment variable.
-*/ );
 
   if ((p = getenv ("PGCOSTINDEX")))
     {
@@ -1863,10 +1904,6 @@ The initial value is set from the PGGEQO environment variable.
     {
       VXPGCOSTINDEX = Qnil;
     }
-  DEFVAR_LISP ("pg:cost-index", &VXPGCOSTINDEX /*
-Default cost index options.
-The initial value is set from the PGCOSTINDEX environment variable.
-*/ );
 
   if ((p = getenv ("PGCOSTHEAP")))
     {
@@ -1876,10 +1913,6 @@ The initial value is set from the PGCOSTINDEX environment variable.
     {
       VXPGCOSTHEAP = Qnil;
     }
-  DEFVAR_LISP ("pg:cost-heap", &VXPGCOSTHEAP /*
-Default cost heap options.
-The initial value is set from the PGCOSTHEAP environment variable.
-*/ );
 
   if ((p = getenv ("PGTZ")))
     {
@@ -1889,10 +1922,6 @@ The initial value is set from the PGCOSTHEAP environment variable.
     {
       VXPGTZ = Qnil;
     }
-  DEFVAR_LISP ("pg:tz", &VXPGTZ /*
-Default timezone to use.
-The initial value is set from the PGTZ environment variable.
-*/ );
 
   if ((p = getenv ("PGDATESTYLE")))
     {
@@ -1902,8 +1931,5 @@ The initial value is set from the PGTZ environment variable.
     {
       VXPGDATESTYLE = Qnil;
     }
-  DEFVAR_LISP ("pg:date-style", &VXPGDATESTYLE /*
-Default date style to use.
-The initial value is set from the PGDATESTYLE environment variable.
-*/ );
 }
+
