@@ -10,10 +10,12 @@ Please send patches to this file to me first before submitting them to
 xemacs-patches.
 */
 
-#ifndef XEMACS_POSTGRESQL_H__
-#define XEMACS_POSTGRESQL_H__ 1
+#ifndef INCLUDED_postgresql_h_
+#define INCLUDED_postgresql_h_ 1
 
-#define BLCKSZ 8192 /* size of a default Postres disk block */
+#include LIBPQ_FE_H_FILE /* main PostgreSQL header file */
+
+#define BLCKSZ 8192 /* size of a default Postgres disk block */
 /*
   This file contains the GCC bug workaround code for the private
   LRECORD types.
@@ -33,6 +35,7 @@ DECLARE_LRECORD (pgconn, Lisp_PGconn);
 
 #define XPGCONN(x) XRECORD (x, pgconn, Lisp_PGconn)
 #define XSETPGCONN(x, p) XSETRECORD (x, p, pgconn)
+#define wrap_pgconn(p) wrap_record (p, pgconn)
 #define PGCONNP(x) RECORDP (x, pgconn)
 #define CHECK_PGCONN(x) CHECK_RECORD (x, pgconn)
 #define CONCHECK_PGCONN(x) CONCHECK_RECORD (x, pgconn)
@@ -53,8 +56,9 @@ DECLARE_LRECORD (pgresult, Lisp_PGresult);
 
 #define XPGRESULT(x) XRECORD (x, pgresult, Lisp_PGresult)
 #define XSETPGRESULT(x, p) XSETRECORD (x, p, pgresult)
+#define wrap_pgresult(p) wrap_record (p, pgresult)
 #define PGRESULTP(x) RECORDP (x, pgresult)
 #define CHECK_PGRESULT(x) CHECK_RECORD (x, pgresult)
 #define CONCHECK_PGRESULT(x) CONCHECK_RECORD (x, pgresult)
 
-#endif /* XEMACS_POSTGRESQL_H__ */
+#endif /* INCLUDED_postgresql_h_ */
