@@ -108,7 +108,7 @@ static void
 close_safely (int fd)
 {
   stop_interrupts ();
-  signal (SIGALRM, close_safely_handler);
+  set_timeout_signal (SIGALRM, close_safely_handler);
   alarm (1);
   close (fd);
   alarm (0);
@@ -198,7 +198,6 @@ connect_to_file_descriptor (Lisp_Object name, Lisp_Object buffer,
   return proc;
 }
 
-#ifdef HAVE_PTYS
 static int allocate_pty_the_old_fashioned_way (void);
 
 /* The file name of the (slave) pty opened by allocate_pty().  */
@@ -410,7 +409,6 @@ allocate_pty_the_old_fashioned_way (void)
       } /* iteration */
   return -1;
 }
-#endif /* HAVE_PTYS */
 
 static int
 create_bidirectional_pipe (int *inchannel, int *outchannel,
@@ -443,7 +441,7 @@ create_bidirectional_pipe (int *inchannel, int *outchannel,
 #ifndef USE_GETADDRINFO
 static int
 get_internet_address (Lisp_Object host, struct sockaddr_in *address,
-		      Error_behavior errb)
+		      Error_Behavior errb)
 {
   struct hostent *host_info_ptr = NULL;
 #ifdef TRY_AGAIN
@@ -456,9 +454,7 @@ get_internet_address (Lisp_Object host, struct sockaddr_in *address,
     {
 #ifdef TRY_AGAIN
       if (count++ > 10) break;
-#ifndef BROKEN_CYGWIN
       h_errno = 0;
-#endif
 #endif
       /* Some systems can't handle SIGIO/SIGALARM in gethostbyname. */
       slow_down_interrupts ();
@@ -483,8 +479,8 @@ get_internet_address (Lisp_Object host, struct sockaddr_in *address,
       numeric_addr = inet_addr ((char *) XSTRING_DATA (host));
       if (NUMERIC_ADDR_ERROR)
 	{
-	  maybe_error (Qprocess, errb,
-		       "Unknown host \"%s\"", XSTRING_DATA (host));
+	  maybe_signal_error (Qio_error, "Unknown host", host,
+				   Qprocess, errb);
 	  return 0;
 	}
 
@@ -814,7 +810,7 @@ unix_init_process (void)
 #ifndef CANNOT_DUMP
   if (! noninteractive || initialized)
 #endif
-    signal (SIGCHLD, sigchld_handler);
+    EMACS_SIGNAL (SIGCHLD, sigchld_handler);
 }
 #endif /* SIGCHLD */
 
@@ -854,7 +850,6 @@ unix_create_process (Lisp_Process *p,
   volatile int forkout  = -1;
   volatile int pty_flag = 0;
 
-#ifdef HAVE_PTYS
   if (!NILP (Vprocess_connection_type))
     {
       /* find a new pty, open the master side, return the opened
@@ -863,7 +858,7 @@ unix_create_process (Lisp_Process *p,
       outchannel = inchannel = allocate_pty ();
     }
 
-  if (inchannel >= 0)
+  if (inchannel >= 0)		/* We successfully allocated a pty. */
     {
       /* You're "supposed" to now open the slave in the child.
 	 On some systems, we can open it here; this allows for
@@ -884,7 +879,6 @@ unix_create_process (Lisp_Process *p,
       UNIX_DATA(p)->pty_flag = pty_flag = 1;
     }
   else
-#endif /* HAVE_PTYS */
     if (create_bidirectional_pipe (&inchannel, &outchannel,
 				   &forkin, &forkout) < 0)
       goto io_failure;
@@ -924,7 +918,6 @@ unix_create_process (Lisp_Process *p,
 
 	disconnect_controlling_terminal ();
 
-#ifdef HAVE_PTYS
 	if (pty_flag)
 	  {
 	    /* Open the pty connection and make the pty's terminal
@@ -1039,17 +1032,15 @@ unix_create_process (Lisp_Process *p,
 	       a SIG_IGN handling from our parent (nohup) and we are in new
 	       process group.
 	    */
-	    signal (SIGHUP, SIG_DFL);
-	  }
+	    EMACS_SIGNAL (SIGHUP, SIG_DFL);
 
-	if (pty_flag)
-	  /* Set up the terminal characteristics of the pty. */
-	  child_setup_tty (xforkout);
+	    /* Set up the terminal characteristics of the pty. */
+	    child_setup_tty (xforkout);
+	  } /* if (pty_flag) */
 
-#endif /* HAVE_PTYS */
 
-	signal (SIGINT,  SIG_DFL);
-	signal (SIGQUIT, SIG_DFL);
+	EMACS_SIGNAL (SIGINT,  SIG_DFL);
+	EMACS_SIGNAL (SIGQUIT, SIG_DFL);
 
 	{
 	  char *current_dir;
@@ -1083,7 +1074,7 @@ unix_create_process (Lisp_Process *p,
       int save_errno = errno;
       close_descriptor_pair (forkin, forkout);
       errno = save_errno;
-      report_file_error ("Doing fork", Qnil);
+      report_process_error ("Doing fork", Qunbound);
     }
 
   /* #### dmoore - why is this commented out, otherwise we leave
@@ -1098,12 +1089,7 @@ unix_create_process (Lisp_Process *p,
   if (forkin != forkout && forkout >= 0)
     close (forkout);
 
-#ifdef HAVE_PTYS
-  if (pty_flag)
-    UNIX_DATA (p)->tty_name = build_string (pty_name);
-  else
-#endif
-    UNIX_DATA (p)->tty_name = Qnil;
+  UNIX_DATA (p)->tty_name = pty_flag ? build_string (pty_name) : Qnil;
 
   /* Notice that SIGCHLD was not blocked. (This is not possible on
      some systems.) No biggie if SIGCHLD occurs right around the
@@ -1118,7 +1104,7 @@ io_failure:
     close_descriptor_pair (forkin, forkout);
     close_descriptor_pair (inchannel, outchannel);
     errno = save_errno;
-    report_file_error ("Opening pty or pipe", Qnil);
+    report_process_error ("Opening pty or pipe", Qunbound);
     return 0; /* not reached */
   }
 }
@@ -1301,17 +1287,21 @@ unix_send_process (Lisp_Object proc, struct lstream* lstream)
 	    break; /* perhaps should abort() if < 0?
 		      This should never happen. */
 	  old_sigpipe =
-	    (SIGTYPE (*) (int)) signal (SIGPIPE, send_process_trap);
+	    (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGPIPE, send_process_trap);
 	  /* Lstream_write() will never successfully write less than
 	     the amount sent in.  In the worst case, it just buffers
 	     the unwritten data. */
 	  writeret = Lstream_write (XLSTREAM (DATA_OUTSTREAM(p)), chunkbuf,
 				    chunklen);
-	  signal (SIGPIPE, old_sigpipe);
-	  if (writeret < 0)
-	    /* This is a real error.  Blocking errors are handled
-	       specially inside of the filedesc stream. */
-	    report_file_error ("writing to process", list1 (proc));
+	  {
+	    int save_errno = errno;
+	    EMACS_SIGNAL (SIGPIPE, old_sigpipe);
+	    errno = save_errno;
+	    if (writeret < 0)
+	      /* This is a real error.  Blocking errors are handled
+		 specially inside of the filedesc stream. */
+	      report_process_error ("writing to process", proc);
+	  }
 	  while (Lstream_was_blocked_p (XLSTREAM (p->pipe_outstream)))
 	    {
 	      /* Buffer is full.  Wait, accepting input;
@@ -1322,15 +1312,15 @@ unix_send_process (Lisp_Object proc, struct lstream* lstream)
 	      if (NILP(p->pipe_outstream))
 		return;
 	      old_sigpipe =
-		(SIGTYPE (*) (int)) signal (SIGPIPE, send_process_trap);
+		(SIGTYPE (*) (int)) EMACS_SIGNAL (SIGPIPE, send_process_trap);
 	      Lstream_flush (XLSTREAM (p->pipe_outstream));
-	      signal (SIGPIPE, old_sigpipe);
+	      EMACS_SIGNAL (SIGPIPE, old_sigpipe);
 	    }
 	}
     }
   else
     { /* We got here from a longjmp() from the SIGPIPE handler */
-      signal (SIGPIPE, old_sigpipe);
+      EMACS_SIGNAL (SIGPIPE, old_sigpipe);
       /* Close the file lstream so we don't attempt to write to it further */
       /* #### There is controversy over whether this might cause fd leakage */
       /*      my tests say no. -slb */
@@ -1344,9 +1334,9 @@ unix_send_process (Lisp_Object proc, struct lstream* lstream)
       invalid_operation ("SIGPIPE raised on process; closed it", p->name);
     }
 
-  old_sigpipe = (SIGTYPE (*) (int)) signal (SIGPIPE, send_process_trap);
+  old_sigpipe = (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGPIPE, send_process_trap);
   Lstream_flush (XLSTREAM (DATA_OUTSTREAM(p)));
-  signal (SIGPIPE, old_sigpipe);
+  EMACS_SIGNAL (SIGPIPE, old_sigpipe);
 }
 
 /*
@@ -1399,9 +1389,9 @@ unix_deactivate_process (Lisp_Process *p)
     flush_pending_output (UNIX_DATA(p)->infd);
 
   /* closing the outstream could result in SIGPIPE, so ignore it. */
-  old_sigpipe = (SIGTYPE (*) (int)) signal (SIGPIPE, SIG_IGN);
+  old_sigpipe = (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGPIPE, SIG_IGN);
   usid = event_stream_delete_stream_pair (p->pipe_instream, p->pipe_outstream);
-  signal (SIGPIPE, old_sigpipe);
+  EMACS_SIGNAL (SIGPIPE, old_sigpipe);
 
   UNIX_DATA(p)->infd  = -1;
 
@@ -1555,8 +1545,9 @@ unix_kill_child_process (Lisp_Object proc, int signo,
 #ifdef ESRCH
       if (errno != ESRCH)
 #endif
-	error ("kill (%ld, %ld) failed: %s",
-	       (long) pgid, (long) signo, strerror (errno));
+	signal_ferror_with_frob (Qio_error, lisp_strerror (errno),
+				 "kill (pgid=%ld, signo=%ld) failed",
+				 (long) pgid, (long) signo);
     }
 }
 
@@ -1600,11 +1591,11 @@ unix_canonicalize_host_name (Lisp_Object host)
   retval = getaddrinfo (ext_host, NULL, &hints, &res);
   if (retval != 0)
     {
-      char *gai_error;
+      CBufbyte *gai_error;
 
       EXTERNAL_TO_C_STRING (gai_strerror (retval), gai_error, Qnative);
-      maybe_error (Qprocess, ERROR_ME_NOT,
-		   "%s \"%s\"", gai_error, XSTRING_DATA (host));
+      maybe_signal_error (Qio_error, gai_error, host,
+			  Qprocess, ERROR_ME_NOT);
       canonname = host;
     }
   else
@@ -1655,7 +1646,7 @@ unix_open_network_stream (Lisp_Object name, Lisp_Object host,
   CHECK_STRING (host);
 
   if (!EQ (protocol, Qtcp) && !EQ (protocol, Qudp))
-    invalid_argument ("Unsupported protocol", protocol);
+    invalid_constant ("Unsupported protocol", protocol);
 
   {
 #ifdef USE_GETADDRINFO
@@ -1694,10 +1685,10 @@ unix_open_network_stream (Lisp_Object name, Lisp_Object host,
     retval = getaddrinfo (ext_host, portstring, &hints, &res);
     if (retval != 0)
       {
-	char *gai_error;
+	CBufbyte *gai_error;
 
 	EXTERNAL_TO_C_STRING (gai_strerror (retval), gai_error, Qnative);
-	error ("%s/%s %s", XSTRING_DATA (host), portstring, gai_error);
+	signal_error (Qio_error, gai_error, list2 (host, service));
       }
 
     /* address loop */
@@ -1862,9 +1853,10 @@ unix_open_network_stream (Lisp_Object name, Lisp_Object host,
 	errno = xerrno;
 
 	if (failed_connect)
-	  report_file_error ("connection failed", list2 (host, name));
+	  report_network_error ("connection failed", list3 (Qunbound, host,
+							    name));
 	else
-	  report_file_error ("error creating socket", list1 (name));
+	  report_network_error ("error creating socket", name);
       }
   }
 
@@ -1872,8 +1864,10 @@ unix_open_network_stream (Lisp_Object name, Lisp_Object host,
   outch = dup (s);
   if (outch < 0)
     {
+      int save_errno = errno;
       close (s); /* this used to be leaked; from Kyle Jones */
-      report_file_error ("error duplicating socket", list1 (name));
+      errno = save_errno;
+      report_network_error ("error duplicating socket", name);
     }
 
   set_socket_nonblocking_maybe (inch, port, "tcp");
@@ -1927,15 +1921,17 @@ unix_open_multicast_group (Lisp_Object name, Lisp_Object dest,
   thettl = (unsigned char) XINT (ttl);
 
   if ((udp = getprotobyname ("udp")) == NULL)
-    type_error (Qinvalid_operation, "No info available for UDP protocol");
+    invalid_operation ("No info available for UDP protocol", Qunbound);
 
   /* Init the sockets. Yes, I need 2 sockets. I couldn't duplicate one. */
   if ((rs = socket (PF_INET, SOCK_DGRAM, udp->p_proto)) < 0)
-    report_file_error ("error creating socket", list1(name));
+    report_network_error ("error creating socket", name);
   if ((ws = socket (PF_INET, SOCK_DGRAM, udp->p_proto)) < 0)
     {
+      int save_errno = errno;
       close (rs);
-      report_file_error ("error creating socket", list1(name));
+      errno = save_errno;
+      report_network_error ("error creating socket", name);
     }
 
   /* This will be used for both sockets */
@@ -1956,9 +1952,12 @@ unix_open_multicast_group (Lisp_Object name, Lisp_Object dest,
   /* bind socket name */
   if (bind (rs, (struct sockaddr *)&sa, sizeof(sa)))
     {
+      int save_errno = errno;
       close (rs);
       close (ws);
-      report_file_error ("error binding socket", list2(name, port));
+      errno = save_errno;
+      report_network_error ("error binding socket", list3 (Qunbound, name,
+							   port));
     }
 
   /* join multicast group */
@@ -1967,9 +1966,12 @@ unix_open_multicast_group (Lisp_Object name, Lisp_Object dest,
   if (setsockopt (rs, IPPROTO_IP, IP_ADD_MEMBERSHIP,
 		  &imr, sizeof (struct ip_mreq)) < 0)
     {
+      int save_errno = errno;
       close (ws);
       close (rs);
-      report_file_error ("error adding membership", list2(name, dest));
+      errno = save_errno;
+      report_network_error ("error adding membership", list3 (Qunbound, name,
+							      dest));
     }
 
   /* Socket configuration for writing ----------------------- */
@@ -2032,7 +2034,8 @@ unix_open_multicast_group (Lisp_Object name, Lisp_Object dest,
 #endif
 
       errno = xerrno;
-      report_file_error ("error connecting socket", list2(name, port));
+      report_network_error ("error connecting socket", list3 (Qunbound, name,
+							      port));
     }
 
 #ifdef CONNECT_NEEDS_SLOWED_INTERRUPTS
@@ -2043,9 +2046,11 @@ unix_open_multicast_group (Lisp_Object name, Lisp_Object dest,
   if (setsockopt (ws, IPPROTO_IP, IP_MULTICAST_TTL,
 		  &thettl, sizeof (thettl)) < 0)
     {
+      int save_errno = errno;
       close (rs);
       close (ws);
-      report_file_error ("error setting ttl", list2(name, ttl));
+      errno = save_errno;
+      report_network_error ("error setting ttl", list3 (Qunbound, name, ttl));
     }
 
   set_socket_nonblocking_maybe (rs, theport, "udp");
