@@ -22,23 +22,11 @@ Boston, MA 02111-1307, USA.  */
 
 /* Synched up with: Not in FSF. */
 
+#define DONT_ENCAPSULATE
 #include <config.h>
 #include "lisp.h"
-#include <errno.h>
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#if defined (HAVE_SYS_PARAM_H) && !defined (WIN32_NATIVE)
-#include <sys/param.h>
-#endif
-
-#ifdef WIN32_NATIVE
-#include <direct.h>
-#endif
-
-#include <sys/stat.h>			/* for S_IFLNK */
+#include "sysfile.h"
 
 /* First char after start of absolute filename. */
 #define ABS_START(name) (name + ABS_LENGTH (name))
@@ -81,7 +69,7 @@ win32_readlink (const char * name, char * buf, int size)
   assert (*name);
   
   /* Sort of check we have a valid filename. */
-  if (strpbrk (name, "*?|<>\"") || strlen (name) >= MAX_PATH)
+  if (strpbrk (name, "*?|<>\"") || strlen (name) >= PATH_MAX)
     {
       errno = EIO;
       return -1;
@@ -137,11 +125,12 @@ static int
 cygwin_readlink (const char * name, char * buf, int size)
 {
   int n = readlink (name, buf, size);
-  if (n < 0)
+  if (n < 0 && errno == EINVAL)
     {
       /* The file may exist, but isn't a symlink. Try to find the
          right name. */
-      char* tmp = alloca (cygwin_posix_to_win32_path_list_buf_size (name));
+      /* !!#### mule-bogosity */
+      char* tmp = (char *) alloca (cygwin_posix_to_win32_path_list_buf_size (name));
       cygwin_posix_to_win32_path_list (name, tmp);
       n = win32_readlink (tmp, buf, size);
     }
@@ -208,6 +197,9 @@ xrealpath (const char *path, char resolved_path [])
   if (abslen == 2 || abslen == 3)
     {
       strncpy (new_path, path, abslen);
+      /* Make sure drive letter is lowercased. */
+      if (abslen == 3)
+	*new_path = tolower (*new_path);
       new_path += abslen;
       path += abslen;
     }
@@ -299,7 +291,11 @@ xrealpath (const char *path, char resolved_path [])
       if (n < 0)
 	{
 	  /* EINVAL means the file exists but isn't a symlink. */
-	  if (errno != EINVAL)
+#ifdef CYGWIN
+	  if (errno != EINVAL && errno != ENOENT)
+#else
+	  if (errno != EINVAL) 
+#endif
 	    return NULL;
 	}
       else
@@ -345,10 +341,5 @@ xrealpath (const char *path, char resolved_path [])
   /* Make sure it's null terminated. */
   *new_path = '\0';
 
-#ifdef WIN32_NATIVE
-  if (ABS_LENGTH (resolved_path) == 3)
-    /* Lowercase drive letter. */
-    *resolved_path = tolower (*resolved_path);
-#endif
   return resolved_path;
 }
