@@ -195,7 +195,8 @@ mswindows_text_width_single_run (HDC hdc, struct face_cachel *cachel,
       assert(run->dimension == 1);	/* #### FIXME! */
       mswindows_set_dc_font (hdc, font_inst,
 			     cachel->underline, cachel->strikethru);
-      GetTextExtentPoint32 (hdc, run->ptr, run->len, &size);
+      /* !!#### more mule bogosity */
+      GetTextExtentPoint32 (hdc, (char *) run->ptr, run->len, &size);
       return(size.cx);
     }
 }
@@ -309,7 +310,6 @@ mswindows_output_blank (struct window *w, struct display_line *dl,
       struct display_glyph_area dga;
       redisplay_calculate_display_boxes (dl, rb->xpos, 
 					 /*rb->object.dglyph.xoffset*/ 0,
-                                         /*rb->object.dglyph.yoffset*/ 0,
 					 start_pixpos, rb->width,
 					 &db, &dga);
       /* blank the background in the appropriate color */
@@ -513,7 +513,7 @@ mswindows_output_string (struct window *w, struct display_line *dl,
     {
       struct display_box db;
       struct display_glyph_area dga;
-      redisplay_calculate_display_boxes (dl, xpos + xoffset, 0, 0,
+      redisplay_calculate_display_boxes (dl, xpos + xoffset, 0,
 					 clip_start, width, &db, &dga);
       /* blank the background in the appropriate color */
       mswindows_update_dc (hdc,
@@ -1044,7 +1044,7 @@ mswindows_output_display_block (struct window *w, struct display_line *dl, int b
 			  int cursor_width, int cursor_height)
 {
   struct frame *f = XFRAME (w->frame);
-  Emchar_dynarr *buf;
+  Emchar_dynarr *buf = Dynarr_new (Emchar);
   Lisp_Object window;
 
   struct display_block *db = Dynarr_atp (dl->display_blocks, block);
@@ -1071,7 +1071,7 @@ mswindows_output_display_block (struct window *w, struct display_line *dl, int b
 
   if (end < 0)
     end = Dynarr_length (rba);
-  buf = Dynarr_new (Emchar);
+  Dynarr_reset (buf);
 
   while (elt < end)
     {
@@ -1166,8 +1166,8 @@ mswindows_output_display_block (struct window *w, struct display_line *dl, int b
 	      struct display_glyph_area dga;
 
 	      redisplay_calculate_display_boxes (dl, rb->xpos, rb->object.dglyph.xoffset,
-						 rb->object.dglyph.yoffset,
-                                                 start_pixpos, rb->width, &dbox, &dga);
+						 start_pixpos, rb->width,
+						 &dbox, &dga);
 
 	      XSETWINDOW (window, w);
 	      instance = glyph_image_instance (rb->object.dglyph.glyph,
@@ -1216,7 +1216,7 @@ mswindows_output_display_block (struct window *w, struct display_line *dl, int b
 		    case IMAGE_TEXT:
 		    case IMAGE_POINTER:
 		    default:
-		      ABORT ();
+		      abort ();
 		    }
 		  IMAGE_INSTANCE_OPTIMIZE_OUTPUT 
 		    (XIMAGE_INSTANCE (instance)) = 0;
@@ -1225,7 +1225,7 @@ mswindows_output_display_block (struct window *w, struct display_line *dl, int b
 	      elt++;
 	    }
 	  else
-	    ABORT ();
+	    abort ();
 	}
     }
 
