@@ -5,10 +5,6 @@
 
 #include "usg5-3.h"
 
-/* Some versions of V.3 have this, but not all. ESIX does. */
-#define HAVE_PTYS
-#define SYSV_PTYS
-
 /* Have -lg be used for debugging. */
 #undef LIBS_DEBUG
 #define LIBS_DEBUG "-lg"
@@ -16,8 +12,6 @@
 /* If using Roell's X server, define X11R4 */
 #ifdef X11R4			/* Roell's X server */
 #define select sys_select /* Emacs select() not good enough? */
-#undef LIBX11_SYSTEM
-#define LIBX11_SYSTEM "-lpt"
 #endif /* X11R4 */
 
 /* ESIX does not need <sys/sioctl.h>, but needs <sys/ptem.h> */
