@@ -1,14 +1,14 @@
-/* Definitions file for GNU Emacs running on Sony's NEWS-OS 5.0.2
+/* Definitions file for XEmacs running on Sony's NEWS-OS 5.0.2
    Copyright (C) 1992, 1994 Free Software Foundation, Inc.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
@@ -31,7 +31,7 @@ Boston, MA 02111-1307, USA.  */
 #undef LIB_STANDARD
 
 #undef LIBS_SYSTEM
-#define LIBS_SYSTEM -lsocket -lnsl -lgen
+#define LIBS_SYSTEM "-lsocket -lnsl -lgen"
 
 /* Disable use of "unexelf.c" and shared libraries, because
    "unexelf.c" doesn't work correctly on NEWS-OS.  "unexmips.c" does
@@ -42,6 +42,6 @@ Boston, MA 02111-1307, USA.  */
 /* Use `ld' directly rather than ordinary link, because ordinary link
    can't produce a non-ELF executable.  */
 #undef ORDINARY_LINK
-#define LINKER /usr/lib/cmplrs/cc/ld
-#define START_FILES pre-crt0.o /usr/ccs/lib/crt1.o
-#define LIB_STANDARD -lc /usr/ccs/lib/crtn.o /usr/ccs/lib/values-Xt.o
+#define LINKER "/usr/lib/cmplrs/cc/ld"
+#define START_FILES "pre-crt0.o /usr/ccs/lib/crt1.o"
+#define LIB_STANDARD "-lc /usr/ccs/lib/crtn.o /usr/ccs/lib/values-Xt.o"
