@@ -1,14 +1,14 @@
-/* Definitions file for GNU Emacs running on Sequent DYNIX/ptx 1.x/2.x
+/* Definitions file for XEmacs running on Sequent DYNIX/ptx 1.x/2.x
    Copyright (C) 1987, 1990 Free Software Foundation, Inc.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
@@ -68,7 +68,6 @@ Boston, MA 02111-1307, USA.  */
 #endif
 
 #ifdef emacs
-#include <sys/stropts.h>	/* Support for pty's */
 #include <sys/conf.h>
 
 /*#define BROKEN_SIGIO*/	/* SIGIO is already undef'd elsewhere. PTX
@@ -105,10 +104,6 @@ struct timezone
 #undef BROKEN_TIOCGWINSZ
 #undef BROKEN_TIOCGETC
 
-/* PTX has pty's but not like System V */
-#define HAVE_PTYS
-#undef SYSV_PTYS
-
 /* Provide pty support which is defined into process.c:allocate_pty.
    Basic ideas for handling getpseudotty were lifted from process.c in
    Emacs 18.57 included on the Sequent Public Software tape.  However, this
