@@ -1,14 +1,14 @@
 /* System description file for SCO OpenServer Release 5
    Copyright (C) 1993, 1994 Free Software Foundation, Inc.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
@@ -37,7 +37,6 @@ Boston, MA 02111-1307, USA.  */
 #define SYSTEM_TYPE "SCO 3.2v5"
 
 /* SCO has ptys, but with weird names */
-#define HAVE_PTYS
 #define PTY_ITERATION \
    for (i = 0; ; i++)
 #define PTY_NAME_SPRINTF \
