@@ -1,14 +1,14 @@
-/* Definitions file for GNU Emacs running on UMAX 4.2
+/* Definitions file for XEmacs running on UMAX 4.2
    Copyright (C) 1985, 1986 Free Software Foundation, Inc.
 
-This file is part of GNU Emacs.
+This file is part of XEmacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+XEmacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU Emacs is distributed in the hope that it will be useful,
+XEmacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
@@ -34,7 +34,6 @@ Boston, MA 02111-1307, USA.  */
 #define BSD
 #define UMAX4_2
 #define UMAX
-/* #define VMS */
 
 /* SYSTEM_TYPE should indicate the kind of system you are using.
  It sets the Lisp variable system-type.  */
@@ -46,12 +45,6 @@ Boston, MA 02111-1307, USA.  */
 
 #define FIRST_PTY_LETTER 'p'
 
-/*
- *	Define HAVE_PTYS if the system supports pty devices.
- */
-
-#define HAVE_PTYS
-
 /* If your system uses COFF (Common Object File Format) then define the
    preprocessor symbol "COFF". */
 
