@@ -78,6 +78,22 @@ static void update_scrollbar_instance (struct window *w, int vertical,
 				       struct scrollbar_instance *instance);
 
 
+static Lisp_Object
+mark_scrollbar_instance (Lisp_Object obj)
+{
+  struct scrollbar_instance *data = XSCROLLBAR_INSTANCE (obj);
+  mark_object (wrap_window_mirror (data->mirror));
+  if (data->next)
+    return wrap_scrollbar_instance (data->next);
+  else
+    return Qnil;
+}
+
+DEFINE_LRECORD_IMPLEMENTATION ("scrollbar-instance", scrollbar_instance,
+			       mark_scrollbar_instance,
+			       internal_object_printer, 0, 0, 0, 0,
+			       struct scrollbar_instance);
+
 static void
 free_scrollbar_instance (struct scrollbar_instance *instance,
 			 struct frame *frame)
@@ -89,7 +105,8 @@ free_scrollbar_instance (struct scrollbar_instance *instance,
       struct device *d = XDEVICE (frame->device);
 
       MAYBE_DEVMETH (d, free_scrollbar_instance, (instance));
-      xfree (instance);
+      /* not worth calling free_managed_lcrecord() -- scrollbar instances
+	 are not created that frequently and it's dangerous. */
     }
 }
 
@@ -148,7 +165,7 @@ free_frame_scrollbars (struct frame *f)
   if (f->mirror_dirty)
     update_frame_window_mirror (f);
 
-  free_scrollbars_loop (f->root_window, f->root_mirror);
+  free_scrollbars_loop (f->root_window, XWINDOW_MIRROR (f->root_mirror));
 
   while (FRAME_SB_VCACHE (f))
     {
@@ -173,8 +190,10 @@ create_scrollbar_instance (struct frame *f, int vertical)
 {
   struct device *d = XDEVICE (f->device);
   struct scrollbar_instance *instance =
-    xnew_and_zero (struct scrollbar_instance);
+    alloc_lcrecord_type (struct scrollbar_instance,
+			 &lrecord_scrollbar_instance);
 
+  zero_lcrecord (instance);
   MAYBE_DEVMETH (d, create_scrollbar_instance, (f, vertical, instance));
 
   return instance;
@@ -240,8 +259,7 @@ compute_scrollbar_instance_usage (struct device *d,
 {
   int total = 0;
 
-  if (HAS_DEVMETH_P(d, compute_scrollbar_instance_usage))
-    total += DEVMETH (d, compute_scrollbar_instance_usage, (d, inst, ovstats));
+  total += DEVMETH (d, compute_scrollbar_instance_usage, (d, inst, ovstats));
 
   while (inst)
     {
@@ -895,23 +913,25 @@ This ensures that VALUE is in the proper range for the horizontal scrollbar.
 void
 syms_of_scrollbar (void)
 {
-  defsymbol (&Qscrollbar_line_up, "scrollbar-line-up");
-  defsymbol (&Qscrollbar_line_down, "scrollbar-line-down");
-  defsymbol (&Qscrollbar_page_up, "scrollbar-page-up");
-  defsymbol (&Qscrollbar_page_down, "scrollbar-page-down");
-  defsymbol (&Qscrollbar_to_top, "scrollbar-to-top");
-  defsymbol (&Qscrollbar_to_bottom, "scrollbar-to-bottom");
-  defsymbol (&Qscrollbar_vertical_drag, "scrollbar-vertical-drag");
+  INIT_LRECORD_IMPLEMENTATION (scrollbar_instance);
 
-  defsymbol (&Qscrollbar_char_left, "scrollbar-char-left");
-  defsymbol (&Qscrollbar_char_right, "scrollbar-char-right");
-  defsymbol (&Qscrollbar_page_left, "scrollbar-page-left");
-  defsymbol (&Qscrollbar_page_right, "scrollbar-page-right");
-  defsymbol (&Qscrollbar_to_left, "scrollbar-to-left");
-  defsymbol (&Qscrollbar_to_right, "scrollbar-to-right");
-  defsymbol (&Qscrollbar_horizontal_drag, "scrollbar-horizontal-drag");
+  DEFSYMBOL (Qscrollbar_line_up);
+  DEFSYMBOL (Qscrollbar_line_down);
+  DEFSYMBOL (Qscrollbar_page_up);
+  DEFSYMBOL (Qscrollbar_page_down);
+  DEFSYMBOL (Qscrollbar_to_top);
+  DEFSYMBOL (Qscrollbar_to_bottom);
+  DEFSYMBOL (Qscrollbar_vertical_drag);
 
-  defsymbol (&Qinit_scrollbar_from_resources, "init-scrollbar-from-resources");
+  DEFSYMBOL (Qscrollbar_char_left);
+  DEFSYMBOL (Qscrollbar_char_right);
+  DEFSYMBOL (Qscrollbar_page_left);
+  DEFSYMBOL (Qscrollbar_page_right);
+  DEFSYMBOL (Qscrollbar_to_left);
+  DEFSYMBOL (Qscrollbar_to_right);
+  DEFSYMBOL (Qscrollbar_horizontal_drag);
+
+  DEFSYMBOL (Qinit_scrollbar_from_resources);
 
   /* #### All these functions should be moved into Lisp.
      See comment above. */
