@@ -81,16 +81,17 @@ void* more_static_core ( ptrdiff_t increment )
       if (static_heap_ptr + size >= static_heap_base + static_heap_size)
 	{
 	  printf(
-"\nRequested %d bytes, static heap exhausted!  base is %p, current ptr\n"
-"is %p. You have exhausted the static heap. \n"
-"\n"
-"If you are simply trying to compile, remove sheap-adjust.h\n"
-"and recompile from the top level. If this doesn't\n"
-"work then STATIC_HEAP_SLOP (defined in this file) is too small.\n"
-"\n"
-"If you want to run temacs, change SHEAP_ADJUSTMENT in sheap-adjust.h\n"
-"to 0 or a +ve number. Generally you should *not* try to run temacs\n"
-"with a static heap, you should dump first.\n", size,
+
+"\nRequested %d bytes, static heap exhausted!  base is %p, current ptr
+is %p. You have exhausted the static heap. 
+
+If you are simply trying to compile, remove sheap-adjust.h
+and recompile from the top level. If this doesn't
+work then STATIC_HEAP_SLOP (defined in this file) is too small.
+
+If you want to run temacs, change SHEAP_ADJUSTMENT in sheap-adjust.h
+to 0 or a +ve number. Generally you should *not* try to run temacs
+with a static heap, you should dump first.\n", size,
 static_heap_base, static_heap_ptr);
 
 	  exit(-1);
@@ -109,7 +110,7 @@ sheap_adjust_h ()
 
   if (stream == NULL)
     report_file_error ("Opening sheap adjustment file",
-		       Fcons (build_string ("sheap-adjust.h"), Qnil));
+		       build_string ("sheap-adjust.h"));
 
   fprintf (stream,
 	   "/*\tDo not edit this file!\n"
