@@ -15,41 +15,21 @@
 
 /* Synched up with: Not in FSF. */
 
-#ifdef HAVE_CONFIG_H
+/* This file Mule-ized by Ben Wing, 5-15-01. */
+
+#define DONT_ENCAPSULATE
+
 #include <config.h>
-#endif
+#include "lisp.h"
+#include "sound.h"
 
-#if __STDC__ || defined(STDC_HEADERS)
-#include <stdlib.h>
-#include <unistd.h>
-#include <fcntl.h>	/* for open() */
-#endif
-
-#include <stdio.h>
-#include <string.h>
-#ifndef emacs
-#include <sys/signal.h>
-#endif
-#include <sys/fcntl.h>
-#include <sys/file.h>
+#include "sysdep.h"
+#include "sysfile.h"
+#include "syssignal.h"
 
 #include <multimedia/libaudio.h>
 #include <multimedia/audio_device.h>
 
-#ifdef emacs
-# include <config.h>
-# include "lisp.h"
-# include "sysdep.h"
-# include <errno.h>
-# include "nativesound.h"
-#include "syssignal.h"
-# define perror(string) \
-    message("audio: %s, %s ", string, strerror (errno))
-# define warn(str) message ("audio: %s ", GETTEXT (str))
-#else /* !emacs */
-# define warn(str) fprintf (stderr, "%s\n", (str))
-#endif /* emacs */
-
 static SIGTYPE (*sighup_handler) (int sig);
 static SIGTYPE (*sigint_handler) (int sig);
 static SIGTYPE sighandler (int sig);
@@ -64,7 +44,7 @@ static double old_volume;
 static Audio_hdr dev_hdr;
 
 static int
-init_device (int volume, unsigned char *data, int fd,
+init_device (int volume, UChar_Binary *data, int fd,
 	     unsigned int *header_length)
 {
 #ifdef SUNOS4_0_3
@@ -76,11 +56,11 @@ init_device (int volume, unsigned char *data, int fd,
   reset_volume_p = 0;
   reset_device_p = 0;
 
-  if (data && fd) ABORT (); /* one or the other */
+  if (data && fd) abort (); /* one or the other */
 
   if (AUDIO_SUCCESS != audio_get_play_config (audio_fd, &dev_hdr))
     {
-      perror ("Not a valid audio device");
+      sound_perror ("Not a valid audio device");
       return 1;
     }
 
@@ -89,9 +69,9 @@ init_device (int volume, unsigned char *data, int fd,
 			: audio_read_filehdr (fd, &file_hdr, 0, 0)))
     {
       if (data)
-	perror ("invalid audio data");
+	sound_perror ("invalid audio data");
       else
-	perror ("invalid audio file");
+	sound_perror ("invalid audio file");
       return 1;
     }
 
@@ -105,20 +85,20 @@ init_device (int volume, unsigned char *data, int fd,
       initialized_device_p = 1;
       if (AUDIO_SUCCESS != audio_set_play_config (audio_fd, &new_hdr))
 	{
-	  char buf1 [100], buf2 [100], buf3 [250];
+	  Extbyte buf1 [100], buf2 [100], buf3 [250];
 	  audio_enc_to_str (&file_hdr, buf1);
 	  audio_enc_to_str (&new_hdr, buf2);
 	  sprintf (buf3, "wanted %s, got %s", buf1, buf2);
-	  warn (buf3);
+	  sound_warn (buf3);
 	  return 1;
 	}
     }
 
   if (volume < 0 || volume > 100)
     {
-      char buf [255];
+      Extbyte buf [255];
       sprintf (buf, "volume must be between 0 and 100 (not %d)", volume);
-      warn (buf);
+      sound_warn (buf);
       return 1;
     }
   {
@@ -149,40 +129,40 @@ reset_device (int wait_p)
 
 
 void
-play_sound_file (char *sound_file, int volume)
+play_sound_file (Extbyte *sound_file, int volume)
 {
   int rrtn, wrtn;
-  unsigned char buf [255];
+  UChar_Binary buf [255];
   int file_fd;
 
   audio_fd = audio_open ();
 
   if (audio_fd < 0)
     {
-      perror ("open /dev/audio");
+      sound_perror ("open /dev/audio");
       return;
     }
 
   /* where to find the proto for signal()... */
-  sighup_handler = (SIGTYPE (*) (int)) signal (SIGHUP, sighandler);
-  sigint_handler = (SIGTYPE (*) (int)) signal (SIGINT, sighandler);
+  sighup_handler = (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGHUP, sighandler);
+  sigint_handler = (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGINT, sighandler);
 
   file_fd = open (sound_file, O_RDONLY, 0);
   if (file_fd < 0)
     {
-      perror (sound_file);
+      sound_perror (sound_file);
       goto END_OF_PLAY;
     }
 
-  if (init_device (volume, (unsigned char *) 0, file_fd, (unsigned int *) 0))
+  if (init_device (volume, (UChar_Binary *) 0, file_fd, (unsigned int *) 0))
     goto END_OF_PLAY;
 
   while (1)
     {
-      rrtn = read (file_fd, (char *) buf, sizeof (buf));
+      rrtn = read (file_fd, (Char_Binary *) buf, sizeof (buf));
       if (rrtn < 0)
 	{
-	  perror ("read");
+	  sound_perror ("read");
 	  goto END_OF_PLAY;
 	}
       if (rrtn == 0)
@@ -190,10 +170,10 @@ play_sound_file (char *sound_file, int volume)
 
       while (1)
 	{
-	  wrtn = write (audio_fd, (char *) buf, rrtn);
+	  wrtn = write (audio_fd, (Char_Binary *) buf, rrtn);
 	  if (wrtn < 0)
 	    {
-	      perror ("write");
+	      sound_perror ("write");
 	      goto END_OF_PLAY;
 	    }
 	  if (wrtn != 0)
@@ -204,9 +184,9 @@ play_sound_file (char *sound_file, int volume)
 	}
       if (wrtn != rrtn)
 	{
-	  char warn_buf [255];
+	  Extbyte warn_buf [255];
 	  sprintf (warn_buf, "play: rrtn = %d, wrtn = %d", rrtn, wrtn);
-	  warn (warn_buf);
+	  sound_warn (warn_buf);
 	  goto END_OF_PLAY;
 	}
     }
@@ -222,13 +202,13 @@ play_sound_file (char *sound_file, int volume)
       close (audio_fd);
     }
 
-  signal (SIGHUP, sighup_handler);
-  signal (SIGINT, sigint_handler);
+  EMACS_SIGNAL (SIGHUP, sighup_handler);
+  EMACS_SIGNAL (SIGINT, sigint_handler);
 }
 
 
 int
-play_sound_data (unsigned char *data, int length, int volume)
+play_sound_data (UChar_Binary *data, int length, int volume)
 {
   int wrtn, start = 0;
   unsigned int ilen;
@@ -239,14 +219,14 @@ play_sound_data (unsigned char *data, int length, int volume)
   if (length == 0) return 0;
 
   /* this is just to get a better error message */
-  if (strncmp (".snd\0", (char *) data, 4))
+  if (strncmp (".snd\0", (Char_Binary *) data, 4))
     {
-      warn ("Not valid audio data (bad magic number)");
+      sound_warn ("Not valid audio data (bad magic number)");
       goto END_OF_PLAY;
     }
   if (length <= sizeof (Audio_hdr))
     {
-      warn ("Not valid audio data (too short)");
+      sound_warn ("Not valid audio data (too short)");
       goto END_OF_PLAY;
     }
 
@@ -255,8 +235,8 @@ play_sound_data (unsigned char *data, int length, int volume)
       return 0;
 
   /* where to find the proto for signal()... */
-  sighup_handler = (SIGTYPE (*) (int)) signal (SIGHUP, sighandler);
-  sigint_handler = (SIGTYPE (*) (int)) signal (SIGINT, sighandler);
+  sighup_handler = (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGHUP, sighandler);
+  sigint_handler = (SIGTYPE (*) (int)) EMACS_SIGNAL (SIGINT, sighandler);
 
   if (init_device (volume, data, 0, &ilen))
     goto END_OF_PLAY;
@@ -268,10 +248,10 @@ play_sound_data (unsigned char *data, int length, int volume)
 
   while (1)
     {
-      wrtn = write (audio_fd, (char *) (data+start), length-start);
+      wrtn = write (audio_fd, (Char_Binary *) (data+start), length-start);
       if (wrtn < 0)
 	{
-	  perror ("write");
+	  sound_perror ("write");
 	  goto END_OF_PLAY;
 	}
       if (wrtn != 0)
@@ -284,9 +264,9 @@ play_sound_data (unsigned char *data, int length, int volume)
     }
   if (wrtn != length)
     {
-      char buf [255];
+      Extbyte buf [255];
       sprintf (buf, "play: rrtn = %d, wrtn = %d", length, wrtn);
-      warn (buf);
+      sound_warn (buf);
       goto END_OF_PLAY;
     }
 
@@ -300,8 +280,8 @@ play_sound_data (unsigned char *data, int length, int volume)
       close (audio_fd);
     }
 
-  signal (SIGHUP, sighup_handler);
-  signal (SIGINT, sigint_handler);
+  EMACS_SIGNAL (SIGHUP, sighup_handler);
+  EMACS_SIGNAL (SIGINT, sigint_handler);
 
   return result;
 }
