@@ -96,6 +96,7 @@ void syms_of_free_hook (void);
 void syms_of_general (void);
 void syms_of_glyphs_x (void);
 void syms_of_glyphs_eimage (void);
+void syms_of_glyphs_shared (void);
 void syms_of_glyphs_widget (void);
 void syms_of_glyphs_mswindows (void);
 void syms_of_glyphs (void);
@@ -410,6 +411,7 @@ void complex_vars_of_glyphs_mswindows (void);
 void complex_vars_of_alloc (void);
 void complex_vars_of_menubar (void);
 void complex_vars_of_scrollbar (void);
+void complex_vars_of_scrollbar_mswindows (void);
 void complex_vars_of_frame (void);
 void complex_vars_of_casetab (void);
 void complex_vars_of_syntax (void);
@@ -454,4 +456,39 @@ void init_redisplay (void);
 void init_sunpro (void);
 void init_win32 (void);
 
+void syms_of_device_gtk (void);
+void syms_of_dialog_gtk (void);
+void syms_of_event_gtk (void);
+void syms_of_frame_gtk (void);
+void syms_of_glyphs_gtk (void);
+void syms_of_gui_gtk (void);
+void syms_of_menubar_gtk (void);
+void syms_of_objects_gtk (void);
+void syms_of_select_gtk (void);
+void syms_of_ui_gtk (void);
+void console_type_create_gtk (void);
+void console_type_create_device_gtk (void);
+void console_type_create_frame_gtk (void);
+void console_type_create_glyphs_gtk (void);
+void console_type_create_menubar_gtk (void);
+void console_type_create_objects_gtk (void);
+void console_type_create_redisplay_gtk (void);
+void console_type_create_scrollbar_gtk (void);
+void console_type_create_toolbar_gtk (void);
+void console_type_create_dialog_gtk (void);
+void image_instantiator_format_create_glyphs_gtk (void);
+void vars_of_device_gtk (void);
+void vars_of_dialog_gtk (void);
+void vars_of_event_gtk (void);
+void vars_of_frame_gtk (void);
+void vars_of_glyphs_gtk (void);
+void vars_of_gui_gtk (void);
+void vars_of_menubar_gtk (void);
+void vars_of_objects_gtk (void);
+void vars_of_scrollbar_gtk (void);
+void vars_of_select_gtk (void);
+void vars_of_ui_gtk (void);
+void complex_vars_of_glyphs_gtk (void);
+void init_event_gtk_late (void);
+
 #endif /* INCLUDED_symsinit_h_ */
