@@ -22,8 +22,8 @@ Boston, MA 02111-1307, USA.  */
 
 /* Synched up with: Not in FSF. */
 
-#ifndef _XEMACS_TOOLBAR_H_
-#define _XEMACS_TOOLBAR_H_
+#ifndef INCLUDED_toolbar_h_
+#define INCLUDED_toolbar_h_
 
 #ifdef HAVE_TOOLBARS
 
@@ -72,6 +72,7 @@ struct toolbar_button
 DECLARE_LRECORD (toolbar_button, struct toolbar_button);
 #define XTOOLBAR_BUTTON(x) XRECORD (x, toolbar_button, struct toolbar_button)
 #define XSETTOOLBAR_BUTTON(x, p) XSETRECORD (x, p, toolbar_button)
+#define wrap_toolbar_button(p) wrap_record (p, toolbar_button)
 #define TOOLBAR_BUTTONP(x) RECORDP (x, toolbar_button)
 #define CHECK_TOOLBAR_BUTTON(x) CHECK_RECORD (x, toolbar_button)
 #define CONCHECK_TOOLBAR_BUTTON(x) CONCHECK_RECORD (x, toolbar_button)
@@ -110,4 +111,4 @@ void mark_frame_toolbar_buttons_dirty (struct frame *f, enum toolbar_pos pos);
 
 #endif /* HAVE_TOOLBARS */
 
-#endif /* _XEMACS_TOOLBAR_H_ */
+#endif /* INCLUDED_toolbar_h_ */
