@@ -36,7 +36,6 @@ static GHashTable *dll_cache;
 
 Lisp_Object gtk_type_to_lisp (GtkArg *arg);
 int lisp_to_gtk_type (Lisp_Object obj, GtkArg *arg);
-int lisp_to_gtk_ret_type (Lisp_Object obj, GtkArg *arg);
 void describe_gtk_arg (GtkArg *arg);
 guint symbol_to_enum (Lisp_Object obj, GtkType t);
 static guint lisp_to_flag (Lisp_Object obj, GtkType t);
@@ -86,7 +85,8 @@ This is for loading dependency DLLs into XEmacs.
 	}
       else
 	{
-	  signal_simple_error ("dll_open error", build_string (dll_error (NULL)));
+	  signal_error (Qfile_error,
+			     "dll_open error", build_string (dll_error (NULL)));
 	}
     }
   return (h ? Qt : Qnil);
@@ -310,7 +310,7 @@ ffi_object_printer (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
   char buf[200];
 
   if (print_readably)
-    error ("printing unreadable object #<ffi %p", XFFI (obj)->function_ptr);
+    printing_unreadable_object ("#<ffi %p>", XFFI (obj)->function_ptr);
 
   write_c_string ("#<ffi ", printcharfun);
   print_internal (XFFI (obj)->function_name, printcharfun, 1);
@@ -520,7 +520,7 @@ Import a variable into the XEmacs namespace.
 
   if (arg.type == GTK_TYPE_INVALID)
     {
-      signal_simple_error ("Unknown type", type);
+      sferror ("Unknown type", type);
     }
 
   /* Need to look thru the already-loaded dlls */
@@ -536,7 +536,7 @@ Import a variable into the XEmacs namespace.
 
   if (!var)
     {
-      signal_simple_error ("Could not locate variable", name);
+      gui_error ("Could not locate variable", name);
     }
 
   GTK_VALUE_POINTER(arg) = var;
@@ -579,7 +579,7 @@ Import a function into the XEmacs namespace.
 
   if (!name_func)
     {
-      signal_simple_error ("Could not locate function", name);
+      gui_error ("Could not locate function", name);
     }
 
   data = allocate_ffi_data ();
@@ -608,7 +608,7 @@ Import a function into the XEmacs namespace.
 
 	  if (the_type == GTK_TYPE_INVALID)
 	    {
-	      signal_simple_error ("Unknown argument type", type);
+	      invalid_argument ("Unknown argument type", type);
 	    }
 
 	  /* All things must be reduced to their basest form... */
@@ -620,7 +620,7 @@ Import a function into the XEmacs namespace.
 
 	  if (NILP (marshaller_type))
 	    {
-	      signal_simple_error ("Do not know how to marshal", type);
+	      invalid_argument ("Do not know how to marshal", type);
 	    }
 	  marshaller = concat3 (marshaller, build_string ("_"), marshaller_type);
 	  n_args++;
@@ -636,7 +636,7 @@ Import a function into the XEmacs namespace.
 
   if (data->return_type == GTK_TYPE_INVALID)
     {
-      signal_simple_error ("Unknown return type", rettype);
+      invalid_argument ("Unknown return type", rettype);
     }
 
   import_gtk_type (data->return_type);
@@ -648,7 +648,7 @@ Import a function into the XEmacs namespace.
 
   if (!marshaller_func)
     {
-      signal_simple_error ("Could not locate marshaller function", marshaller);
+      gui_error ("Could not locate marshaller function", marshaller);
     }
 
   data->n_args = n_args;
@@ -724,7 +724,7 @@ Call an external function.
 	  if (lisp_to_gtk_type (XCAR (tail), &the_args[n_args]))
 	    {
 	      /* There was some sort of an error */
-	      signal_simple_error ("Error converting arguments", args);
+	      gui_error ("Error converting arguments", args);
 	    }
 	  n_args++;
 	}
@@ -775,7 +775,7 @@ emacs_gtk_object_printer (Lisp_Object obj, Lisp_Object printcharfun, int escapef
   char buf[200];
 
   if (print_readably)
-    error ("printing unreadable object #<GtkObject %p>", XGTK_OBJECT (obj)->object);
+    printing_unreadable_object ("#<GtkObject %p>", XGTK_OBJECT (obj)->object);
 
   write_c_string ("#<GtkObject (", printcharfun);
   if (XGTK_OBJECT (obj)->alive_p)
@@ -815,7 +815,7 @@ object_getprop (Lisp_Object obj, Lisp_Object prop)
 
   if (!(info->arg_flags & GTK_ARG_READABLE))
     {
-      signal_simple_error ("Attempt to get write-only property", prop);
+      invalid_operation ("Attempt to get write-only property", prop);
     }
 
   gtk_object_getv (XGTK_OBJECT (obj)->object, 1, args);
@@ -879,12 +879,12 @@ object_putprop (Lisp_Object obj, Lisp_Object prop, Lisp_Object value)
 
   if (lisp_to_gtk_type (value, &args[0]))
     {
-      signal_simple_error ("Error converting to GtkType", value);
+      gui_error ("Error converting to GtkType", value);
     }
 
   if (!(info->arg_flags & GTK_ARG_WRITABLE))
     {
-      signal_simple_error ("Attemp to set read-only argument", prop);
+      invalid_operation ("Attempt to set read-only argument", prop);
     }
 
   gtk_object_setv (XGTK_OBJECT (obj)->object, 1, args);
@@ -908,7 +908,7 @@ emacs_gtk_object_finalizer (void *header, int for_disksave)
       Lisp_Object obj;
       XSETGTK_OBJECT (obj, data);
 
-      signal_simple_error
+      invalid_operation
 	("Can't dump an emacs containing GtkObject objects", obj);
     }
 
@@ -961,7 +961,7 @@ Lisp_Object build_gtk_object (GtkObject *obj)
   emacs_gtk_object_data *data = NULL;
   GUI_ID id = 0;
 
-  id = (GUI_ID) gtk_object_get_data (obj, GTK_DATA_GUI_IDENTIFIER);
+  id = (GUI_ID) gtk_object_get_data (obj, "xemacs::gui_id");
 
   if (id)
     {
@@ -977,7 +977,7 @@ Lisp_Object build_gtk_object (GtkObject *obj)
       XSETGTK_OBJECT (retval, data);
 
       id = new_gui_id ();
-      gtk_object_set_data (obj, GTK_DATA_GUI_IDENTIFIER, (gpointer) id);
+      gtk_object_set_data (obj, "xemacs::gui_id", (gpointer) id);
       gcpro_popup_callbacks (id, retval);
       gtk_object_ref (obj);
       gtk_signal_connect (obj, "destroy", GTK_SIGNAL_FUNC (__notice_object_destruction), (gpointer)id);
@@ -1036,7 +1036,7 @@ __internal_callback_marshal (GtkObject *obj, gpointer data, guint n_args, GtkArg
   signal_fake_event ();
 
   if (args[n_args].type != GTK_TYPE_NONE)
-    lisp_to_gtk_ret_type (rval, &args[n_args]);
+    lisp_to_gtk_type (rval, &args[n_args]);
 
   UNGCPRO;
 }
@@ -1086,7 +1086,7 @@ emacs_gtk_boxed_printer (Lisp_Object obj, Lisp_Object printcharfun, int escapefl
   char buf[200];
 
   if (print_readably)
-    error ("printing unreadable object #<GtkBoxed %p>", XGTK_BOXED (obj)->object);
+    printing_unreadable_object ("#<GtkBoxed %p>", XGTK_BOXED (obj)->object);
 
   write_c_string ("#<GtkBoxed (", printcharfun);
   write_c_string (gtk_type_name (XGTK_BOXED (obj)->object_type), printcharfun);
@@ -1196,7 +1196,7 @@ This is for loading dependency DLLs into XEmacs.
 
   if (t == GTK_TYPE_INVALID)
     {
-      signal_simple_error ("Not a GTK type", type);
+      invalid_argument ("Not a GTK type", type);
     }
   return (make_int (GTK_FUNDAMENTAL_TYPE (t)));
 }
@@ -1232,7 +1232,7 @@ The cdr is a list of all the magic properties it has.
       t = gtk_type_from_name (XSTRING_DATA (type));
       if (t == GTK_TYPE_INVALID)
 	{
-	  signal_simple_error ("Not a GTK type", type);
+	  invalid_argument ("Not a GTK type", type);
 	}
     }
   else
@@ -1243,7 +1243,7 @@ The cdr is a list of all the magic properties it has.
 
   if (GTK_FUNDAMENTAL_TYPE (t) != GTK_TYPE_OBJECT)
     {
-      signal_simple_error ("Not a GtkObject", type);
+      invalid_argument ("Not a GtkObject", type);
     }
 
   /* Need to do stupid shit like this to get the args
@@ -1331,10 +1331,10 @@ syms_of_ui_gtk (void)
   INIT_LRECORD_IMPLEMENTATION (emacs_ffi);
   INIT_LRECORD_IMPLEMENTATION (emacs_gtk_object);
   INIT_LRECORD_IMPLEMENTATION (emacs_gtk_boxed);
-  defsymbol (&Qemacs_ffip, "emacs-ffi-p");
-  defsymbol (&Qemacs_gtk_objectp, "emacs-gtk-object-p");
-  defsymbol (&Qemacs_gtk_boxedp, "emacs-gtk-boxed-p");
-  defsymbol (&Qvoid, "void");
+  DEFSYMBOL_MULTIWORD_PREDICATE (Qemacs_ffip);
+  DEFSYMBOL_MULTIWORD_PREDICATE (Qemacs_gtk_objectp);
+  DEFSYMBOL_MULTIWORD_PREDICATE (Qemacs_gtk_boxedp);
+  DEFSYMBOL (Qvoid);
   DEFSUBR (Fdll_load);
   DEFSUBR (Fgtk_import_function_internal);
   DEFSUBR (Fgtk_import_variable_internal);
@@ -1644,7 +1644,7 @@ int lisp_to_gtk_type (Lisp_Object obj, GtkArg *arg)
 	    }
 	  else
 	    {
-	      signal_simple_error ("Don't know how to convert object to GDK_WINDOW", obj);
+	      invalid_argument ("Don't know how to convert object to GDK_WINDOW", obj);
 	    }
 	  break;
 	}
@@ -1665,11 +1665,11 @@ int lisp_to_gtk_type (Lisp_Object obj, GtkArg *arg)
 	    }
 	  else if (STRINGP (obj))
 	    {
-	      signal_simple_error ("Please use a color specifier or instance, not a string", obj);
+	      invalid_argument ("Please use a color specifier or instance, not a string", obj);
 	    }
 	  else
 	    {
-	      signal_simple_error ("Don't know hot to convert to GdkColor", obj);
+	      invalid_argument ("Don't know how to convert to GdkColor", obj);
 	    }
 	}
       else if (arg->type == GTK_TYPE_GDK_FONT)
@@ -1703,11 +1703,11 @@ int lisp_to_gtk_type (Lisp_Object obj, GtkArg *arg)
 	    }
 	  else if (STRINGP (obj))
 	    {
-	      signal_simple_error ("Please use a font specifier or instance, not a string", obj);
+	      invalid_argument ("Please use a font specifier or instance, not a string", obj);
 	    }
 	  else
 	    {
-	      signal_simple_error ("Don't know hot to convert to GdkColor", obj);
+	      invalid_argument ("Don't know how to convert to GdkColor", obj);
 	    }
 	}
       else
@@ -1763,7 +1763,7 @@ int lisp_to_gtk_type (Lisp_Object obj, GtkArg *arg)
 	  if (XGTK_OBJECT (obj)->alive_p)
 	    GTK_VALUE_OBJECT (*arg) = XGTK_OBJECT (obj)->object;
 	  else
-	    signal_simple_error ("Attempting to pass dead object to GTK function", obj);
+	    invalid_argument ("Attempting to pass dead object to GTK function", obj);
 	}
       break;
 
@@ -1797,285 +1797,6 @@ int lisp_to_gtk_type (Lisp_Object obj, GtkArg *arg)
   return (0);
 }
 
-/* Convert lisp types to GTK return types.  This is identical to
-   lisp_to_gtk_type() except that the macro used to set the value is
-   different.
-
-   ### There should be some way of combining these two functions.
-*/
-int lisp_to_gtk_ret_type (Lisp_Object obj, GtkArg *arg)
-{
-  switch (GTK_FUNDAMENTAL_TYPE (arg->type))
-    {
-      /* flag types */
-    case GTK_TYPE_NONE:
-      return (0);
-    case GTK_TYPE_CHAR:
-      {
-	Emchar c;
-
-	CHECK_CHAR_COERCE_INT (obj);
-	c = XCHAR (obj);
-	*(GTK_RETLOC_CHAR (*arg)) = c;
-      }
-      break;
-    case GTK_TYPE_UCHAR:
-      {
-	Emchar c;
-
-	CHECK_CHAR_COERCE_INT (obj);
-	c = XCHAR (obj);
-	*(GTK_RETLOC_CHAR (*arg)) = c;
-      }
-      break;
-    case GTK_TYPE_BOOL:
-      *(GTK_RETLOC_BOOL (*arg)) = NILP (obj) ? FALSE : TRUE;
-      break;
-    case GTK_TYPE_INT:
-    case GTK_TYPE_UINT:
-      if (NILP (obj) || EQ (Qt, obj))
-	{
-	  /* For we are a kind mistress and allow sending t/nil for
-             1/0 to stupid GTK functions that say they take guint or
-             gint in the header files, but actually treat it like a
-             bool.  *sigh*
-	  */
-	  *(GTK_RETLOC_INT(*arg)) = NILP (obj) ? 0 : 1;
-	}
-      else
-	{
-	  CHECK_INT (obj);
-	  *(GTK_RETLOC_INT(*arg)) = XINT (obj);
-	}
-      break;
-    case GTK_TYPE_LONG:
-    case GTK_TYPE_ULONG:
-      abort();
-    case GTK_TYPE_FLOAT:
-      CHECK_INT_OR_FLOAT (obj);
-      *(GTK_RETLOC_FLOAT(*arg)) = extract_float (obj);
-      break;
-    case GTK_TYPE_DOUBLE:
-      CHECK_INT_OR_FLOAT (obj);
-      *(GTK_RETLOC_DOUBLE(*arg)) = extract_float (obj);
-      break;
-    case GTK_TYPE_STRING:
-      if (NILP (obj))
-	*(GTK_RETLOC_STRING (*arg)) = NULL;
-      else
-	{
-	  CHECK_STRING (obj);
-	  *(GTK_RETLOC_STRING (*arg)) = (char *) XSTRING_DATA (obj);
-	}
-      break;
-    case GTK_TYPE_ENUM:
-    case GTK_TYPE_FLAGS:
-      /* Convert a lisp symbol to a GTK enum */
-      *(GTK_RETLOC_ENUM(*arg)) = lisp_to_flag (obj, arg->type);
-      break;
-    case GTK_TYPE_BOXED:
-      if (NILP (obj))
-	{
-	  *(GTK_RETLOC_BOXED(*arg)) = NULL;
-	}
-      else if (GTK_BOXEDP (obj))
-	{
-	  *(GTK_RETLOC_BOXED(*arg)) = XGTK_BOXED (obj)->object;
-	}
-      else if (arg->type == GTK_TYPE_STYLE)
-	{
-	  obj = Ffind_face (obj);
-	  CHECK_FACE (obj);
-	  *(GTK_RETLOC_BOXED(*arg)) = face_to_style (obj);
-	}
-      else if (arg->type == GTK_TYPE_GDK_GC)
-	{
-	  obj = Ffind_face (obj);
-	  CHECK_FACE (obj);
-	  *(GTK_RETLOC_BOXED(*arg)) = face_to_gc (obj);
-	}
-      else if (arg->type == GTK_TYPE_GDK_WINDOW)
-	{
-	  if (GLYPHP (obj))
-	    {
-	      Lisp_Object window = Fselected_window (Qnil);
-	      Lisp_Object instance = glyph_image_instance (obj, window, ERROR_ME_NOT, 1);
-	      struct Lisp_Image_Instance *p = XIMAGE_INSTANCE (instance);
-
-	      switch (XIMAGE_INSTANCE_TYPE (instance))
-		{
-		case IMAGE_TEXT:
-		case IMAGE_POINTER:
-		case IMAGE_SUBWINDOW:
-		case IMAGE_NOTHING:
-		  *(GTK_RETLOC_BOXED(*arg)) = NULL;
-		  break;
-
-		case IMAGE_MONO_PIXMAP:
-		case IMAGE_COLOR_PIXMAP:
-		  *(GTK_RETLOC_BOXED(*arg)) = IMAGE_INSTANCE_GTK_PIXMAP (p);
-		  break;
-		}
-	    }
-	  else if (GTK_OBJECTP (obj) && GTK_IS_WIDGET (XGTK_OBJECT (obj)->object))
-	    {
-	      *(GTK_RETLOC_BOXED(*arg)) = GTK_WIDGET (XGTK_OBJECT (obj))->window;
-	    }
-	  else
-	    {
-	      signal_simple_error ("Don't know how to convert object to GDK_WINDOW", obj);
-	    }
-	  break;
-	}
-      else if (arg->type == GTK_TYPE_GDK_COLOR)
-	{
-	  if (COLOR_SPECIFIERP (obj))
-	    {
-	      /* If it is a specifier, we just convert it to an
-                 instance, and let the ifs below handle it.
-	      */
-	      obj = Fspecifier_instance (obj, Qnil, Qnil, Qnil);
-	    }
-	  
-	  if (COLOR_INSTANCEP (obj))
-	    {
-	      /* Easiest one */
-	      *(GTK_RETLOC_BOXED(*arg)) = COLOR_INSTANCE_GTK_COLOR (XCOLOR_INSTANCE (obj));
-	    }
-	  else if (STRINGP (obj))
-	    {
-	      signal_simple_error ("Please use a color specifier or instance, not a string", obj);
-	    }
-	  else
-	    {
-	      signal_simple_error ("Don't know hot to convert to GdkColor", obj);
-	    }
-	}
-      else if (arg->type == GTK_TYPE_GDK_FONT)
-	{
-	  if (SYMBOLP (obj))
-	    {
-	      /* If it is a symbol, we treat that as a face name */
-	      obj = Ffind_face (obj);
-	    }
-
-	  if (FACEP (obj))
-	    {
-	      /* If it is a face, we just grab the font specifier, and
-                 cascade down until we finally reach a FONT_INSTANCE
-	      */
-	      obj = Fget (obj, Qfont, Qnil);
-	    }
-
-	  if (FONT_SPECIFIERP (obj))
-	    {
-	      /* If it is a specifier, we just convert it to an
-                 instance, and let the ifs below handle it
-	      */
-	      obj = Fspecifier_instance (obj, Qnil, Qnil, Qnil);
-	    }
-
-	  if (FONT_INSTANCEP (obj))
-	    {
-	      /* Easiest one */
-	      *(GTK_RETLOC_BOXED(*arg)) = FONT_INSTANCE_GTK_FONT (XFONT_INSTANCE (obj));
-	    }
-	  else if (STRINGP (obj))
-	    {
-	      signal_simple_error ("Please use a font specifier or instance, not a string", obj);
-	    }
-	  else
-	    {
-	      signal_simple_error ("Don't know hot to convert to GdkColor", obj);
-	    }
-	}
-      else
-	{
-	  /* Unknown type to convert to boxed */
-	  stderr_out ("Don't know how to convert to boxed!\n");
-	  *(GTK_RETLOC_BOXED(*arg)) = NULL;
-	}
-      break;
-
-    case GTK_TYPE_POINTER:
-      if (NILP (obj))
-	*(GTK_RETLOC_POINTER(*arg)) = NULL;
-      else
-	*(GTK_RETLOC_POINTER(*arg)) = LISP_TO_VOID (obj);
-      break;
-
-      /* structured types */
-    case GTK_TYPE_SIGNAL:
-    case GTK_TYPE_ARGS: /* This we can do as a list of values */
-    case GTK_TYPE_C_CALLBACK:
-    case GTK_TYPE_FOREIGN:
-      stderr_out ("Do not know how to convert `%s' from lisp!\n", gtk_type_name (arg->type));
-      return (-1);
-
-#if 0
-      /* #### BILL! */
-      /* This is not used, and does not work with union type */
-    case GTK_TYPE_CALLBACK:
-      {
-	GUI_ID id;
-
-	id = new_gui_id ();
-	obj = Fcons (Qnil, obj); /* Empty data */
-	obj = Fcons (make_int (id), obj);
-
-	gcpro_popup_callbacks (id, obj);
-
-	*(GTK_RETLOC_CALLBACK(*arg)).marshal = __internal_callback_marshal;
-	*(GTK_RETLOC_CALLBACK(*arg)).data = (gpointer) obj;
-	*(GTK_RETLOC_CALLBACK(*arg)).notify = __internal_callback_destroy;
-      }
-      break;
-#endif
-
-      /* base type of the object system */
-    case GTK_TYPE_OBJECT:
-      if (NILP (obj))
-	*(GTK_RETLOC_OBJECT (*arg)) = NULL;
-      else
-	{
-	  CHECK_GTK_OBJECT (obj);
-	  if (XGTK_OBJECT (obj)->alive_p)
-	    *(GTK_RETLOC_OBJECT (*arg)) = XGTK_OBJECT (obj)->object;
-	  else
-	    signal_simple_error ("Attempting to pass dead object to GTK function", obj);
-	}
-      break;
-
-    default:
-      if (GTK_FUNDAMENTAL_TYPE (arg->type) == GTK_TYPE_ARRAY)
-	{
-	  if (NILP (obj))
-	    *(GTK_RETLOC_POINTER(*arg)) = NULL;
-	  else
-	    {
-	      xemacs_list_to_array (obj, arg);
-	    }
-	}
-      else if (GTK_FUNDAMENTAL_TYPE (arg->type) == GTK_TYPE_LISTOF)
-	{
-	  if (NILP (obj))
-	    *(GTK_RETLOC_POINTER(*arg)) = NULL;
-	  else
-	    {
-	      xemacs_list_to_gtklist (obj, arg);
-	    }
-	}
-      else
-	{
-	  stderr_out ("Do not know how to convert `%s' from lisp!\n", gtk_type_name (arg->type));
-	  abort();
-	}
-      break;
-    }
-
-  return (0);
-}
-
 /* This is used in glyphs-gtk.c as well */
 static Lisp_Object
 get_enumeration (GtkType t)
@@ -2105,14 +1826,14 @@ symbol_to_enum (Lisp_Object obj, GtkType t)
 
   if (NILP (alist))
     {
-      signal_simple_error ("Unkown enumeration", build_string (gtk_type_name (t)));
+      invalid_argument ("Unknown enumeration", build_string (gtk_type_name (t)));
     }
 
   value = Fassq (obj, alist);
 
   if (NILP (value))
     {
-      signal_simple_error ("Unknown value", obj);
+      invalid_argument ("Unknown value", obj);
     }
 
   CHECK_INT (XCDR (value));
@@ -2174,7 +1895,7 @@ enum_to_symbol (guint value, GtkType t)
 
   if (NILP (alist))
     {
-      signal_simple_error ("Unkown enumeration", build_string (gtk_type_name (t)));
+      invalid_argument ("Unknown enumeration", build_string (gtk_type_name (t)));
     }
 
   cell = Frassq (make_int (value), alist);
