@@ -1,4 +1,4 @@
-/* unexec for GNU Emacs on Cygwin32.
+/* unexec for XEmacs on Cygwin32.
    Copyright (C) 1994, 1998 Free Software Foundation, Inc.
 
 This file is part of XEmacs.
@@ -26,35 +26,28 @@ Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 #include <config.h>
 #include "lisp.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <string.h>
-
 #define DONT_ENCAPSULATE /* filenames are external in unex*.c */
 #include "sysfile.h"
 
-#define PERROR(arg) perror(arg);exit(-1) 
+#define PERROR(arg)				\
+do {						\
+  perror (arg);					\
+  exit (-1);					\
+} while (0)
 
-#if !defined(HAVE_A_OUT_H) && !defined(WIN32_NATIVE)
+#if !defined (HAVE_A_OUT_H) && !defined (WIN32_NATIVE)
 unexec (char *, char *, void *, void *,	void *)
 {
   PERROR("cannot unexec() a.out.h not installed");
 }
 #else
 
-#ifndef MAX_PATH
-#define MAX_PATH 260
-#endif
-
 #ifdef MINGW
 #include <../../include/a.out.h>
 #else
 #include <a.out.h>
 #endif
 
-#define STACK_SIZE 0x800000
 #define ALLOC_UNIT 0xFFFF
 #define ALLOC_MASK ~((unsigned long)(ALLOC_UNIT))
 #define ALIGN_ALLOC(addr) \
@@ -91,13 +84,12 @@ FILHDR f_hdr;
 PEAOUTHDR f_ohdr;
 SCNHDR f_data, f_bss, f_text, f_nextdata;
 
-#define PERROR(arg) perror(arg);exit(-1) 
-#define CHECK_AOUT_POS(a) \
-if (lseek(a_out, 0, SEEK_CUR) != a) \
-{ \
-  printf("we are at %lx, should be at %lx\n", \
-	 lseek(a_out, 0, SEEK_CUR), a); \
-  exit(-1); \
+#define CHECK_AOUT_POS(a)			\
+if (lseek(a_out, 0, SEEK_CUR) != a)		\
+{						\
+  printf("we are at %lx, should be at %lx\n",	\
+	 lseek(a_out, 0, SEEK_CUR), a);		\
+  exit(-1);					\
 }
 
 /* Dump out .data and .bss sections into a new executable.  */
@@ -107,7 +99,7 @@ unexec (char *out_name, char *in_name, uintptr_t start_data,
 {
   /* ugly nt hack - should be in lisp */
   int a_new, a_out = -1;
-  char new_name[MAX_PATH], a_name[MAX_PATH];
+  char new_name[PATH_MAX], a_name[PATH_MAX];
   char *ptr;
   
   /* Make sure that the input and output filenames have the
@@ -126,15 +118,11 @@ unexec (char *out_name, char *in_name, uintptr_t start_data,
   /* round_heap (get_allocation_unit ()); */
 
   if (a_name && (a_out = open (a_name, O_RDONLY | OPEN_BINARY)) < 0)
-    {
-      PERROR (a_name);
-    }
+    PERROR (a_name);
 
   if ((a_new = open (new_name, O_WRONLY | O_TRUNC | O_CREAT | OPEN_BINARY,
 		     0755)) < 0)
-    {
-      PERROR (new_name);
-    }
+    PERROR (new_name);
 
   /* Get the interesting section info, like start and size of .bss...  */
   get_section_info (a_out, a_name);
@@ -147,54 +135,41 @@ unexec (char *out_name, char *in_name, uintptr_t start_data,
 }
 
 /* Flip through the executable and cache the info necessary for dumping.  */
-static void get_section_info (int a_out, char* a_name)
+static void
+get_section_info (int a_out, char* a_name)
 {
   extern char my_ebss[];
   /* From lastfile.c  */
   extern char my_edata[];
 
   if (read (a_out, &f_hdr, sizeof (f_hdr)) != sizeof (f_hdr))
-    {
-      PERROR (a_name);
-    }
+    PERROR (a_name);
 
   if (f_hdr.e_magic != DOSMAGIC) 
-    {
-      PERROR("unknown exe header");
-    }
+    PERROR("unknown exe header");
 
   /* Check the NT header signature ...  */
   if (f_hdr.nt_signature != NT_SIGNATURE) 
-    {
-      PERROR("invalid nt header");
-    }
+    PERROR("invalid nt header");
 
   /* Flip through the sections for .data and .bss ...  */
   if (f_hdr.f_opthdr > 0)
     {
       if (read (a_out, &f_ohdr, AOUTSZ) != AOUTSZ)
-	{
-	  PERROR (a_name);
-	}
+	PERROR (a_name);
     }
   /* Loop through .data & .bss section headers, copying them in.
      With newer lds these are reversed so we have to cope with both */
   lseek (a_out, sizeof (f_hdr) + f_hdr.f_opthdr, 0);
 
   if (read (a_out, &f_text, sizeof (f_text)) != sizeof (f_text)
-      ||
-      strcmp (f_text.s_name, ".text"))
-    {
-      PERROR ("no .text section");
-    }
+      || strcmp (f_text.s_name, ".text"))
+    PERROR ("no .text section");
 
   /* The .bss section.  */
   if (read (a_out, &f_bss, sizeof (f_bss)) != sizeof (f_bss)
-      ||
-      (strcmp (f_bss.s_name, ".bss") && strcmp (f_bss.s_name, ".data")))
-    {
-      PERROR ("no .bss / .data section");
-    }
+      || (strcmp (f_bss.s_name, ".bss") && strcmp (f_bss.s_name, ".data")))
+    PERROR ("no .bss / .data section");
 
   /* check for reversed .bss and .data */
   if (!strcmp(f_bss.s_name, ".data"))
@@ -208,20 +183,14 @@ static void get_section_info (int a_out, char* a_name)
   if (!sections_reversed)
     {
       if (read (a_out, &f_data, sizeof (f_data)) != sizeof (f_data)
-	  ||
-	  strcmp (f_data.s_name, ".data"))
-	{
-	  PERROR ("no .data section");
-	}
+	  || strcmp (f_data.s_name, ".data"))
+	PERROR ("no .data section");
     }
   else
     {
       if (read (a_out, &f_bss, sizeof (f_bss)) != sizeof (f_bss)
-	  ||
-	  strcmp (f_bss.s_name, ".bss"))
-	{
-	  PERROR ("no .bss section");
-	}
+	  || strcmp (f_bss.s_name, ".bss"))
+	PERROR ("no .bss section");
     }
   
   bss_start = (void *) ((char*)f_ohdr.ImageBase + f_bss.s_vaddr);
@@ -244,9 +213,7 @@ static void get_section_info (int a_out, char* a_name)
   if (read (a_out, &f_nextdata, sizeof (f_nextdata)) != sizeof (f_nextdata)
       &&
       strcmp (&f_nextdata.s_name[2], "data"))
-    {
-      PERROR ("no other data section");
-    }
+    PERROR ("no other data section");
 }
 
 /* The dump routines.  */
@@ -256,30 +223,30 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
 {
   long size=0;
   unsigned long new_data_size, new_bss_size, 
-    bss_padding, file_sz_change, data_padding=0,
-    f_data_s_vaddr = f_data.s_vaddr,
-    f_data_s_scnptr = f_data.s_scnptr,
-    f_bss_s_vaddr = f_bss.s_vaddr, 
-    f_nextdata_s_scnptr = f_nextdata.s_scnptr;
+  bss_padding, file_sz_change, data_padding=0,
+  f_data_s_vaddr = f_data.s_vaddr,
+  f_data_s_scnptr = f_data.s_scnptr,
+  f_bss_s_vaddr = f_bss.s_vaddr, 
+  f_nextdata_s_scnptr = f_nextdata.s_scnptr;
 
   int i;
   void* empty_space;
   extern int static_heap_dumped;
   SCNHDR section;
   /* calculate new sizes:
-
+     
      f_ohdr.dsize is the total initialized data size on disk which is
      f_data.s_size + f_idata.s_size.
-
+     
      f_ohdr.data_start is the base addres of all data and so should
      not be changed.
      
      *.s_vaddr is the virtual address of the start of the section
      *normalized from f_ohdr.ImageBase.
-
+     
      *.s_paddr appears to be the number of bytes in the section
      *actually used (whereas *.s_size is aligned).
-
+     
      bsize is now 0 since subsumed into .data
      dsize is dsize + (f_data.s_vaddr - f_bss.s_vaddr)
      f_data.s_vaddr is f_bss.s_vaddr
@@ -299,24 +266,18 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
     }
 
   if ((new_bss_size - bss_size) < BSS_PAD_SIZE)
-    { 
-      PERROR (".bss free space too small");
-    }
+    PERROR (".bss free space too small");
 
   file_sz_change=(new_bss_size + data_padding) - BSS_PAD_SIZE;
   new_data_size=f_ohdr.dsize + file_sz_change;
 
   if (!sections_reversed)
-    {
-      f_data.s_vaddr = f_bss.s_vaddr;
-    }
+    f_data.s_vaddr = f_bss.s_vaddr;
   f_data.s_paddr += file_sz_change;
 #if 0 
   if (f_data.s_size + f_nextdata.s_size != f_ohdr.dsize)
-    {
-      printf("section size doesn't tally with dsize %lx != %lx\n", 
-	     f_data.s_size + f_nextdata.s_size, f_ohdr.dsize);
-    }
+    printf("section size doesn't tally with dsize %lx != %lx\n", 
+	   f_data.s_size + f_nextdata.s_size, f_ohdr.dsize);
 #endif
   f_data.s_size += file_sz_change;
   lseek (a_new, 0, SEEK_SET);
@@ -328,33 +289,22 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
 
   printf("writing file header\n");
   if (write(a_new, &f_hdr, sizeof(f_hdr)) != sizeof(f_hdr))
-    {
-      PERROR("failed to write file header");
-    }
+    PERROR("failed to write file header");
   /* write optional header fixing dsize & bsize*/
   printf("writing optional header\n");
   printf("new data size is %lx, >= %lx\n", new_data_size,
 	 f_ohdr.dsize + f_ohdr.bsize);
   if (new_data_size < f_ohdr.dsize + f_ohdr.bsize )
-    {
-      printf("warning: new data size is < approx\n");
-    }
+    printf("warning: new data size is < approx\n");
   f_ohdr.dsize=new_data_size;
   f_ohdr.bsize=BSS_PAD_SIZE;
-  /* Prevent stack overflow with regexp usage. */
-  f_ohdr.SizeOfStackReserve = STACK_SIZE;
-
   if (write(a_new, &f_ohdr, sizeof(f_ohdr)) != sizeof(f_ohdr))
-    {
-      PERROR("failed to write optional header");
-    }
+    PERROR("failed to write optional header");
   /* write text as is */
   printf("writing text header (unchanged)\n");
 
   if (write(a_new, &f_text, sizeof(f_text)) != sizeof(f_text))
-    {
-      PERROR("failed to write text header");
-    }
+    PERROR("failed to write text header");
 #ifndef NO_DEBUG
   /* Write small bss section. */
   if (!sections_reversed)
@@ -363,18 +313,14 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
       f_bss.s_paddr = BSS_PAD_SIZE;
       f_bss.s_vaddr = f_data.s_vaddr - BSS_PAD_SIZE;
       if (write(a_new, &f_bss, sizeof(f_bss)) != sizeof(f_bss))
-	{
-	  PERROR("failed to write bss header");
-	}
+	PERROR("failed to write bss header");
     }
 #endif
   /* write new data header */
   printf("writing .data header\n");
 
   if (write(a_new, &f_data, sizeof(f_data)) != sizeof(f_data))
-    {
-      PERROR("failed to write data header");
-    }
+    PERROR("failed to write data header");
 #ifndef NO_DEBUG
   /* Write small bss section. */
   if (sections_reversed)
@@ -383,9 +329,7 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
       f_bss.s_paddr = BSS_PAD_SIZE;
       f_bss.s_vaddr = f_nextdata.s_vaddr - BSS_PAD_SIZE;
       if (write(a_new, &f_bss, sizeof(f_bss)) != sizeof(f_bss))
-	{
-	  PERROR("failed to write bss header");
-	}
+	PERROR("failed to write bss header");
     }
 #endif
   printf("writing following data header\n");
@@ -393,34 +337,26 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
   if (f_nextdata.s_lnnoptr != 0) f_nextdata.s_lnnoptr += file_sz_change;
   if (f_nextdata.s_relptr != 0) f_nextdata.s_relptr += file_sz_change;
   if (write(a_new, &f_nextdata, sizeof(f_nextdata)) != sizeof(f_nextdata))
-    {
-      PERROR("failed to write nextdata header");
-    }
+    PERROR("failed to write nextdata header");
 
   /* copy other section headers adjusting the file offset */
   for (i=0; i<(f_hdr.f_nscns-3); i++)
     {
       if (read (a_out, &section, sizeof (section)) != sizeof (section))
-	{
-	  PERROR ("no .data section");
-	}
+	PERROR ("no .data section");
       
       section.s_scnptr += file_sz_change;
       if (section.s_lnnoptr != 0) section.s_lnnoptr += file_sz_change;
       if (section.s_relptr != 0) section.s_relptr += file_sz_change;
 
       if (write(a_new, &section, sizeof(section)) != sizeof(section))
-	{
-	  PERROR("failed to write data header");
-	}
+	PERROR("failed to write data header");
     }
 #ifdef NO_DEBUG
   /* dump bss to maintain offsets */
   memset(&f_bss, 0, sizeof(f_bss));
   if (write(a_new, &f_bss, sizeof(f_bss)) != sizeof(f_bss))
-    {
-      PERROR("failed to write bss header");
-    }
+    PERROR("failed to write bss header");
 #endif
   size=lseek(a_new, 0, SEEK_CUR);
   CHECK_AOUT_POS(size);
@@ -446,16 +382,12 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
       /* pad, needs to be zero */
       bss_padding = (new_bss_size - bss_size) - BSS_PAD_SIZE;
       if (bss_padding < 0)
-	{
-	  PERROR("padded .bss too small");
-	}
+	PERROR("padded .bss too small");
       printf ("padding .bss ... %lx bytes\n", bss_padding);
       empty_space = malloc(bss_padding);
       memset(empty_space, 0, bss_padding);
       if (write(a_new, empty_space, bss_padding) != (int)bss_padding)
-	{
-	  PERROR("failed to write bss section");
-	}
+	PERROR("failed to write bss section");
       free(empty_space);
     }
 
@@ -464,9 +396,7 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
   /* Get a pointer to the raw data in our address space.  */
   printf ("dumping .data section... %lx bytes\n", data_size);
   if (write(a_new, data_start_va, data_size) != (int)data_size)
-    {
-      PERROR("failed to write data section");
-    }
+    PERROR("failed to write data section");
   /* were going to use free again ... */
   static_heap_dumped = 0;
   
@@ -487,23 +417,17 @@ copy_executable_and_dump_data_section (int a_out, int a_new)
       /* dump bss + padding between sections */
       printf ("dumping .bss into executable... %lx bytes\n", bss_size);
       if (write(a_new, bss_start, bss_size) != (int)bss_size)
-	{
-	  PERROR("failed to write bss section");
-	}
+	PERROR("failed to write bss section");
       
       /* pad, needs to be zero */
       bss_padding = (new_bss_size - bss_size) - BSS_PAD_SIZE;
       if (bss_padding < 0)
-	{
-	  PERROR("padded .bss too small");
-	}
+	PERROR("padded .bss too small");
       printf ("padding .bss ... %lx bytes\n", bss_padding);
       empty_space = malloc(bss_padding);
       memset(empty_space, 0, bss_padding);
       if (write(a_new, empty_space, bss_padding) != (int)bss_padding)
-	{
-	  PERROR("failed to write bss section");
-	}
+	PERROR("failed to write bss section");
       free(empty_space);
       if (lseek(a_new, 0, SEEK_CUR) != f_nextdata.s_scnptr)
 	{
@@ -542,9 +466,7 @@ static void dup_file_area(int a_out, int a_new, long size)
     {
       n = size > sizeof (page) ? sizeof (page) : size;
       if (read (a_out, page, n) != n || write (a_new, page, n) != n)
-	{
-	  PERROR ("dump_out()");
-	}
+	PERROR ("dump_out()");
     }
 }
 
@@ -555,15 +477,11 @@ static void write_int_to_bss(int a_out, int a_new, void* va, void* newval)
 
   cpos = lseek(a_new, 0, SEEK_CUR);
   if (va < bss_start || va > bss_start + f_data.s_size)
-    {
-      PERROR("address not in data space\n");
-    }
+    PERROR("address not in data space\n");
   lseek(a_new, f_data.s_scnptr + ((unsigned long)va - 
 				  (unsigned long)bss_start), SEEK_SET);
   if (write(a_new, newval, sizeof(int)) != (int)sizeof(int))
-    {
-      PERROR("failed to write int value");
-    }
+    PERROR("failed to write int value");
   lseek(a_new, cpos, SEEK_SET);
 }
 #endif
