@@ -2,8 +2,8 @@
 emacs_is_beta=t
 emacs_major_version=21
 emacs_minor_version=5
-emacs_beta_version=1
-xemacs_codename="anise"
+emacs_beta_version=2
+xemacs_codename="artichoke"
 infodock_major_version=4
 infodock_minor_version=0
 infodock_build_version=8
